@@ -21,10 +21,7 @@
 import shutil
 
 from lava_common.exceptions import InfrastructureError
-from lava_dispatcher.action import (
-    Pipeline,
-    Action,
-)
+from lava_dispatcher.action import Pipeline, Action
 from lava_dispatcher.actions.boot import BootAction
 from lava_dispatcher.connections.serial import ConnectDevice
 from lava_dispatcher.logical import Boot, RetryAction
@@ -46,19 +43,28 @@ class CMSIS(Boot):
 
     @classmethod
     def accepts(cls, device, parameters):
-        if 'cmsis-dap' not in device['actions']['boot']['methods']:
+        if "cmsis-dap" not in device["actions"]["boot"]["methods"]:
             return False, '"cmsis-dap" is not in the device configuration boot methods'
-        if 'method' not in parameters:
+        if "method" not in parameters:
             return False, '"method" not in parameters'
-        if parameters['method'] != 'cmsis-dap':
+        if parameters["method"] != "cmsis-dap":
             return False, '"method" was not "cmsis-dap"'
-        if 'board_id' not in device:
+        if "board_id" not in device:
             return False, 'device has no "board_id" configured'
-        if 'parameters' not in device['actions']['boot']['methods']['cmsis-dap']:
-            return False, '"parameters" was not in the device boot method configuration for "cmsis-dap"'
-        if 'usb_mass_device' not in device['actions']['boot']['methods']['cmsis-dap']['parameters']:
-            return False, '"usb_mass_device" was not in the device configuration "cmsis-dap" boot method parameters'
-        return True, 'accepted'
+        if "parameters" not in device["actions"]["boot"]["methods"]["cmsis-dap"]:
+            return (
+                False,
+                '"parameters" was not in the device boot method configuration for "cmsis-dap"',
+            )
+        if (
+            "usb_mass_device"
+            not in device["actions"]["boot"]["methods"]["cmsis-dap"]["parameters"]
+        ):
+            return (
+                False,
+                '"usb_mass_device" was not in the device configuration "cmsis-dap" boot method parameters',
+            )
+        return True, "accepted"
 
 
 class BootCMSIS(BootAction):
@@ -68,7 +74,9 @@ class BootCMSIS(BootAction):
     summary = "boot cmsis usb image"
 
     def populate(self, parameters):
-        self.internal_pipeline = Pipeline(parent=self, job=self.job, parameters=parameters)
+        self.internal_pipeline = Pipeline(
+            parent=self, job=self.job, parameters=parameters
+        )
         self.internal_pipeline.add_action(BootCMSISRetry())
 
 
@@ -80,16 +88,22 @@ class BootCMSISRetry(RetryAction):
 
     def validate(self):
         super().validate()
-        method_params = self.job.device['actions']['boot']['methods']['cmsis-dap']['parameters']
-        usb_mass_device = method_params.get('usb_mass_device')
+        method_params = self.job.device["actions"]["boot"]["methods"]["cmsis-dap"][
+            "parameters"
+        ]
+        usb_mass_device = method_params.get("usb_mass_device")
         if not usb_mass_device:
             self.errors = "usb_mass_device unset"
 
     def populate(self, parameters):
-        self.internal_pipeline = Pipeline(parent=self, job=self.job, parameters=parameters)
-        method_params = self.job.device['actions']['boot']['methods']['cmsis-dap']['parameters']
-        usb_mass_device = method_params.get('usb_mass_device')
-        resets_after_flash = method_params.get('resets_after_flash', True)
+        self.internal_pipeline = Pipeline(
+            parent=self, job=self.job, parameters=parameters
+        )
+        method_params = self.job.device["actions"]["boot"]["methods"]["cmsis-dap"][
+            "parameters"
+        ]
+        usb_mass_device = method_params.get("usb_mass_device")
+        resets_after_flash = method_params.get("resets_after_flash", True)
         if self.job.device.hard_reset_command:
             self.internal_pipeline.add_action(ResetDevice())
             self.internal_pipeline.add_action(WaitDevicePathAction(usb_mass_device))
@@ -104,6 +118,7 @@ class FlashCMSISAction(Action):
     name = "flash-cmsis"
     description = "flash cmsis to usb mass storage"
     summary = "flash cmsis to usb mass storage"
+    command_exception = InfrastructureError
 
     def __init__(self):
         super().__init__()
@@ -112,31 +127,38 @@ class FlashCMSISAction(Action):
 
     def validate(self):
         super().validate()
-        if self.job.device['board_id'] == '0000000000':
+        if self.job.device["board_id"] == "0000000000":
             self.errors = "[FLASH_CMSIS] board_id unset"
-        method_parameters = self.job.device['actions']['boot']['methods']['cmsis-dap']['parameters']
-        self.usb_mass_device = method_parameters.get('usb_mass_device')
+        method_parameters = self.job.device["actions"]["boot"]["methods"]["cmsis-dap"][
+            "parameters"
+        ]
+        self.usb_mass_device = method_parameters.get("usb_mass_device")
         if not self.usb_mass_device:
             self.errors = "usb_mass_device unset"
-        for action in self.get_namespace_keys('download-action'):
-            action_arg = self.get_namespace_data(action='download-action', label=action, key='file')
+        for action in self.get_namespace_keys("download-action"):
+            action_arg = self.get_namespace_data(
+                action="download-action", label=action, key="file"
+            )
             self.filelist.extend([action_arg])
 
     def run(self, connection, max_end_time):
-        connection = self.get_namespace_data(
-            action='shared', label='shared', key='connection', deepcopy=False)
         connection = super().run(connection, max_end_time)
         dstdir = mkdtemp()
-        mount_command = "mount -t vfat %s %s" % (self.usb_mass_device, dstdir)
-        self.run_command(mount_command.split(' '), allow_silent=True)
         # mount
+        self.run_cmd(
+            ["mount", "-t", "vfat", self.usb_mass_device, dstdir],
+            error_msg="Unable to mount USB device %s" % self.usb_mass_device,
+        )
+        # copy files
         for f in self.filelist:
             self.logger.debug("Copying %s to %s", f, dstdir)
             shutil.copy2(f, dstdir)
+        # sync
+        self.run_cmd(["sync", dstdir], error_msg="Unable to sync %s" % dstdir)
         # umount
-        umount_command = "umount %s" % self.usb_mass_device
-        self.run_command(umount_command.split(' '), allow_silent=True)
-        if self.errors:
-            raise InfrastructureError("Unable to (un)mount USB device: %s" % self.usb_mass_device)
-        self.set_namespace_data(action='shared', label='shared', key='connection', value=connection)
+        self.run_cmd(
+            ["umount", self.usb_mass_device],
+            error_msg="Unable to unmount USB device %s" % self.usb_mass_device,
+        )
+
         return connection
