@@ -1,4 +1,4 @@
-# Copyright (C) 2015 Linaro Limited
+# Copyright (C) 2015-2019 Linaro Limited
 #
 # Author: Stevan Radakovic <stevan.radakovic@linaro.org>
 #
@@ -36,17 +36,20 @@ class ExportDeviceEnvironment(Action):
 
     def validate(self):
         super().validate()
-        shell_file = self.get_namespace_data(action='deploy-device-env',
-                                             label='environment', key='shell_file')
-        environment = self.get_namespace_data(action='deploy-device-env',
-                                              label='environment', key='env_dict')
+        shell_file = self.get_namespace_data(
+            action="deploy-device-env", label="environment", key="shell_file"
+        )
+        environment = self.get_namespace_data(
+            action="deploy-device-env", label="environment", key="env_dict"
+        )
         if not environment:
             return
         # Append export commands to the shell init file.
         # Retain quotes into the final shell.
         for key in environment:
-            self.env.append("echo export %s=\\'%s\\' >> %s" % (
-                key, environment[key], shell_file))
+            self.env.append(
+                "echo export %s=\\'%s\\' >> %s" % (key, environment[key], shell_file)
+            )
 
     def run(self, connection, max_end_time):
 
@@ -56,15 +59,15 @@ class ExportDeviceEnvironment(Action):
         connection = super().run(connection, max_end_time)
 
         shell_file = self.get_namespace_data(
-            action='deploy-device-env',
-            label='environment',
-            key='shell_file'
+            action="deploy-device-env", label="environment", key="shell_file"
         )
 
         for line in self.env:
             connection.sendline(line, delay=self.character_delay)
+            connection.wait()
 
         if shell_file:
-            connection.sendline('. %s' % shell_file, delay=self.character_delay)
+            connection.sendline(". %s" % shell_file, delay=self.character_delay)
+            connection.wait()
 
         return connection
