@@ -18,14 +18,8 @@
 # along
 # with this program; if not, see <http://www.gnu.org/licenses>.
 
-from lava_dispatcher.action import (
-    Pipeline,
-)
-from lava_dispatcher.actions.boot import (
-    AutoLoginAction,
-    BootAction,
-    OverlayUnpack,
-)
+from lava_dispatcher.action import Pipeline
+from lava_dispatcher.actions.boot import AutoLoginAction, BootAction, OverlayUnpack
 from lava_dispatcher.actions.boot.environment import ExportDeviceEnvironment
 from lava_dispatcher.logical import Boot
 from lava_dispatcher.power import ResetDevice
@@ -46,36 +40,32 @@ class Minimal(Boot):
 
     @classmethod
     def accepts(cls, device, parameters):
-        if 'minimal' not in device['actions']['boot']['methods']:
+        if "minimal" not in device["actions"]["boot"]["methods"]:
             return False, '"minimal" was not in device configuration boot methods'
-        if 'method' not in parameters:
+        if "method" not in parameters:
             return False, '"method" was not in parameters'
-        if parameters['method'] != 'minimal':
+        if parameters["method"] != "minimal":
             return False, '"method" was not "minimal"'
-        return True, 'accepted'
+        return True, "accepted"
 
 
 class MinimalBoot(BootAction):
 
-    name = 'minimal-boot'
+    name = "minimal-boot"
     description = "connect and reset device"
     summary = "connect and reset device"
 
     def populate(self, parameters):
-        self.internal_pipeline = Pipeline(parent=self, job=self.job, parameters=parameters)
+        self.internal_pipeline = Pipeline(
+            parent=self, job=self.job, parameters=parameters
+        )
         self.internal_pipeline.add_action(ConnectDevice())
-        self.internal_pipeline.add_action(ResetDevice())
+        if parameters.get("reset", True):
+            self.internal_pipeline.add_action(ResetDevice())
         if self.has_prompts(parameters):
             self.internal_pipeline.add_action(AutoLoginAction())
             if self.test_has_shell(parameters):
                 self.internal_pipeline.add_action(ExpectShellSession())
-                if 'transfer_overlay' in parameters:
+                if "transfer_overlay" in parameters:
                     self.internal_pipeline.add_action(OverlayUnpack())
                 self.internal_pipeline.add_action(ExportDeviceEnvironment())
-
-    def run(self, connection, max_end_time):
-        connection = self.get_namespace_data(
-            action='shared', label='shared', key='connection', deepcopy=False)
-        connection = super().run(connection, max_end_time)
-        self.set_namespace_data(action='shared', label='shared', key='connection', value=connection)
-        return connection
