@@ -18,11 +18,8 @@
 # along
 # with this program; if not, see <http://www.gnu.org/licenses>.
 
-from lava_dispatcher.action import (
-    Pipeline,
-    Action,
-    JobError,
-)
+from lava_common.utils import binary_version
+from lava_dispatcher.action import Pipeline, Action, JobError
 from lava_dispatcher.logical import Boot, RetryAction
 from lava_dispatcher.actions.boot import BootAction
 from lava_dispatcher.connections.serial import ConnectDevice
@@ -45,39 +42,45 @@ class PyOCD(Boot):
 
     @classmethod
     def accepts(cls, device, parameters):
-        if 'pyocd' not in device['actions']['boot']['methods']:
+        if "pyocd" not in device["actions"]["boot"]["methods"]:
             return False, '"pyocd" was not in the device configuration boot methods'
-        if 'method' not in parameters:
+        if "method" not in parameters:
             return False, '"method" was not in parameters'
-        if parameters['method'] != 'pyocd':
+        if parameters["method"] != "pyocd":
             return False, '"method" was not "pyocd"'
-        if 'board_id' not in device:
+        if "board_id" not in device:
             return False, '"board_id" is not in the device configuration'
-        return True, 'accepted'
+        return True, "accepted"
 
 
 class BootPyOCD(BootAction):
 
-    name = 'boot-pyocd-image'
+    name = "boot-pyocd-image"
     description = "boot pyocd image with retry"
     summary = "boot pyocd image with retry"
 
     def populate(self, parameters):
-        self.internal_pipeline = Pipeline(parent=self, job=self.job, parameters=parameters)
+        self.internal_pipeline = Pipeline(
+            parent=self, job=self.job, parameters=parameters
+        )
         self.internal_pipeline.add_action(BootPyOCDRetry())
 
 
 class BootPyOCDRetry(RetryAction):
 
-    name = 'boot-pyocd-image'
+    name = "boot-pyocd-image"
     description = "boot pyocd image using the command line interface"
     summary = "boot pyocd image"
 
     def populate(self, parameters):
-        self.internal_pipeline = Pipeline(parent=self, job=self.job, parameters=parameters)
+        self.internal_pipeline = Pipeline(
+            parent=self, job=self.job, parameters=parameters
+        )
         if self.job.device.hard_reset_command:
             self.internal_pipeline.add_action(ResetDevice())
-            self.internal_pipeline.add_action(WaitDeviceBoardID(self.job.device.get('board_id')))
+            self.internal_pipeline.add_action(
+                WaitDeviceBoardID(self.job.device.get("board_id"))
+            )
         self.internal_pipeline.add_action(FlashPyOCDAction())
         self.internal_pipeline.add_action(ConnectDevice())
 
@@ -95,19 +98,24 @@ class FlashPyOCDAction(Action):
 
     def validate(self):
         super().validate()
-        boot = self.job.device['actions']['boot']['methods']['pyocd']
-        pyocd_binary = boot['parameters']['command']
-        which(pyocd_binary)
+        boot = self.job.device["actions"]["boot"]["methods"]["pyocd"]
+        pyocd_binary = boot["parameters"]["command"]
+        binary = which(pyocd_binary)
+        self.logger.info(binary_version(binary, "--version"))
         self.base_command = [pyocd_binary]
-        self.base_command.extend(boot['parameters'].get('options', []))
-        if self.job.device['board_id'] == '0000000000':
+        self.base_command.extend(boot["parameters"].get("options", []))
+        if self.job.device["board_id"] == "0000000000":
             self.errors = "[PYOCD] board_id unset"
         substitutions = {}
-        self.base_command.extend(['--board', self.job.device['board_id']])
-        for action in self.get_namespace_keys('download-action'):
+        self.base_command.extend(["--board", self.job.device["board_id"]])
+        for action in self.get_namespace_keys("download-action"):
             pyocd_full_command = []
-            image_arg = self.get_namespace_data(action='download-action', label=action, key='image_arg')
-            action_arg = self.get_namespace_data(action='download-action', label=action, key='file')
+            image_arg = self.get_namespace_data(
+                action="download-action", label=action, key="image_arg"
+            )
+            action_arg = self.get_namespace_data(
+                action="download-action", label=action, key="file"
+            )
             if image_arg:
                 if not isinstance(image_arg, str):
                     self.errors = "image_arg is not a string (try quoting it)"
@@ -120,17 +128,14 @@ class FlashPyOCDAction(Action):
                 pyocd_full_command.extend(self.base_command)
                 pyocd_full_command.extend([action_arg])
                 self.exec_list.append(pyocd_full_command)
-        if len(self.exec_list) < 1:
+        if not self.exec_list:
             self.errors = "No PyOCD command to execute"
 
     def run(self, connection, max_end_time):
-        connection = self.get_namespace_data(
-            action='shared', label='shared', key='connection', deepcopy=False)
         connection = super().run(connection, max_end_time)
         for pyocd_command in self.exec_list:
-            pyocd = ' '.join(pyocd_command)
+            pyocd = " ".join(pyocd_command)
             self.logger.info("PyOCD command: %s", pyocd)
-            if not self.run_command(pyocd.split(' ')):
-                raise JobError("%s command failed" % (pyocd.split(' ')))
-        self.set_namespace_data(action='shared', label='shared', key='connection', value=connection)
+            if not self.run_command(pyocd.split(" ")):
+                raise JobError("%s command failed" % (pyocd.split(" ")))
         return connection
