@@ -23,7 +23,7 @@
 
 # pylint: disable=unused-import
 
-from lava_dispatcher.actions.boot import SecondaryShell
+from lava_dispatcher.actions.boot.bootloader import BootBootloader
 from lava_dispatcher.actions.boot.cmsis_dap import CMSIS
 from lava_dispatcher.actions.boot.depthcharge import Depthcharge
 from lava_dispatcher.actions.boot.dfu import DFU
@@ -36,10 +36,14 @@ from lava_dispatcher.actions.boot.ipxe import IPXE
 from lava_dispatcher.actions.boot.kexec import BootKExec
 from lava_dispatcher.actions.boot.lxc import BootLxc
 from lava_dispatcher.actions.boot.minimal import Minimal
+from lava_dispatcher.actions.boot.openocd import OpenOCD
 from lava_dispatcher.actions.boot.pyocd import PyOCD
+from lava_dispatcher.actions.boot.jlink import JLink
 from lava_dispatcher.actions.boot.qemu import BootQEMU
+from lava_dispatcher.actions.boot.secondary import SecondaryShell
 from lava_dispatcher.actions.boot.ssh import SshLogin, Schroot
 from lava_dispatcher.actions.boot.u_boot import UBoot
+from lava_dispatcher.actions.boot.barebox import Barebox
 from lava_dispatcher.actions.boot.uefi import UefiShell
 from lava_dispatcher.actions.boot.uefi_menu import UefiMenu
 from lava_dispatcher.actions.boot.recovery import RecoveryBoot
