@@ -21,7 +21,7 @@
 import re
 import subprocess  # nosec - internal
 
-from lava_common.exceptions import InfrastructureError, JobError
+from lava_common.exceptions import InfrastructureError
 from lava_dispatcher.action import Pipeline
 from lava_dispatcher.actions.deploy import DeployAction
 from lava_dispatcher.actions.deploy.environment import DeployDeviceEnvironment
@@ -42,10 +42,14 @@ class DockerAction(DeployAction):
 
         # Print docker version
         try:
-            out = subprocess.check_output(["docker", "version", "-f", "{{.Server.Version}}"])  # nosec - internal
+            out = subprocess.check_output(  # nosec - internal
+                ["docker", "version", "-f", "{{.Server.Version}}"]
+            )
             out = out.decode("utf-8", errors="replace").strip("\n")
             self.logger.debug("docker server, installed at version: %s", out)
-            out = subprocess.check_output(["docker", "version", "-f", "{{.Client.Version}}"])  # nosec - internal
+            out = subprocess.check_output(  # nosec - internal
+                ["docker", "version", "-f", "{{.Client.Version}}"]
+            )
             out = out.decode("utf-8", errors="replace").strip("\n")
             self.logger.debug("docker client, installed at version: %s", out)
         except subprocess.CalledProcessError as exc:
@@ -64,13 +68,21 @@ class DockerAction(DeployAction):
 
         # check docker image name
         # The string should be safe for command line inclusion
-        if re.compile("^[a-z0-9._:/-]+$").match(self.image_name) is None:
+        if (
+            re.compile(
+                "^[a-z0-9]+[a-z0-9._/-]*[a-z0-9]+(:[a-zA-Z0-9_]+[a-zA-Z0-9._-]*)?$"
+            ).match(self.image_name)
+            is None
+        ):
             self.errors = "image name '%s' is invalid" % self.image_name
-        self.set_namespace_data(action=self.name, label='image',
-                                key='name', value=self.image_name)
+        self.set_namespace_data(
+            action=self.name, label="image", key="name", value=self.image_name
+        )
 
     def populate(self, parameters):
-        self.internal_pipeline = Pipeline(parent=self, job=self.job, parameters=parameters)
+        self.internal_pipeline = Pipeline(
+            parent=self, job=self.job, parameters=parameters
+        )
         if self.test_needs_deployment(parameters):
             self.internal_pipeline.add_action(DeployDeviceEnvironment())
         if self.test_needs_overlay(parameters):
@@ -79,20 +91,28 @@ class DockerAction(DeployAction):
     def run(self, connection, max_end_time):
         # Pull the image
         if self.local:
-            cmd = ["docker", "image", "inspect", "--format", "image exists",
-                   self.image_name]
+            cmd = [
+                "docker",
+                "image",
+                "inspect",
+                "--format",
+                "image exists",
+                self.image_name,
+            ]
             error_msg = "Unable to inspect docker image '%s'" % self.image_name
             self.run_cmd(cmd, error_msg=error_msg)
         else:
-            self.run_cmd(["docker", "pull", self.image_name],
-                         error_msg="Unable to pull docker image '%s'" % self.image_name)
+            self.run_cmd(
+                ["docker", "pull", self.image_name],
+                error_msg="Unable to pull docker image '%s'" % self.image_name,
+            )
 
         return super().run(connection, max_end_time)
 
 
 class Docker(Deployment):
     compatibility = 4
-    name = 'docker'
+    name = "docker"
 
     def __init__(self, parent, parameters):
         super().__init__(parent)
@@ -103,10 +123,10 @@ class Docker(Deployment):
 
     @classmethod
     def accepts(cls, device, parameters):
-        if 'docker' not in device['actions']['deploy']['methods']:
+        if "docker" not in device["actions"]["deploy"]["methods"]:
             return False, "'docker' not in the device configuration deploy methods"
-        if parameters['to'] != 'docker':
+        if parameters["to"] != "docker":
             return False, '"to" parameter is not "docker"'
-        if 'image' not in parameters:
+        if "image" not in parameters:
             return False, '"image" is not in the deployment parameters'
-        return True, 'accepted'
+        return True, "accepted"
