@@ -27,10 +27,12 @@ from lava_dispatcher.actions.deploy.download import (
     DownloaderAction,
     QCowConversionAction,
 )
-from lava_dispatcher.actions.deploy.apply_overlay import ApplyOverlayGuest
+from lava_dispatcher.actions.deploy.apply_overlay import (
+    ApplyOverlayGuest,
+    ApplyOverlayTftp,
+)
 from lava_dispatcher.actions.deploy.environment import DeployDeviceEnvironment
 from lava_dispatcher.actions.deploy.overlay import OverlayAction
-from lava_dispatcher.actions.deploy.apply_overlay import ApplyOverlayTftp
 from lava_dispatcher.utils.compression import untar_file
 
 # pylint: disable=too-many-instance-attributes
@@ -38,26 +40,35 @@ from lava_dispatcher.utils.compression import untar_file
 
 class DeployImagesAction(DeployAction):  # FIXME: Rename to DeployPosixImages
 
-    name = 'deployimages'
+    name = "deployimages"
     description = "deploy images using guestfs"
     summary = "deploy images"
 
     def populate(self, parameters):
-        self.internal_pipeline = Pipeline(parent=self, job=self.job, parameters=parameters)
+        self.internal_pipeline = Pipeline(
+            parent=self, job=self.job, parameters=parameters
+        )
         path = self.mkdtemp()
-        if 'uefi' in parameters:
+        if "uefi" in parameters:
             uefi_path = self.mkdtemp()
-            self.internal_pipeline.add_action(DownloaderAction('uefi', uefi_path))
+            self.internal_pipeline.add_action(DownloaderAction("uefi", uefi_path))
             # uefi option of QEMU needs a directory, not the filename
-            self.set_namespace_data(action=self.name, label='image', key='uefi_dir', value=uefi_path, parameters=parameters)
+            self.set_namespace_data(
+                action=self.name,
+                label="image",
+                key="uefi_dir",
+                value=uefi_path,
+                parameters=parameters,
+            )
             # alternatively use the -bios option and standard image args
-        for image in parameters['images'].keys():
-            if image != 'yaml_line':
-                self.internal_pipeline.add_action(DownloaderAction(image, path))
-                if parameters['images'][image].get('format', '') == 'qcow2':
-                    self.internal_pipeline.add_action(QCowConversionAction(image))
+        for image in parameters["images"].keys():
+            self.internal_pipeline.add_action(DownloaderAction(image, path))
+            if parameters["images"][image].get("format", "") == "qcow2":
+                self.internal_pipeline.add_action(QCowConversionAction(image))
         if self.test_needs_overlay(parameters):
-            self.internal_pipeline.add_action(OverlayAction())  # idempotent, includes testdef
+            self.internal_pipeline.add_action(
+                OverlayAction()
+            )  # idempotent, includes testdef
             self.internal_pipeline.add_action(ApplyOverlayGuest())
         if self.test_needs_deployment(parameters):
             self.internal_pipeline.add_action(DeployDeviceEnvironment())
@@ -68,8 +79,9 @@ class DeployQemuNfs(Deployment):
     Strategy class for a kernel & NFS QEMU deployment.
     Does not use GuestFS, adds overlay to the NFS
     """
+
     compatibility = 5
-    name = 'qemu-nfs'
+    name = "qemu-nfs"
 
     def __init__(self, parent, parameters):
         super().__init__(parent)
@@ -86,38 +98,45 @@ class DeployQemuNfs(Deployment):
         This is *not* the same as validation of the action
         which can use instance data.
         """
-        if 'nfs' not in device['actions']['deploy']['methods']:
+        if "nfs" not in device["actions"]["deploy"]["methods"]:
             return False, '"nfs" is not in the device configuration deploy methods'
-        if parameters['to'] != 'nfs':
+        if parameters["to"] != "nfs":
             return False, '"to" is not "nfs"'
-        if 'qemu-nfs' not in device['actions']['boot']['methods']:
+        if "qemu-nfs" not in device["actions"]["boot"]["methods"]:
             return False, '"qemu-nfs" is not in the device configuration boot methods'
-        if 'type' in parameters:
-            if parameters['type'] != 'monitor':
+        if "type" in parameters:
+            if parameters["type"] != "monitor":
                 return False, '"type" was set, but it was not "monitor"'
-        return True, 'accepted'
+        return True, "accepted"
 
 
 class DeployQemuNfsAction(DeployAction):
 
-    name = 'deploy-qemu-nfs'
+    name = "deploy-qemu-nfs"
     description = "deploy qemu with NFS"
     summary = "deploy NFS for QEMU"
 
     def populate(self, parameters):
-        self.internal_pipeline = Pipeline(parent=self, job=self.job, parameters=parameters)
+        self.internal_pipeline = Pipeline(
+            parent=self, job=self.job, parameters=parameters
+        )
         path = self.mkdtemp()
-        if 'uefi' in parameters:
+        if "uefi" in parameters:
             uefi_path = self.mkdtemp()
-            self.internal_pipeline.add_action(DownloaderAction('uefi', uefi_path))
+            self.internal_pipeline.add_action(DownloaderAction("uefi", uefi_path))
             # uefi option of QEMU needs a directory, not the filename
-            self.set_namespace_data(action=self.name, label='image', key='uefi_dir', value=uefi_path, parameters=parameters)
+            self.set_namespace_data(
+                action=self.name,
+                label="image",
+                key="uefi_dir",
+                value=uefi_path,
+                parameters=parameters,
+            )
             # alternatively use the -bios option and standard image args
-        for image in parameters['images'].keys():
-            if image != 'yaml_line':
-                self.internal_pipeline.add_action(DownloaderAction(image, path))
-                if parameters['images'][image].get('format', '') == 'qcow2':
-                    self.internal_pipeline.add_action(QCowConversionAction(image))
+        for image in parameters["images"].keys():
+            self.internal_pipeline.add_action(DownloaderAction(image, path))
+            if parameters["images"][image].get("format", "") == "qcow2":
+                self.internal_pipeline.add_action(QCowConversionAction(image))
         self.internal_pipeline.add_action(ExtractNfsAction())
         self.internal_pipeline.add_action(OverlayAction())
         self.internal_pipeline.add_action(ApplyOverlayTftp())
@@ -132,9 +151,9 @@ class ExtractNfsAction(Action):
 
     def __init__(self):
         super().__init__()
-        self.param_key = 'nfsrootfs'
+        self.param_key = "nfsrootfs"
         self.file_key = "nfsroot"
-        self.extra_compression = ['xz']
+        self.extra_compression = ["xz"]
         self.use_tarfile = True
         self.use_lzma = False
 
@@ -142,45 +161,53 @@ class ExtractNfsAction(Action):
         super().validate()
         if not self.valid:
             return
-        if not self.parameters['images'].get(self.param_key):  # idempotency
+        if not self.parameters["images"].get(self.param_key):  # idempotency
             return
         if not self.get_namespace_data(
-                action='download-action', label=self.param_key, key='file'):
+            action="download-action", label=self.param_key, key="file"
+        ):
             self.errors = "no file specified extract as %s" % self.param_key
-        if not os.path.exists('/usr/sbin/exportfs'):
-            raise InfrastructureError("NFS job requested but nfs-kernel-server not installed.")
-        if 'prefix' in self.parameters['images'][self.param_key]:
-            prefix = self.parameters['images'][self.param_key]['prefix']
-            if prefix.startswith('/'):
-                self.errors = 'prefix must not be an absolute path'
-            if not prefix.endswith('/'):
-                self.errors = 'prefix must be a directory and end with /'
+        if not os.path.exists("/usr/sbin/exportfs"):
+            raise InfrastructureError(
+                "NFS job requested but nfs-kernel-server not installed."
+            )
+        if "prefix" in self.parameters["images"][self.param_key]:
+            prefix = self.parameters["images"][self.param_key]["prefix"]
+            if prefix.startswith("/"):
+                self.errors = "prefix must not be an absolute path"
+            if not prefix.endswith("/"):
+                self.errors = "prefix must be a directory and end with /"
 
     def run(self, connection, max_end_time):
-        if not self.parameters['images'].get(self.param_key):  # idempotency
+        if not self.parameters["images"].get(self.param_key):  # idempotency
             return connection
         connection = super().run(connection, max_end_time)
-        root = self.get_namespace_data(action='download-action', label=self.param_key, key='file')
+        root = self.get_namespace_data(
+            action="download-action", label=self.param_key, key="file"
+        )
         root_dir = self.mkdtemp()
         untar_file(root, root_dir)
-        self.set_namespace_data(action='extract-rootfs', label='file', key=self.file_key, value=root_dir)
+        self.set_namespace_data(
+            action="extract-rootfs", label="file", key=self.file_key, value=root_dir
+        )
         self.logger.debug("Extracted %s to %s", self.file_key, root_dir)
 
-        if 'prefix' in self.parameters['images'][self.param_key]:
-            prefix = self.parameters['images'][self.param_key]['prefix']
-            self.logger.warning("Adding '%s' prefix, any other content will not be visible.",
-                                prefix)
+        if "prefix" in self.parameters["images"][self.param_key]:
+            prefix = self.parameters["images"][self.param_key]["prefix"]
+            self.logger.warning(
+                "Adding '%s' prefix, any other content will not be visible.", prefix
+            )
 
             # Grab the path already defined in super().run() and add the prefix
             root_dir = self.get_namespace_data(
-                action='extract-rootfs',
-                label='file',
-                key=self.file_key
+                action="extract-rootfs", label="file", key=self.file_key
             )
             root_dir = os.path.join(root_dir, prefix)
             # sets the directory into which the overlay is unpacked and which
             # is used in the substitutions into the bootloader command string.
-            self.set_namespace_data(action='extract-rootfs', label='file', key=self.file_key, value=root_dir)
+            self.set_namespace_data(
+                action="extract-rootfs", label="file", key=self.file_key, value=root_dir
+            )
         return connection
 
 
@@ -200,8 +227,9 @@ class DeployImages(Deployment):
         customisation-action
         test-definitions-action
     """
+
     compatibility = 4
-    name = 'images'
+    name = "images"
 
     def __init__(self, parent, parameters):
         super().__init__(parent)
@@ -218,14 +246,14 @@ class DeployImages(Deployment):
         This is *not* the same as validation of the action
         which can use instance data.
         """
-        if 'image' not in device['actions']['deploy']['methods']:
+        if "image" not in device["actions"]["deploy"]["methods"]:
             return False, '"image" is not in the device configuration deploy methods'
-        if parameters['to'] != 'tmpfs':
+        if parameters["to"] != "tmpfs":
             return False, '"to" parameter is not "tmpfs"'
         # lookup if the job parameters match the available device methods
-        if 'images' not in parameters:
+        if "images" not in parameters:
             return False, '"images" was not in the deployment parameters'
-        if 'type' in parameters:
-            if parameters['type'] != 'monitor':
+        if "type" in parameters:
+            if parameters["type"] != "monitor":
                 return False, '"type" parameter was set but it was not "monitor"'
-        return True, 'accepted'
+        return True, "accepted"
