@@ -26,10 +26,7 @@ import tarfile
 from lava_dispatcher.actions.deploy import DeployAction
 from lava_dispatcher.action import Action, Pipeline
 from lava_common.exceptions import InfrastructureError, LAVABug
-from lava_dispatcher.actions.deploy.testdef import (
-    TestDefinitionAction,
-    get_test_action_namespaces,
-)
+from lava_dispatcher.actions.deploy.testdef import TestDefinitionAction
 from lava_dispatcher.logical import Deployment
 from lava_dispatcher.utils.contextmanager import chdir
 from lava_dispatcher.utils.filesystem import check_ssh_identity_file
@@ -52,11 +49,11 @@ class Overlay(Deployment):
 
     @classmethod
     def accepts(cls, device, parameters):
-        if 'overlay' not in device['actions']['deploy']['methods']:
+        if "overlay" not in device["actions"]["deploy"]["methods"]:
             return False, "'overlay' not in the device configuration deploy methods"
-        if parameters['to'] != 'overlay':
+        if parameters["to"] != "overlay":
             return False, '"to" parameter is not "overlay"'
-        return True, 'accepted'
+        return True, "accepted"
 
 
 # pylint: disable=too-many-instance-attributes
@@ -88,53 +85,76 @@ class OverlayAction(DeployAction):
     def __init__(self):
         super().__init__()
         self.lava_test_dir = os.path.realpath(
-            '%s/../../lava_test_shell' % os.path.dirname(__file__))
+            "%s/../../lava_test_shell" % os.path.dirname(__file__)
+        )
         self.scripts_to_copy = []
         # 755 file permissions
-        self.xmod = stat.S_IRWXU | stat.S_IXGRP | stat.S_IRGRP | stat.S_IXOTH | stat.S_IROTH
-        self.target_mac = ''
-        self.target_ip = ''
-        self.probe_ip = ''
-        self.probe_channel = ''
+        self.xmod = (
+            stat.S_IRWXU | stat.S_IXGRP | stat.S_IRGRP | stat.S_IXOTH | stat.S_IROTH
+        )
+        self.target_mac = ""
+        self.target_ip = ""
+        self.probe_ip = ""
+        self.probe_channel = ""
 
     def validate(self):
         super().validate()
-        self.scripts_to_copy = sorted(glob.glob(os.path.join(self.lava_test_dir, 'lava-*')))
+        self.scripts_to_copy = sorted(
+            glob.glob(os.path.join(self.lava_test_dir, "lava-*"))
+        )
         # Distro-specific scripts override the generic ones
         if not self.test_needs_overlay(self.parameters):
             return
-        lava_test_results_dir = self.get_constant('lava_test_results_dir', 'posix')
+        lava_test_results_dir = self.get_constant("lava_test_results_dir", "posix")
         lava_test_results_dir = lava_test_results_dir % self.job.job_id
-        self.set_namespace_data(action='test', label='results', key='lava_test_results_dir',
-                                value=lava_test_results_dir)
-        lava_test_sh_cmd = self.get_constant('lava_test_sh_cmd', 'posix')
-        self.set_namespace_data(action='test', label='shared', key='lava_test_sh_cmd',
-                                value=lava_test_sh_cmd)
+        self.set_namespace_data(
+            action="test",
+            label="results",
+            key="lava_test_results_dir",
+            value=lava_test_results_dir,
+        )
+        lava_test_sh_cmd = self.get_constant("lava_test_sh_cmd", "posix")
+        self.set_namespace_data(
+            action="test",
+            label="shared",
+            key="lava_test_sh_cmd",
+            value=lava_test_sh_cmd,
+        )
 
         # Add distro support scripts - only if deployment_data is set
-        distro = self.parameters['deployment_data'].get('distro')
+        distro = self.parameters["deployment_data"].get("distro")
         if distro:
-            distro_support_dir = '%s/distro/%s' % (self.lava_test_dir, distro)
-            self.scripts_to_copy += sorted(glob.glob(os.path.join(distro_support_dir,
-                                                                  'lava-*')))
+            distro_support_dir = "%s/distro/%s" % (self.lava_test_dir, distro)
+            self.scripts_to_copy += sorted(
+                glob.glob(os.path.join(distro_support_dir, "lava-*"))
+            )
 
         if not self.scripts_to_copy:
             self.logger.debug("Skipping lava_test_shell support scripts.")
-        if 'parameters' in self.job.device:
-            if 'interfaces' in self.job.device['parameters']:
-                if 'target' in self.job.device['parameters']['interfaces']:
-                    self.target_mac = self.job.device['parameters']['interfaces']['target'].get('mac', '')
-                    self.target_ip = self.job.device['parameters']['interfaces']['target'].get('ip', '')
-        for device in self.job.device.get('static_info', []):
-            if 'probe_channel' in device and 'probe_ip' in device:
-                self.probe_channel = device['probe_channel']
-                self.probe_ip = device['probe_ip']
+        if "parameters" in self.job.device:
+            if "interfaces" in self.job.device["parameters"]:
+                if "target" in self.job.device["parameters"]["interfaces"]:
+                    self.target_mac = self.job.device["parameters"]["interfaces"][
+                        "target"
+                    ].get("mac", "")
+                    self.target_ip = self.job.device["parameters"]["interfaces"][
+                        "target"
+                    ].get("ip", "")
+        for device in self.job.device.get("static_info", []):
+            if "probe_channel" in device and "probe_ip" in device:
+                self.probe_channel = device["probe_channel"]
+                self.probe_ip = device["probe_ip"]
                 break
 
     def populate(self, parameters):
-        self.internal_pipeline = Pipeline(parent=self, job=self.job, parameters=parameters)
+        self.internal_pipeline = Pipeline(
+            parent=self, job=self.job, parameters=parameters
+        )
         if self.test_needs_overlay(parameters):
-            if any('ssh' in data for data in self.job.device['actions']['deploy']['methods']):
+            if any(
+                "ssh" in data
+                for data in self.job.device["actions"]["deploy"]["methods"]
+            ):
                 # only devices supporting ssh deployments add this action.
                 self.internal_pipeline.add_action(SshAuthorize())
             self.internal_pipeline.add_action(VlandOverlayAction())
@@ -143,69 +163,109 @@ class OverlayAction(DeployAction):
             self.internal_pipeline.add_action(CompressOverlay())
             self.internal_pipeline.add_action(PersistentNFSOverlay())  # idempotent
 
+    def _export_data(self, fout, data, prefix):
+        if isinstance(data, dict):
+            if prefix:
+                prefix += "_"
+            for key, value in data.items():
+                self._export_data(fout, value, "%s%s" % (prefix, key))
+        elif isinstance(data, (list, tuple)):
+            if prefix:
+                prefix += "_"
+            for index, value in enumerate(data):
+                self._export_data(fout, value, "%s%s" % (prefix, index))
+        else:
+            if isinstance(data, bool):
+                data = "1" if data else "0"
+            elif isinstance(data, int):
+                data = data
+            else:
+                data = "'%s'" % data
+            self.logger.debug("- %s=%s", prefix, data)
+            fout.write("export %s=%s\n" % (prefix, data))
+
     def run(self, connection, max_end_time):  # pylint: disable=too-many-locals
         """
         Check if a lava-test-shell has been requested, implement the overlay
         * create test runner directories beneath the temporary location
         * copy runners into test runner directories
         """
+        namespace = self.parameters.get("namespace")
+        if not self.test_needs_overlay(self.parameters):
+            self.logger.info("[%s] skipped %s - no test action.", namespace, self.name)
+            return connection
+
         tmp_dir = self.mkdtemp()
-        namespace = self.parameters.get('namespace')
-        if namespace:
-            if namespace not in get_test_action_namespaces(self.job.parameters):
-                self.logger.info("[%s] skipped %s - no test action.", namespace, self.name)
-                return connection
-        self.set_namespace_data(action='test', label='shared', key='location', value=tmp_dir)
-        lava_test_results_dir = self.get_namespace_data(action='test', label='results', key='lava_test_results_dir')
+        self.set_namespace_data(
+            action="test", label="shared", key="location", value=tmp_dir
+        )
+        lava_test_results_dir = self.get_namespace_data(
+            action="test", label="results", key="lava_test_results_dir"
+        )
         if not lava_test_results_dir:
             raise LAVABug("Unable to identify top level lava test directory")
-        shell = self.get_namespace_data(action='test', label='shared', key='lava_test_sh_cmd')
+        shell = self.get_namespace_data(
+            action="test", label="shared", key="lava_test_sh_cmd"
+        )
         self.logger.debug("[%s] Preparing overlay tarball in %s", namespace, tmp_dir)
         lava_path = os.path.abspath("%s/%s" % (tmp_dir, lava_test_results_dir))
-        for runner_dir in ['bin', 'tests', 'results']:
+        for runner_dir in ["bin", "tests", "results"]:
             # avoid os.path.join as lava_test_results_dir startswith / so location is *dropped* by join.
             path = os.path.abspath("%s/%s" % (lava_path, runner_dir))
             if not os.path.exists(path):
                 os.makedirs(path, 0o755)
                 self.logger.debug("makedir: %s", path)
         for fname in self.scripts_to_copy:
-            with open(fname, 'r') as fin:
+            with open(fname, "r") as fin:
                 foutname = os.path.basename(fname)
-                output_file = '%s/bin/%s' % (lava_path, foutname)
+                output_file = "%s/bin/%s" % (lava_path, foutname)
                 if "distro" in fname:
                     distribution = os.path.basename(os.path.dirname(fname))
                     self.logger.debug("Updating %s (%s)", output_file, distribution)
                 else:
                     self.logger.debug("Creating %s", output_file)
-                with open(output_file, 'w') as fout:
+                with open(output_file, "w") as fout:
                     fout.write("#!%s\n\n" % shell)
-                    if foutname == 'lava-target-mac':
+                    if foutname == "lava-target-mac":
                         fout.write("TARGET_DEVICE_MAC='%s'\n" % self.target_mac)
-                    if foutname == 'lava-target-ip':
+                    if foutname == "lava-target-ip":
                         fout.write("TARGET_DEVICE_IP='%s'\n" % self.target_ip)
-                    if foutname == 'lava-probe-ip':
+                    if foutname == "lava-probe-ip":
                         fout.write("PROBE_DEVICE_IP='%s'\n" % self.probe_ip)
-                    if foutname == 'lava-probe-channel':
+                    if foutname == "lava-probe-channel":
                         fout.write("PROBE_DEVICE_CHANNEL='%s'\n" % self.probe_channel)
-                    if foutname == 'lava-target-storage':
+                    if foutname == "lava-target-storage":
                         fout.write('LAVA_STORAGE="\n')
-                        for method in self.job.device.get('storage_info', [{}]):
+                        for method in self.job.device.get("storage_info", [{}]):
                             for key, value in method.items():
-                                if key == 'yaml_line':
-                                    continue
-                                self.logger.debug("storage methods:\t%s\t%s", key, value)
+                                self.logger.debug(
+                                    "storage methods:\t%s\t%s", key, value
+                                )
                                 fout.write(r"\t%s\t%s\n" % (key, value))
                         fout.write('"\n')
                     fout.write(fin.read())
                     os.fchmod(fout.fileno(), self.xmod)
 
+        # Generate environment file
+        self.logger.debug("Creating %s/environment", lava_path)
+        with open(os.path.join(lava_path, "environment"), "w") as fout:
+            sources = [
+                ("environment", ""),
+                ("device_info", "LAVA_DEVICE_INFO"),
+                ("static_info", "LAVA_STATIC_INFO"),
+                ("storage_info", "LAVA_STORAGE_INFO"),
+            ]
+            for source, prefix in sources:
+                data = self.job.device.get(source, {})
+                if data:
+                    self.logger.debug("%s:", source)
+                    self._export_data(fout, data, prefix)
+
         # Generate the file containing the secrets
-        if 'secrets' in self.job.parameters:
+        if "secrets" in self.job.parameters:
             self.logger.debug("Creating %s/secrets", lava_path)
-            with open(os.path.join(lava_path, 'secrets'), 'w') as fout:
-                for key, value in self.job.parameters['secrets'].items():
-                    if key == 'yaml_line':
-                        continue
+            with open(os.path.join(lava_path, "secrets"), "w") as fout:
+                for key, value in self.job.parameters["secrets"].items():
                     fout.write("%s=%s\n" % (key, value))
 
         connection = super().run(connection, max_end_time)
@@ -222,8 +282,11 @@ class MultinodeOverlayAction(OverlayAction):
         super().__init__()
         # Multinode-only
         self.lava_multi_node_test_dir = os.path.realpath(
-            '%s/../../lava_test_shell/multi_node' % os.path.dirname(__file__))
-        self.lava_multi_node_cache_file = '/tmp/lava_multi_node_cache.txt'  # nosec - on the DUT
+            "%s/../../lava_test_shell/multi_node" % os.path.dirname(__file__)
+        )
+        self.lava_multi_node_cache_file = (
+            "/tmp/lava_multi_node_cache.txt"  # nosec - on the DUT
+        )
         self.role = None
         self.protocol = MultinodeProtocol.name
 
@@ -235,24 +298,33 @@ class MultinodeOverlayAction(OverlayAction):
     def validate(self):
         super().validate()
         # idempotency
-        if 'actions' not in self.job.parameters:
+        if "actions" not in self.job.parameters:
             return
-        if 'protocols' in self.job.parameters and \
-                self.protocol in [protocol.name for protocol in self.job.protocols]:
-            if 'target_group' not in self.job.parameters['protocols'][self.protocol]:
+        if "protocols" in self.job.parameters and self.protocol in [
+            protocol.name for protocol in self.job.protocols
+        ]:
+            if "target_group" not in self.job.parameters["protocols"][self.protocol]:
                 return
-            if 'role' not in self.job.parameters['protocols'][self.protocol]:
+            if "role" not in self.job.parameters["protocols"][self.protocol]:
                 self.errors = "multinode job without a specified role"
             else:
-                self.role = self.job.parameters['protocols'][self.protocol]['role']
+                self.role = self.job.parameters["protocols"][self.protocol]["role"]
 
-    def run(self, connection, max_end_time):  # pylint: disable=too-many-locals,too-many-branches,too-many-statements
+    def run(
+        self, connection, max_end_time
+    ):  # pylint: disable=too-many-locals,too-many-branches,too-many-statements
         if self.role is None:
             self.logger.debug("skipped %s", self.name)
             return connection
-        lava_test_results_dir = self.get_namespace_data(action='test', label='results', key='lava_test_results_dir')
-        shell = self.get_namespace_data(action='test', label='shared', key='lava_test_sh_cmd')
-        location = self.get_namespace_data(action='test', label='shared', key='location')
+        lava_test_results_dir = self.get_namespace_data(
+            action="test", label="results", key="lava_test_results_dir"
+        )
+        shell = self.get_namespace_data(
+            action="test", label="shared", key="lava_test_sh_cmd"
+        )
+        location = self.get_namespace_data(
+            action="test", label="shared", key="location"
+        )
         if not location:
             raise LAVABug("Missing lava overlay location")
         if not os.path.exists(location):
@@ -260,40 +332,54 @@ class MultinodeOverlayAction(OverlayAction):
 
         # the roles list can only be populated after the devices have been assigned
         # therefore, cannot be checked in validate which is executed at submission.
-        if 'roles' not in self.job.parameters['protocols'][self.protocol]:
-            raise LAVABug("multinode definition without complete list of roles after assignment")
+        if "roles" not in self.job.parameters["protocols"][self.protocol]:
+            raise LAVABug(
+                "multinode definition without complete list of roles after assignment"
+            )
 
         # Generic scripts
         lava_path = os.path.abspath("%s/%s" % (location, lava_test_results_dir))
-        scripts_to_copy = glob.glob(os.path.join(self.lava_multi_node_test_dir, 'lava-*'))
+        scripts_to_copy = glob.glob(
+            os.path.join(self.lava_multi_node_test_dir, "lava-*")
+        )
         self.logger.debug(self.lava_multi_node_test_dir)
         self.logger.debug("lava_path: %s", lava_path)
         self.logger.debug("scripts to copy %s", scripts_to_copy)
 
         for fname in scripts_to_copy:
-            with open(fname, 'r') as fin:
+            with open(fname, "r") as fin:
                 foutname = os.path.basename(fname)
-                output_file = '%s/bin/%s' % (lava_path, foutname)
+                output_file = "%s/bin/%s" % (lava_path, foutname)
                 self.logger.debug("Creating %s", output_file)
-                with open(output_file, 'w') as fout:
+                with open(output_file, "w") as fout:
                     fout.write("#!%s\n\n" % shell)
                     # Target-specific scripts (add ENV to the generic ones)
-                    if foutname == 'lava-group':
+                    if foutname == "lava-group":
                         fout.write('LAVA_GROUP="\n')
-                        for client_name in self.job.parameters['protocols'][self.protocol]['roles']:
-                            if client_name == 'yaml_line':
-                                continue
-                            role_line = self.job.parameters['protocols'][self.protocol]['roles'][client_name]
-                            self.logger.debug("group roles:\t%s\t%s", client_name, role_line)
+                        for client_name in self.job.parameters["protocols"][
+                            self.protocol
+                        ]["roles"]:
+                            role_line = self.job.parameters["protocols"][self.protocol][
+                                "roles"
+                            ][client_name]
+                            self.logger.debug(
+                                "group roles:\t%s\t%s", client_name, role_line
+                            )
                             fout.write(r"\t%s\t%s\n" % (client_name, role_line))
                         fout.write('"\n')
-                    elif foutname == 'lava-role':
-                        fout.write("TARGET_ROLE='%s'\n" % self.job.parameters['protocols'][self.protocol]['role'])
-                    elif foutname == 'lava-self':
+                    elif foutname == "lava-role":
+                        fout.write(
+                            "TARGET_ROLE='%s'\n"
+                            % self.job.parameters["protocols"][self.protocol]["role"]
+                        )
+                    elif foutname == "lava-self":
                         fout.write("LAVA_HOSTNAME='%s'\n" % self.job.job_id)
                     else:
                         fout.write("LAVA_TEST_BIN='%s/bin'\n" % lava_test_results_dir)
-                        fout.write("LAVA_MULTI_NODE_CACHE='%s'\n" % self.lava_multi_node_cache_file)
+                        fout.write(
+                            "LAVA_MULTI_NODE_CACHE='%s'\n"
+                            % self.lava_multi_node_cache_file
+                        )
                         # always write out full debug logs
                         fout.write("LAVA_MULTI_NODE_DEBUG='yes'\n")
                     fout.write(fin.read())
@@ -315,8 +401,9 @@ class VlandOverlayAction(OverlayAction):
         super().__init__()
         # vland-only
         self.lava_vland_test_dir = os.path.realpath(
-            '%s/../../lava_test_shell/vland' % os.path.dirname(__file__))
-        self.lava_vland_cache_file = '/tmp/lava_vland_cache.txt'  # nosec - on the DUT
+            "%s/../../lava_test_shell/vland" % os.path.dirname(__file__)
+        )
+        self.lava_vland_cache_file = "/tmp/lava_vland_cache.txt"  # nosec - on the DUT
         self.params = {}
         self.sysfs = []
         self.tags = []
@@ -331,39 +418,46 @@ class VlandOverlayAction(OverlayAction):
     def validate(self):
         super().validate()
         # idempotency
-        if 'actions' not in self.job.parameters:
+        if "actions" not in self.job.parameters:
             return
-        if 'protocols' not in self.job.parameters:
+        if "protocols" not in self.job.parameters:
             return
         if self.protocol not in [protocol.name for protocol in self.job.protocols]:
             return
-        if 'parameters' not in self.job.device:
+        if "parameters" not in self.job.device:
             self.errors = "Device lacks parameters"
-        elif 'interfaces' not in self.job.device['parameters']:
+        elif "interfaces" not in self.job.device["parameters"]:
             self.errors = "Device lacks vland interfaces data."
         if not self.valid:
             return
         # same as the parameters of the protocol itself.
-        self.params = self.job.parameters['protocols'][self.protocol]
-        device_params = self.job.device['parameters']['interfaces']
-        vprotocol = [vprotocol for vprotocol in self.job.protocols if vprotocol.name == self.protocol][0]
+        self.params = self.job.parameters["protocols"][self.protocol]
+        device_params = self.job.device["parameters"]["interfaces"]
+        vprotocol = [
+            vprotocol
+            for vprotocol in self.job.protocols
+            if vprotocol.name == self.protocol
+        ][0]
         # needs to be the configured interface for each vlan.
         for key, _ in self.params.items():
-            if key == 'yaml_line' or key not in vprotocol.params:
+            if key not in vprotocol.params:
                 continue
-            self.names.append(",".join([key, vprotocol.params[key]['iface']]))
+            self.names.append(",".join([key, vprotocol.params[key]["iface"]]))
         for interface in device_params:
-            self.sysfs.append(",".join(
-                [
-                    interface,
-                    device_params[interface]['mac'],
-                    device_params[interface]['sysfs'],
-                ]))
+            self.sysfs.append(
+                ",".join(
+                    [
+                        interface,
+                        device_params[interface]["mac"],
+                        device_params[interface]["sysfs"],
+                    ]
+                )
+            )
         for interface in device_params:
-            if not device_params[interface]['tags']:
+            if not device_params[interface]["tags"]:
                 # skip primary interface
                 continue
-            for tag in device_params[interface]['tags']:
+            for tag in device_params[interface]["tags"]:
                 self.tags.append(",".join([interface, tag]))
 
     # pylint: disable=anomalous-backslash-in-string
@@ -381,36 +475,42 @@ class VlandOverlayAction(OverlayAction):
         if not self.params:
             self.logger.debug("skipped %s", self.name)
             return connection
-        location = self.get_namespace_data(action='test', label='shared', key='location')
-        lava_test_results_dir = self.get_namespace_data(action='test', label='results', key='lava_test_results_dir')
-        shell = self.get_namespace_data(action='test', label='shared', key='lava_test_sh_cmd')
+        location = self.get_namespace_data(
+            action="test", label="shared", key="location"
+        )
+        lava_test_results_dir = self.get_namespace_data(
+            action="test", label="results", key="lava_test_results_dir"
+        )
+        shell = self.get_namespace_data(
+            action="test", label="shared", key="lava_test_sh_cmd"
+        )
         if not location:
             raise LAVABug("Missing lava overlay location")
         if not os.path.exists(location):
             raise LAVABug("Unable to find overlay location")
 
         lava_path = os.path.abspath("%s/%s" % (location, lava_test_results_dir))
-        scripts_to_copy = glob.glob(os.path.join(self.lava_vland_test_dir, 'lava-*'))
+        scripts_to_copy = glob.glob(os.path.join(self.lava_vland_test_dir, "lava-*"))
         self.logger.debug(self.lava_vland_test_dir)
         self.logger.debug({"lava_path": lava_path, "scripts": scripts_to_copy})
 
         for fname in scripts_to_copy:
-            with open(fname, 'r') as fin:
+            with open(fname, "r") as fin:
                 foutname = os.path.basename(fname)
-                output_file = '%s/bin/%s' % (lava_path, foutname)
+                output_file = "%s/bin/%s" % (lava_path, foutname)
                 self.logger.debug("Creating %s", output_file)
-                with open(output_file, 'w') as fout:
+                with open(output_file, "w") as fout:
                     fout.write("#!%s\n\n" % shell)
                     # Target-specific scripts (add ENV to the generic ones)
-                    if foutname == 'lava-vland-self':
+                    if foutname == "lava-vland-self":
                         fout.write(r'LAVA_VLAND_SELF="')
                         for line in self.sysfs:
                             fout.write(r"%s\n" % line)
-                    elif foutname == 'lava-vland-names':
+                    elif foutname == "lava-vland-names":
                         fout.write(r'LAVA_VLAND_NAMES="')
                         for line in self.names:
                             fout.write(r"%s\n" % line)
-                    elif foutname == 'lava-vland-tags':
+                    elif foutname == "lava-vland-tags":
                         fout.write(r'LAVA_VLAND_TAGS="')
                         if not self.tags:
                             fout.write(r"\n")
@@ -428,15 +528,22 @@ class CompressOverlay(Action):
     """
     Makes a tarball of the finished overlay and declares filename of the tarball
     """
+
     name = "compress-overlay"
     description = "Create a lava overlay tarball and store alongside the job"
     summary = "Compress the lava overlay files"
 
     def run(self, connection, max_end_time):
         output = os.path.join(self.mkdtemp(), "overlay-%s.tar.gz" % self.level)
-        location = self.get_namespace_data(action='test', label='shared', key='location')
-        lava_test_results_dir = self.get_namespace_data(action='test', label='results', key='lava_test_results_dir')
-        self.set_namespace_data(action='test', label='shared', key='output', value=output)
+        location = self.get_namespace_data(
+            action="test", label="shared", key="location"
+        )
+        lava_test_results_dir = self.get_namespace_data(
+            action="test", label="results", key="lava_test_results_dir"
+        )
+        self.set_namespace_data(
+            action="test", label="shared", key="output", value=output
+        )
         if not location:
             raise LAVABug("Missing lava overlay location")
         if not os.path.exists(location):
@@ -450,12 +557,16 @@ class CompressOverlay(Action):
                 with tarfile.open(output, "w:gz") as tar:
                     tar.add(".%s" % lava_test_results_dir)
                     # ssh authorization support
-                    if os.path.exists('./root/'):
-                        tar.add(".%s" % '/root/')
+                    if os.path.exists("./root/"):
+                        tar.add(".%s" % "/root/")
             except tarfile.TarError as exc:
-                raise InfrastructureError("Unable to create lava overlay tarball: %s" % exc)
+                raise InfrastructureError(
+                    "Unable to create lava overlay tarball: %s" % exc
+                )
 
-        self.set_namespace_data(action=self.name, label='output', key='file', value=output)
+        self.set_namespace_data(
+            action=self.name, label="output", key="file", value=output
+        )
         return connection
 
 
@@ -474,8 +585,8 @@ class SshAuthorize(Action):
     """
 
     name = "ssh-authorize"
-    description = 'include public key in overlay and authorize root user'
-    summary = 'add public key to authorized_keys'
+    description = "include public key in overlay and authorize root user"
+    summary = "add public key to authorized_keys"
 
     def __init__(self):
         super().__init__()
@@ -484,24 +595,31 @@ class SshAuthorize(Action):
 
     def validate(self):
         super().validate()
-        if 'to' in self.parameters:
-            if self.parameters['to'] == 'ssh':
+        if "to" in self.parameters:
+            if self.parameters["to"] == "ssh":
                 return
-        if 'authorize' in self.parameters:
-            if self.parameters['authorize'] != 'ssh':
+        if "authorize" in self.parameters:
+            if self.parameters["authorize"] != "ssh":
                 return
-        if not any('ssh' in data for data in self.job.device['actions']['deploy']['methods']):
+        if not any(
+            "ssh" in data for data in self.job.device["actions"]["deploy"]["methods"]
+        ):
             # idempotency - leave self.identity_file as None
             return
-        params = self.job.device['actions']['deploy']['methods']
+        params = self.job.device["actions"]["deploy"]["methods"]
         check = check_ssh_identity_file(params)
         if check[0]:
             self.errors = check[0]
         elif check[1]:
             self.identity_file = check[1]
         if self.valid:
-            self.set_namespace_data(action=self.name, label='authorize', key='identity_file', value=self.identity_file)
-            if 'authorize' in self.parameters:
+            self.set_namespace_data(
+                action=self.name,
+                label="authorize",
+                key="identity_file",
+                value=self.identity_file,
+            )
+            if "authorize" in self.parameters:
                 # only secondary connections set active.
                 self.active = True
 
@@ -511,26 +629,32 @@ class SshAuthorize(Action):
             self.logger.debug("No authorisation required.")  # idempotency
             return connection
         # add the authorization keys to the overlay
-        location = self.get_namespace_data(action='test', label='shared', key='location')
-        lava_test_results_dir = self.get_namespace_data(action='test', label='results', key='lava_test_results_dir')
+        location = self.get_namespace_data(
+            action="test", label="shared", key="location"
+        )
+        lava_test_results_dir = self.get_namespace_data(
+            action="test", label="results", key="lava_test_results_dir"
+        )
         if not location:
             raise LAVABug("Missing lava overlay location")
         if not os.path.exists(location):
             raise LAVABug("Unable to find overlay location")
         lava_path = os.path.abspath("%s/%s" % (location, lava_test_results_dir))
-        output_file = '%s/%s' % (lava_path, os.path.basename(self.identity_file))
+        output_file = "%s/%s" % (lava_path, os.path.basename(self.identity_file))
         shutil.copyfile(self.identity_file, output_file)
         shutil.copyfile("%s.pub" % self.identity_file, "%s.pub" % output_file)
         if not self.active:
             # secondary connections only
             return connection
-        self.logger.info("Adding SSH authorisation for %s.pub", os.path.basename(output_file))
-        user_sshdir = os.path.join(location, 'root', '.ssh')
+        self.logger.info(
+            "Adding SSH authorisation for %s.pub", os.path.basename(output_file)
+        )
+        user_sshdir = os.path.join(location, "root", ".ssh")
         os.makedirs(user_sshdir, 0o755, exist_ok=True)
         # if /root/.ssh/authorized_keys exists in the test image it will be overwritten
         # the key exists in the lava_test_results_dir to allow test writers to work around this
         # after logging in via the identity_file set here
-        authorize = os.path.join(user_sshdir, 'authorized_keys')
+        authorize = os.path.join(user_sshdir, "authorized_keys")
         self.logger.debug("Copying %s to %s", "%s.pub" % self.identity_file, authorize)
         shutil.copyfile("%s.pub" % self.identity_file, authorize)
         os.chmod(authorize, 0o600)
@@ -550,17 +674,24 @@ class PersistentNFSOverlay(Action):
 
     def validate(self):
         super().validate()
-        persist = self.parameters.get('persistent_nfs')
+        persist = self.parameters.get("persistent_nfs")
         if not persist:
             return
-        if 'address' not in persist:
+        if "address" not in persist:
             self.errors = "Missing address for persistent NFS"
             return
-        if ':' not in persist['address']:
-            self.errors = "Unrecognised NFS URL: '%s'" % self.parameters['persistent_nfs']['address']
+        if ":" not in persist["address"]:
+            self.errors = (
+                "Unrecognised NFS URL: '%s'"
+                % self.parameters["persistent_nfs"]["address"]
+            )
             return
-        nfs_server, dirname = persist['address'].split(':')
-        which('rpcinfo')
+        nfs_server, dirname = persist["address"].split(":")
+        which("rpcinfo")
         self.errors = rpcinfo_nfs(nfs_server)
-        self.set_namespace_data(action=self.name, label='nfs_address', key='nfsroot', value=dirname)
-        self.set_namespace_data(action=self.name, label='nfs_address', key='serverip', value=nfs_server)
+        self.set_namespace_data(
+            action=self.name, label="nfs_address", key="nfsroot", value=dirname
+        )
+        self.set_namespace_data(
+            action=self.name, label="nfs_address", key="serverip", value=nfs_server
+        )
