@@ -18,14 +18,11 @@
 # along
 # with this program; if not, see <http://www.gnu.org/licenses>.
 
-import time
+from lava_dispatcher.connection import RECOGNIZED_TAGS
 from lava_dispatcher.utils.shell import which
 from lava_dispatcher.action import Action
 from lava_common.exceptions import JobError, InfrastructureError
-from lava_dispatcher.shell import (
-    ShellCommand,
-    ShellSession,
-)
+from lava_dispatcher.shell import ShellCommand, ShellSession
 
 # pylint: disable=too-many-public-methods,too-many-instance-attributes
 # pylint: disable=too-many-branches
@@ -45,18 +42,20 @@ class ConnectDevice(Action):
 
     def __init__(self):
         super().__init__()
-        self.session_class = ShellSession  # wraps the pexpect and provides prompt_str access
+        self.session_class = (
+            ShellSession
+        )  # wraps the pexpect and provides prompt_str access
         self.shell_class = ShellCommand  # runs the command to initiate the connection
-        self.command = ''
+        self.command = ""
         self.hardware = None
         self.primary = True
-        self.message = 'Connecting to device using'
+        self.message = "Connecting to device using"
         self.tag_dict = {}
 
     def _check_command(self):
-        exe = ''
+        exe = ""
         try:
-            exe = self.command.split(' ')[0]
+            exe = self.command.split(" ")[0]
         except AttributeError:
             self.errors = "Unable to parse the connection command %s" % self.command
         which(exe)
@@ -64,75 +63,111 @@ class ConnectDevice(Action):
     def validate(self):
         super().validate()
         matched = False
-        if 'commands' not in self.job.device:
+        if "serial" not in self.job.device["actions"]["boot"]["connections"]:
+            self.errors = "Device not configured to support serial connection."
+        if "commands" not in self.job.device:
             self.errors = "Invalid device configuration - missing 'commands'"
             return
-        if 'connect' in self.job.device['commands']:
+        if "connect" in self.job.device["commands"]:
             # deprecated but allowed for primary
             if self.primary:
-                self.command = self.job.device['commands']['connect'][:]  # local copy to retain idempotency.
+                self.command = self.job.device["commands"]["connect"][
+                    :
+                ]  # local copy to retain idempotency.
             else:
                 self.errors = "Device configuration retains deprecated connect command."
-        elif 'connections' in self.job.device['commands']:
+        elif "connections" in self.job.device["commands"]:
             # if not primary, takes account of the name from the job definition
-            for hardware, value in self.job.device['commands']['connections'].items():
-                if 'connect' not in value:
+            for hardware, value in self.job.device["commands"]["connections"].items():
+                if "connect" not in value:
                     self.errors = "Misconfigured connection commands"
                     return
                 if self.primary:
-                    if 'primary' in value.get('tags', []):
+                    if "primary" in value.get("tags", []):
                         self.hardware = hardware
-                        self.tag_dict[hardware] = value.get('tags', [])
+                        self.tag_dict[hardware] = value.get("tags", [])
                         break
                 else:
-                    if 'tags' in value:
-                        if 'primary' in value['tags']:
+                    if "tags" in value:
+                        if "primary" in value["tags"]:
                             # ignore any primary hardware
                             continue
                         else:
                             # allow tags other than primary
                             if hardware == self.hardware:
                                 matched = True
-                                self.tag_dict[hardware] = value.get('tags', [])
+                                self.tag_dict[hardware] = value.get("tags", [])
                                 break
                     else:
                         # allow for no tags
                         matched = True
-                        self.tag_dict[hardware] = value.get('tags', [])
+                        self.tag_dict[hardware] = value.get("tags", [])
                         break
             if self.primary:
                 if not self.hardware:
                     self.errors = "Unable to identify primary connection command."
             else:
                 if not matched:
-                    self.errors = "Unable to identify connection command hardware. %s" % self.hardware
-            self.command = self.job.device['commands']['connections'][self.hardware]['connect'][:]  # local copy to retain idempotency.
+                    self.errors = (
+                        "Unable to identify connection command hardware. %s"
+                        % self.hardware
+                    )
+            self.command = self.job.device["commands"]["connections"][self.hardware][
+                "connect"
+            ][
+                :
+            ]  # local copy to retain idempotency.
         self._check_command()
 
     def run(self, connection, max_end_time):
-        connection_namespace = self.parameters.get('connection-namespace')
+        connection_namespace = self.parameters.get("connection-namespace")
         parameters = None
         if connection_namespace:
             parameters = {"namespace": connection_namespace}
         else:
-            parameters = {'namespace': self.parameters.get('namespace', 'common')}
+            parameters = {"namespace": self.parameters.get("namespace", "common")}
         connection = self.get_namespace_data(
-            action='shared', label='shared', key='connection', deepcopy=False, parameters=parameters)
+            action="shared",
+            label="shared",
+            key="connection",
+            deepcopy=False,
+            parameters=parameters,
+        )
         if connection:
             self.logger.debug("Already connected")
+            # Save the connection in the current namespace
+            self.set_namespace_data(
+                action="shared", label="shared", key="connection", value=connection
+            )
             return connection
         elif connection_namespace:
-            self.logger.warning("connection_namespace provided but no connection found. "
-                                "Please ensure that this parameter is correctly set to existing namespace.")
+            self.logger.warning(
+                "connection_namespace provided but no connection found. "
+                "Please ensure that this parameter is correctly set to existing namespace."
+            )
+            raise JobError(
+                "Unable to reuse connection from namespace '%s'" % connection_namespace
+            )
 
         self.logger.info(
-            "[%s] %s %s '%s'", parameters['namespace'], self.name, self.message, self.command)
+            "[%s] %s %s '%s'",
+            parameters["namespace"],
+            self.name,
+            self.message,
+            self.command,
+        )
         # ShellCommand executes the connection command
         shell = self.shell_class(
-            "%s\n" % self.command, self.timeout, logger=self.logger,
-            window=self.job.device.get_constant('spawn_maxread'))
+            "%s\n" % self.command,
+            self.timeout,
+            logger=self.logger,
+            window=self.job.device.get_constant("spawn_maxread"),
+        )
         if shell.exitstatus:
-            raise JobError("%s command exited %d: %s" % (self.command, shell.exitstatus, shell.readlines()))
+            raise JobError(
+                "%s command exited %d: %s"
+                % (self.command, shell.exitstatus, shell.readlines())
+            )
         # ShellSession monitors the pexpect
         connection = self.session_class(self.job, shell)
         connection.connected = True
@@ -140,9 +175,12 @@ class ConnectDevice(Action):
             connection.tags = self.tag_dict[self.hardware]
         connection = super().run(connection, max_end_time)
         if not connection.prompt_str:
-            connection.prompt_str = [self.job.device.get_constant(
-                'default-shell-prompt')]
-        self.set_namespace_data(action='shared', label='shared', key='connection', value=connection)
+            connection.prompt_str = [
+                self.job.device.get_constant("default-shell-prompt")
+            ]
+        self.set_namespace_data(
+            action="shared", label="shared", key="connection", value=connection
+        )
         return connection
 
 
@@ -158,14 +196,18 @@ class ConnectShell(ConnectDevice):
         self.primary = False
         self.hardware = name
         self.summary = "run connection command"
-        self.description = "use the configured command to connect serial to a second shell"
-        self.message = 'Connecting to shell using'
-        self.session_class = ShellSession  # wraps the pexpect and provides prompt_str access
+        self.description = (
+            "use the configured command to connect serial to a second shell"
+        )
+        self.message = "Connecting to shell using"
+        self.session_class = (
+            ShellSession
+        )  # wraps the pexpect and provides prompt_str access
         self.shell_class = ShellCommand  # runs the command to initiate the connection
 
     def validate(self):
         super().validate()
-        if 'connections' not in self.job.device['commands']:
+        if "connections" not in self.job.device["commands"]:
             self.errors = "Unable to connect to shell - missing connections block."
             return
         self._check_command()
@@ -175,7 +217,7 @@ class ConnectShell(ConnectDevice):
         connection = super().run(connection, max_end_time)
         self.logger.debug("Forcing a prompt")
         # force a prompt to appear without using a character that could be interpreted as a username
-        connection.sendline('')
+        connection.sendline("")
         return connection
 
 
@@ -188,14 +230,78 @@ class QemuSession(ShellSession):
 
     def __init__(self, job, raw_connection):
         super().__init__(job, raw_connection)
-        self.tags = ['qemu']
+        self.tags = ["qemu"]
 
     def finalise(self):
         self.disconnect("closing")
         super().finalise()
 
-    def disconnect(self, reason=''):
-        self.sendline('poweroff', disconnecting=True)
+    def disconnect(self, reason=""):
+        self.sendline("poweroff", disconnecting=True)
         self.listen_feedback(5)
         self.connected = False
         super().disconnect()
+
+
+class DisconnectDevice(ConnectDevice):
+    """
+    Breaks the serial connection made by ConnectDevice.
+    """
+
+    def __init__(self):
+        super().__init__()
+        self.name = "disconnect-device"
+        self.description = "disconnect from console"
+        self.summary = self.description
+
+    def validate(self):
+        super().validate()
+        if "connections" not in self.job.device["commands"]:
+            self.errors = "Unable to connect to shell - missing connections block."
+            return
+        primary_connection_has_correct_tags = False
+        for connection in self.job.device["commands"]["connections"]:
+            tags = self.job.device["commands"]["connections"][connection]["tags"]
+            if "primary" in tags:
+                # This is the primary connection that will be disconnected.
+                # Check we know how to disconnect.
+                if set(tags) & set(RECOGNIZED_TAGS):
+                    primary_connection_has_correct_tags = True
+        if not primary_connection_has_correct_tags:
+            self.errors = (
+                "LAVA does not know how to disconnect: "
+                "ensure that primary connection has one of the following tags: {}".format(
+                    RECOGNIZED_TAGS
+                )
+            )
+
+    def run(self, connection, max_end_time):
+        connection_namespace = self.parameters.get("connection-namespace")
+        parameters = None
+        if connection_namespace:
+            parameters = {"namespace": connection_namespace}
+        else:
+            parameters = {"namespace": self.parameters.get("namespace", "common")}
+        connection = self.get_namespace_data(
+            action="shared",
+            label="shared",
+            key="connection",
+            deepcopy=False,
+            parameters=parameters,
+        )
+
+        if connection:
+            self.logger.debug("Stopping connection")
+            connection.disconnect()
+            connection.connected = False
+            self.set_namespace_data(
+                action="shared",
+                label="shared",
+                key="connection",
+                value=None,
+                parameters=parameters,
+            )
+            return None
+        else:
+            self.logger.debug("Not connected, no need to disconnect.")
+        return connection
