@@ -21,6 +21,7 @@
 
 import yaml
 
+from lava_common.compat import yaml_safe_load
 from lava_common.exceptions import ConfigurationError
 
 
@@ -44,52 +45,60 @@ class PipelineDevice(dict):
 
     @property
     def hard_reset_command(self):
-        return self.get('commands', {}).get('hard_reset', '')
+        return self.get("commands", {}).get("hard_reset", "")
 
     @property
     def soft_reset_command(self):
-        return self.get('commands', {}).get('soft_reset', '')
+        return self.get("commands", {}).get("soft_reset", "")
 
     @property
     def pre_os_command(self):
-        return self.get('commands', {}).get('pre_os_command')
+        return self.get("commands", {}).get("pre_os_command")
 
     @property
     def pre_power_command(self):
-        return self.get('commands', {}).get('pre_power_command')
+        return self.get("commands", {}).get("pre_power_command")
 
     @property
     def power_command(self):
-        return self.get('commands', {}).get('power_on', '')
+        return self.get("commands", {}).get("power_on", "")
 
     @property
     def connect_command(self):
-        if 'connect' in self['commands']:
-            return self['commands']['connect']
-        elif 'connections' in self['commands']:
-            for hardware, value in self['commands']['connections'].items():
-                if 'connect' not in value:
-                    return ''
-                if 'tags' in value and 'primary' in value['tags']:
-                    return value['connect']
-        return ''
+        if "connect" in self["commands"]:
+            return self["commands"]["connect"]
+        elif "connections" in self["commands"]:
+            for hardware, value in self["commands"]["connections"].items():
+                if "connect" not in value:
+                    return ""
+                if "tags" in value and "primary" in value["tags"]:
+                    return value["connect"]
+        return ""
 
     def get_constant(self, const, prefix=None, missing_ok=False, missing_default=None):
-        if 'constants' not in self:
-            raise ConfigurationError("constants section not present in the device config.")
-        constants = self['constants']
+        if "constants" not in self:
+            raise ConfigurationError(
+                "constants section not present in the device config."
+            )
+        constants = self["constants"]
         if prefix:
             if prefix in constants:
                 if const in constants[prefix]:
                     return constants[prefix][const]
             if missing_ok:
                 return missing_default
-            raise ConfigurationError("Constant %s,%s does not exist in the device config 'constants' section." % (prefix, const))
+            raise ConfigurationError(
+                "Constant %s,%s does not exist in the device config 'constants' section."
+                % (prefix, const)
+            )
         if const in constants:
             return constants[const]
         if missing_ok:
             return missing_default
-        raise ConfigurationError("Constant %s does not exist in the device config 'constants' section." % const)
+        raise ConfigurationError(
+            "Constant %s does not exist in the device config 'constants' section."
+            % const
+        )
 
 
 class NewDevice(PipelineDevice):
@@ -106,19 +115,19 @@ class NewDevice(PipelineDevice):
             if isinstance(target, str):
                 with open(target) as f_in:
                     data = f_in.read()
-                data = yaml.safe_load(data)
+                data = yaml_safe_load(data)
             elif isinstance(target, dict):
                 data = target
             else:
                 data = target.read()
-                data = yaml.safe_load(data)
+                data = yaml_safe_load(data)
             if data is None:
                 raise ConfigurationError("Missing device configuration")
             self.update(data)
         except yaml.parser.ParserError:
             raise ConfigurationError("%s could not be parsed" % target)
 
-        self.setdefault('power_state', 'off')  # assume power is off at start of job
+        self.setdefault("power_state", "off")  # assume power is off at start of job
 
     def check_config(self, job):
         """
