@@ -1,4 +1,4 @@
-# Copyright (C) 2015 Linaro Limited
+# Copyright (C) 2015-2019 Linaro Limited
 #
 # Author: Neil Williams <neil.williams@linaro.org>
 #
@@ -19,11 +19,13 @@
 # with this program; if not, see <http://www.gnu.org/licenses>.
 
 
+import os
 import copy
 import time
 import json
 import socket
 import logging
+import subprocess  # nosec - vland
 from lava_dispatcher.connection import Protocol
 from lava_common.exceptions import JobError, TestError
 from lava_dispatcher.protocols.multinode import MultinodeProtocol
@@ -44,17 +46,20 @@ class VlandProtocol(Protocol):
     *must* be able to setup a vlan that could potentially use ports on any switch
     in the configured set - so each needs to be able to see all of the others.
     """
+
     name = "lava-vland"
     level = 5
 
     def __init__(self, parameters, job_id):
         super().__init__(parameters, job_id)
-        self.logger = logging.getLogger('dispatcher')
+        self.logger = logging.getLogger("dispatcher")
         self.vlans = {}
         self.ports = []
         self.names = {}
-        self.base_group = parameters['protocols'][MultinodeProtocol.name]['target_group'].replace('-', '')[:10]
-        self.sub_id = parameters['protocols'][MultinodeProtocol.name]['sub_id']
+        self.base_group = parameters["protocols"][MultinodeProtocol.name][
+            "target_group"
+        ].replace("-", "")[:10]
+        self.sub_id = parameters["protocols"][MultinodeProtocol.name]["sub_id"]
         self.fake_run = False
         self.settings = None
         self.blocks = 4 * 1024
@@ -66,23 +71,19 @@ class VlandProtocol(Protocol):
 
     @classmethod
     def accepts(cls, parameters):
-        if 'protocols' not in parameters:
+        if "protocols" not in parameters:
             return False
-        if 'lava-multinode' not in parameters['protocols']:
+        if "lava-multinode" not in parameters["protocols"]:
             return False
-        if 'target_group' not in parameters['protocols'][MultinodeProtocol.name]:
+        if "target_group" not in parameters["protocols"][MultinodeProtocol.name]:
             return False
-        if 'lava-vland' not in parameters['protocols']:
+        if "lava-vland" not in parameters["protocols"]:
             return False
         return True
 
     def read_settings(self):  # pylint: disable=no-self-use
         # FIXME: support config file
-        settings = {
-            "port": 3080,
-            "poll_delay": 1,
-            "vland_hostname": "localhost"
-        }
+        settings = {"port": 3080, "poll_delay": 1, "vland_hostname": "localhost"}
         return settings
 
     def _connect(self, delay):
@@ -92,12 +93,15 @@ class VlandProtocol(Protocol):
         self.sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
         self.sock.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
         try:
-            self.sock.connect((self.settings['vland_hostname'], self.settings['port']))
+            self.sock.connect((self.settings["vland_hostname"], self.settings["port"]))
             return True
         except OSError as exc:
             self.logger.exception(
                 "socket error on connect: %d %s %s",
-                exc.errno, self.settings['vland_hostname'], self.settings['port'])
+                exc.errno,
+                self.settings["vland_hostname"],
+                self.settings["port"],
+            )
             time.sleep(delay)
             self.sock.close()
             return False
@@ -115,7 +119,7 @@ class VlandProtocol(Protocol):
                 self.logger.debug("zero bytes sent for message - connection closed?")
                 return False
         except OSError as exc:
-            self.logger.exception("socket error '%d' on send", exc.message)
+            self.logger.exception("socket error '%s' on send", exc)
             self.sock.close()
             return False
         return True
@@ -123,12 +127,12 @@ class VlandProtocol(Protocol):
     def _recv_message(self):
         try:
             header = self.sock.recv(8)  # 32bit limit as a hexadecimal
-            if not header or header == '':
+            if not header or header == "":
                 self.logger.debug("empty header received?")
                 return json.dumps({"response": "wait"})
             msg_count = int(header, 16)
             recv_count = 0
-            response = ''
+            response = ""
             while recv_count < msg_count:
                 response += self.sock.recv(self.blocks).decode()
                 recv_count += self.blocks
@@ -152,19 +156,27 @@ class VlandProtocol(Protocol):
             raise JobError("Message was too long to send!")
         c_iter = 0
         response = None
-        delay = self.settings['poll_delay']
-        self.logger.debug("Connecting to VLANd on %s:%s timeout=%d seconds.",
-                          self.settings['vland_hostname'], self.settings['port'], timeout)
+        delay = self.settings["poll_delay"]
+        self.logger.debug(
+            "Connecting to VLANd on %s:%s timeout=%d seconds.",
+            self.settings["vland_hostname"],
+            self.settings["port"],
+            timeout,
+        )
         while True:
-            c_iter += self.settings['poll_delay']
+            c_iter += self.settings["poll_delay"]
             if self._connect(delay):
-                delay = self.settings['poll_delay']
+                delay = self.settings["poll_delay"]
             else:
                 delay += 2
                 continue
-            if not c_iter % int(10 * self.settings['poll_delay']):
-                self.logger.debug("sending message: %s waited %s of %s seconds",
-                                  json.loads(message)['request'], c_iter, int(timeout))
+            if not c_iter % int(10 * self.settings["poll_delay"]):
+                self.logger.debug(
+                    "sending message: %s waited %s of %s seconds",
+                    json.loads(message)["request"],
+                    c_iter,
+                    int(timeout),
+                )
             # blocking synchronous call
             if not self._send_message(message):
                 continue
@@ -177,7 +189,7 @@ class VlandProtocol(Protocol):
                 self.logger.debug("response starting '%s' was not JSON", response[:42])
                 self.finalise_protocol()
                 break
-            if json_data['response'] != 'wait':
+            if json_data["response"] != "wait":
                 break
             else:
                 time.sleep(delay)
@@ -208,34 +220,31 @@ class VlandProtocol(Protocol):
         :return: a tuple containing the internal name used by vland and the vland tag.
         """
         msg = {
-            'type': 'vlan_update',
-            'command': 'api.create_vlan',
-            'data': {
-                'name': self.names[friendly_name],
-                'tag': -1,
-                'is_base_vlan': False
-            }
+            "type": "vlan_update",
+            "command": "api.create_vlan",
+            "data": {
+                "name": self.names[friendly_name],
+                "tag": -1,
+                "is_base_vlan": False,
+            },
         }
         self.logger.debug({"create_vlan": msg})
         response = self._call_vland(msg)
-        if not response or response == '':
+        if not response or response == "":
             return (None, None)
         reply = json.loads(response)
-        if 'data' in reply:
-            return reply['data']
+        if "data" in reply:
+            return reply["data"]
         raise JobError("Deploy vlans failed for %s: %s" % (friendly_name, reply))
 
     def _declare_created(self, friendly_name, tag):
         if not self.configured:
             return False
         send_msg = {
-            'request': 'lava_send',
-            'timeout': VLAND_DEPLOY_TIMEOUT,
-            'messageID': friendly_name,
-            'message': {
-                'vlan_name': self.vlans[friendly_name],
-                'vlan_tag': tag
-            }
+            "request": "lava_send",
+            "timeout": VLAND_DEPLOY_TIMEOUT,
+            "messageID": friendly_name,
+            "message": {"vlan_name": self.vlans[friendly_name], "vlan_tag": tag},
         }
         self.multinode_protocol(send_msg)
 
@@ -243,23 +252,21 @@ class VlandProtocol(Protocol):
         if not self.configured:
             return False
         wait_msg = {
-            'request': 'lava_wait',
-            'timeout': VLAND_DEPLOY_TIMEOUT,
-            'messageID': friendly_name,
+            "request": "lava_wait",
+            "timeout": VLAND_DEPLOY_TIMEOUT,
+            "messageID": friendly_name,
         }
         ret = self.multinode_protocol(wait_msg)
         if ret:
             values = list(ret.values())[0]
-            return (values['vlan_name'], values['vlan_tag'],)
+            return (values["vlan_name"], values["vlan_tag"])
         raise JobError("Waiting for vlan creation failed: %s" % ret)
 
     def _delete_vlan(self, friendly_name, vlan_id):
         msg = {
-            'type': 'vlan_update',
-            'command': 'api.delete_vlan',
-            'data': {
-                'vlan_id': vlan_id,
-            }
+            "type": "vlan_update",
+            "command": "api.delete_vlan",
+            "data": {"vlan_id": vlan_id},
         }
         self.logger.debug({"delete_vlan": msg})
         self._call_vland(msg)
@@ -267,43 +274,35 @@ class VlandProtocol(Protocol):
 
     def _lookup_switch_id(self, switch_name):
         msg = {
-            'type': 'db_query',
-            'command': 'db.get_switch_id_by_name',
-            'data': {
-                'name': switch_name
-            }
+            "type": "db_query",
+            "command": "db.get_switch_id_by_name",
+            "data": {"name": switch_name},
         }
         self.logger.debug({"lookup_switch": msg})
         response = self._call_vland(msg)
-        if not response or response == '':
+        if not response or response == "":
             raise JobError("Switch_id for switch name: %s not found" % switch_name)
         reply = json.loads(response)
-        return reply['data']
+        return reply["data"]
 
     def _lookup_port_id(self, switch_id, port):
         msg = {
-            'type': 'db_query',
-            'command': 'db.get_port_by_switch_and_number',
-            'data': {
-                'switch_id': switch_id,
-                'number': port
-            }
+            "type": "db_query",
+            "command": "db.get_port_by_switch_and_number",
+            "data": {"switch_id": switch_id, "number": port},
         }
         self.logger.debug({"lookup_port_id": msg})
         response = self._call_vland(msg)
-        if not response or response == '':
+        if not response or response == "":
             raise JobError("Port_id for port: %s not found" % port)
         reply = json.loads(response)
-        return reply['data']
+        return reply["data"]
 
     def _set_port_onto_vlan(self, vlan_id, port_id):
         msg = {
-            'type': 'vlan_update',
-            'command': 'api.set_current_vlan',
-            'data': {
-                'port_id': port_id,
-                'vlan_id': vlan_id
-            }
+            "type": "vlan_update",
+            "command": "api.set_current_vlan",
+            "data": {"port_id": port_id, "vlan_id": vlan_id},
         }
         self.logger.debug({"set_port_onto_vlan": msg})
         self._call_vland(msg)
@@ -311,11 +310,9 @@ class VlandProtocol(Protocol):
 
     def _restore_port(self, port_id):
         msg = {
-            'type': 'vlan_update',
-            'command': 'api.restore_base_vlan',
-            'data': {
-                'port_id': port_id,
-            }
+            "type": "vlan_update",
+            "command": "api.restore_base_vlan",
+            "data": {"port_id": port_id},
         }
         self.logger.debug({"restore_port": msg})
         self._call_vland(msg)
@@ -329,9 +326,9 @@ class VlandProtocol(Protocol):
         """
         self.settings = self.read_settings()
         self.base_message = {
-            "port": self.settings['port'],
+            "port": self.settings["port"],
             "poll_delay": self.settings["poll_delay"],
-            "host": self.settings['vland_hostname'],
+            "host": self.settings["vland_hostname"],
             "client_name": socket.gethostname(),
         }
 
@@ -345,70 +342,88 @@ class VlandProtocol(Protocol):
             return True
         if not device:
             self.errors = "Unable to configure protocol without a device"
-        elif 'parameters' not in device:
+        elif "parameters" not in device:
             self.errors = "Invalid device configuration, no parameters given."
-        elif 'interfaces' not in device['parameters']:
+        elif "interfaces" not in device["parameters"]:
             self.errors = "Device lacks interfaces information."
-        elif not isinstance(device['parameters']['interfaces'], dict):
+        elif not isinstance(device["parameters"]["interfaces"], dict):
             self.errors = "Invalid interfaces dictionary for device"
-        protocols = [protocol for protocol in job.protocols if protocol.name == MultinodeProtocol.name]
+        protocols = [
+            protocol
+            for protocol in job.protocols
+            if protocol.name == MultinodeProtocol.name
+        ]
         if not protocols:
             self.errors = "Unable to determine Multinode protocol object"
         self.multinode_protocol = protocols[0]
         if not self.valid:
             return False
-        interfaces = [interface for interface, _ in device['parameters']['interfaces'].items()]
+        interfaces = [
+            interface for interface, _ in device["parameters"]["interfaces"].items()
+        ]
         available = []
         for iface in interfaces:
-            if device['parameters']['interfaces'][iface]['tags']:
+            if device["parameters"]["interfaces"][iface]["tags"]:
                 # skip primary interfaces
-                available.extend(device['parameters']['interfaces'][iface]['tags'])
+                available.extend(device["parameters"]["interfaces"][iface]["tags"])
         requested = []
-        for friendly_name in self.parameters['protocols'][self.name]:
-            if friendly_name == 'yaml_line':
-                continue
+        for friendly_name in self.parameters["protocols"][self.name]:
             base_jobid = "%s" % job.job_id
             base = "%s%s" % (base_jobid[-8:], friendly_name[:8])
-            self.names[friendly_name] = ''.join(e for e in base if e.isalnum())[:16]
-        self.params = copy.deepcopy(self.parameters['protocols'][self.name])
+            self.names[friendly_name] = "".join(e for e in base if e.isalnum())[:16]
+        self.params = copy.deepcopy(self.parameters["protocols"][self.name])
         for vlan_name in self.params:
-            if vlan_name == 'yaml_line':
-                continue
-            if 'tags' not in self.params[vlan_name]:
+            if "tags" not in self.params[vlan_name]:
                 self.errors = "device already configured for %s" % self.name
             else:
-                requested.extend(self.params[vlan_name]['tags'])
+                requested.extend(self.params[vlan_name]["tags"])
         if set(available) & set(requested) != set(requested):
             self.errors = "Requested link speeds %s are not available %s for device" % (
-                requested, available)
+                requested,
+                available,
+            )
         if not self.valid:
             return False
 
         # one vlan_name, one combination of switch & port, one interface, any supported link speed.
         # this may need more work with more complex vlan jobs
         for vlan_name in self.params:
-            if vlan_name == 'yaml_line':
-                continue
             for iface in interfaces:
-                device_info = device['parameters']['interfaces'][iface]
-                if ' '.join([device_info['switch'], str(device_info['port'])]) in self.nodes_seen:
+                device_info = device["parameters"]["interfaces"][iface]
+                if (
+                    " ".join([device_info["switch"], str(device_info["port"])])
+                    in self.nodes_seen
+                ):
                     # combination of switch & port already processed for this device
                     continue
-                if not device_info['tags']:
+                if not device_info["tags"]:
                     # primary network interface, must not allow a vlan
                     continue
                 # device interface tags & job tags must equal job tags
                 # device therefore must support all job tags, not all job tags available on the device need to be specified
-                if set(device_info['tags']) & set(self.params[vlan_name]['tags']) == set(self.params[vlan_name]['tags']):
-                    self.params[vlan_name]['switch'] = device_info['switch']
-                    self.params[vlan_name]['port'] = device_info['port']
-                    self.params[vlan_name]['iface'] = iface
-                    self.nodes_seen.append(' '.join([device_info['switch'], str(device_info['port'])]))
+                if set(device_info["tags"]) & set(
+                    self.params[vlan_name]["tags"]
+                ) == set(self.params[vlan_name]["tags"]):
+                    self.params[vlan_name]["switch"] = device_info["switch"]
+                    self.params[vlan_name]["port"] = device_info["port"]
+                    self.params[vlan_name]["iface"] = iface
+                    self.nodes_seen.append(
+                        " ".join([device_info["switch"], str(device_info["port"])])
+                    )
                     break
         if self.sub_id == 0:
             self.logger.info("[%s] Job will deploy requested VLANs.", self.name)
         else:
             self.logger.info("[%s] Job will wait for VLANs to be deployed.", self.name)
+        vland = "/usr/sbin/vland-admin"
+        if os.path.exists(vland):
+            # allow the unit tests to run
+            vers = (
+                subprocess.check_output([vland, "vland_version"])  # nosec vland
+                .strip()
+                .decode("utf-8", errors="replace")
+            )
+            self.logger.info("[%s] Job will use vland version: %s", self.name, vers)
         self.logger.debug("[%s] parameters: %s", self.name, self.params)
         super().configure(device, job)
         return True
@@ -430,23 +445,39 @@ class VlandProtocol(Protocol):
         # run_admin_command --create_vlan test30 -1 false
         if self.sub_id != 0:
             for friendly_name, _ in self.names.items():
-                self.logger.info("Waiting for vlan %s : %s to be deployed.", friendly_name, self.names[friendly_name])
+                self.logger.info(
+                    "Waiting for vlan %s : %s to be deployed.",
+                    friendly_name,
+                    self.names[friendly_name],
+                )
                 self.vlans[friendly_name], tag = self._wait_on_create(friendly_name)
-                self.logger.debug("vlan name: %s vlan tag: %s", self.vlans[friendly_name], tag)
+                self.logger.debug(
+                    "vlan name: %s vlan tag: %s", self.vlans[friendly_name], tag
+                )
         else:
             for friendly_name, _ in self.names.items():
-                self.logger.info("Deploying vlan %s : %s", friendly_name, self.names[friendly_name])
+                self.logger.info(
+                    "Deploying vlan %s : %s", friendly_name, self.names[friendly_name]
+                )
                 self.vlans[friendly_name], tag = self._create_vlan(friendly_name)
-                self.logger.debug("vlan name: %s vlan tag: %s", self.vlans[friendly_name], tag)
+                self.logger.debug(
+                    "vlan name: %s vlan tag: %s", self.vlans[friendly_name], tag
+                )
                 if not tag:  # error state from create_vlan
                     raise JobError("Unable to create vlan %s" % friendly_name)
+                # FIXME: _declare_created may return False but this is not checked.
                 self._declare_created(friendly_name, tag)
         for friendly_name, _ in self.names.items():
             params = self.params[friendly_name]
-            switch_id = self._lookup_switch_id(params['switch'])
-            port_id = self._lookup_port_id(switch_id, params['port'])
-            self.logger.info("Setting switch %s port %s to vlan %s on %s",
-                             params['switch'], params['port'], friendly_name, params['iface'])
+            switch_id = self._lookup_switch_id(params["switch"])
+            port_id = self._lookup_port_id(switch_id, params["port"])
+            self.logger.info(
+                "Setting switch %s port %s to vlan %s on %s",
+                params["switch"],
+                params["port"],
+                friendly_name,
+                params["iface"],
+            )
             self._set_port_onto_vlan(self.vlans[friendly_name], port_id)
             self.ports.append(port_id)
 
@@ -459,25 +490,26 @@ class VlandProtocol(Protocol):
             self.logger.exception(msg)
             raise JobError(msg)
 
-    def _api_select(self, data):
+    def _api_select(self, data, action=None):
         if not data:
             raise TestError("Protocol called without any data")
-        if 'request' not in data:
+        if "request" not in data:
             raise JobError("Bad API call over protocol - missing request")
-        if data['request'] == 'deploy_vlans':
+        if data["request"] == "deploy_vlans":
             self.deploy_vlans()
         else:
             raise JobError("Unrecognised API call in request.")
-        return None
 
     def check_timeout(self, duration, data):
         if not data:
             raise TestError("Protocol called without any data")
-        if 'request' not in data:
+        if "request" not in data:
             raise JobError("Bad API call over protocol - missing request")
-        if data['request'] == 'deploy_vlans':
+        if data["request"] == "deploy_vlans":
             if duration < VLAND_DEPLOY_TIMEOUT:
-                raise JobError("Timeout of %s is insufficient for deploy_vlans" % duration)
+                raise JobError(
+                    "Timeout of %s is insufficient for deploy_vlans" % duration
+                )
             self.logger.info("Setting vland base timeout to %s seconds", duration)
             self.poll_timeout.duration = duration
             return True
