@@ -18,10 +18,13 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with LAVA.  If not, see <http://www.gnu.org/licenses/>.
 
+import warnings
+
 from django import forms
 from django.core.exceptions import ValidationError
 from django.contrib import admin
-from django.contrib.auth.admin import UserAdmin
+from django.contrib.auth.admin import UserAdmin, GroupAdmin
+from django.contrib.auth.models import Permission, Group
 from django.db import transaction
 from django.conf import settings
 
@@ -30,9 +33,10 @@ from lava_scheduler_app.models import (
     Alias,
     BitWidth,
     Core,
-    DefaultDeviceOwner,
     Device,
     DeviceType,
+    GroupDeviceTypePermission,
+    GroupDevicePermission,
     JobFailureTag,
     NotificationRecipient,
     ProcessorFamily,
@@ -47,12 +51,42 @@ from linaro_django_xmlrpc.models import AuthToken
 # pylint: disable=no-self-use,function-redefined
 
 
+class GroupObjectPermissionInline(admin.TabularInline):
+    extra = 0
+    supported_permissions = (
+        DeviceType.PERMISSIONS_PRIORITY + Device.PERMISSIONS_PRIORITY
+    )
+
+    def formfield_for_foreignkey(self, db_field, request=None, **kwargs):
+        supported_codenames = [x.split(".")[1] for x in self.supported_permissions]
+        if db_field.name == "permission":
+            kwargs["queryset"] = Permission.objects.filter(
+                content_type__model=self.parent_model._meta.object_name.lower(),
+                codename__in=supported_codenames,
+            )
+        return super(GroupObjectPermissionInline, self).formfield_for_foreignkey(
+            db_field, request, **kwargs
+        )
+
+
+class GroupDeviceTypePermissionInline(GroupObjectPermissionInline):
+    model = GroupDeviceTypePermission
+    extra = 0
+
+
+class GroupDevicePermissionInline(GroupObjectPermissionInline):
+    model = GroupDevicePermission
+    extra = 0
+
+
 class AliasAdmin(admin.ModelAdmin):
     def get_readonly_fields(self, _, obj=None):
         if obj:  # editing an existing object
             return self.readonly_fields + ("name",)
         return self.readonly_fields
 
+    list_display = ("name", "device_type")
+
 
 class ArchitectureAdmin(admin.ModelAdmin):
     def get_readonly_fields(self, _, obj=None):
@@ -75,16 +109,6 @@ class CoreAdmin(admin.ModelAdmin):
         return self.readonly_fields
 
 
-class DefaultOwnerInline(admin.StackedInline):
-    """
-    Exposes the default owner override class
-    in the Django admin interface
-    """
-
-    model = DefaultDeviceOwner
-    can_delete = False
-
-
 def expire_user_action(
     modeladmin, request, queryset
 ):  # pylint: disable=unused-argument
@@ -103,12 +127,34 @@ def expire_user_action(
 expire_user_action.short_description = "Expire user account"
 
 
-class UserAdmin(UserAdmin):
-    """
-    Defines the override class for DefaultOwnerInline
-    """
+class CustomGroupAdminForm(forms.ModelForm):
+    users = forms.ModelMultipleChoiceField(
+        User.objects.all(),
+        widget=admin.widgets.FilteredSelectMultiple("Users", False),
+        required=False,
+    )
+
+    def __init__(self, *args, **kwargs):
+        super(CustomGroupAdminForm, self).__init__(*args, **kwargs)
+        if self.instance.pk:
+            initial_users = self.instance.user_set.values_list("pk", flat=True)
+            self.initial["users"] = initial_users
+
+    def save(self, *args, **kwargs):
+        kwargs["commit"] = True
+        return super(CustomGroupAdminForm, self).save(*args, **kwargs)
+
+    def save_m2m(self):
+        self.instance.user_set.clear()
+        self.instance.user_set.add(*self.cleaned_data["users"])
+
+
+class CustomGroupAdmin(GroupAdmin):
+    form = CustomGroupAdminForm
+
+
+class CustomUserAdmin(UserAdmin):
 
-    inlines = (DefaultOwnerInline,)
     actions = [expire_user_action]
 
     def has_delete_permission(self, request, obj=None):
@@ -117,12 +163,21 @@ class UserAdmin(UserAdmin):
 
 #  Setup the override in the django admin interface at startup.
 admin.site.unregister(User)
-admin.site.register(User, UserAdmin)
+admin.site.register(User, CustomUserAdmin)
+admin.site.unregister(Group)
+admin.site.register(Group, CustomGroupAdmin)
 
 
 def cancel_action(modeladmin, request, queryset):  # pylint: disable=unused-argument
     with transaction.atomic():
-        for testjob in queryset.select_for_update():
+        for testjob in queryset:
+            # TODO: hacky. until django 2.0+ is used and select_for_update gets
+            # the 'of' argument.
+            warnings.warn(
+                "select_for_update should be applied to the whole queryset at once, once we upgrade to django 2+",
+                DeprecationWarning,
+            )
+            testjob = TestJob.objects.select_for_update().get(pk=testjob.pk)
             if testjob.can_cancel(request.user):
                 if testjob.is_multinode:
                     for job in testjob.sub_jobs_list:
@@ -139,9 +194,14 @@ cancel_action.short_description = "cancel selected jobs"
 def fail_action(modeladmin, request, queryset):
     if request.user.is_superuser:
         with transaction.atomic():
-            for testjob in queryset.select_for_update().filter(
-                state=TestJob.STATE_CANCELING
-            ):
+            for testjob in queryset.filter(state=TestJob.STATE_CANCELING):
+                # TODO: hacky. until django 2.0+ is used and select_for_update
+                # gets the 'of' argument.
+                warnings.warn(
+                    "select_for_update should be applied to the whole queryset at once, once we upgrade to django 2+",
+                    DeprecationWarning,
+                )
+                testjob = TestJob.objects.select_for_update().get(pk=testjob.pk)
                 testjob.go_state_finished(TestJob.HEALTH_INCOMPLETE)
                 testjob.save()
 
@@ -220,7 +280,15 @@ class RequestedDeviceTypeFilter(admin.SimpleListFilter):
 
 def _update_devices_health(request, queryset, health):
     with transaction.atomic():
-        for device in queryset.select_for_update():
+        for device in queryset:
+            # TODO: hacky. until django 2.0+ is used and select_for_update gets
+            # the 'of' argument.
+            warnings.warn(
+                "select_for_update should be applied to the whole queryset at once, once we upgrade to django 2+",
+                DeprecationWarning,
+            )
+            device = Device.objects.select_for_update().get(pk=device.pk)
+
             old_health_display = device.get_health_display()
             device.health = health
             device.save()
@@ -264,6 +332,13 @@ class DeviceAdmin(admin.ModelAdmin):
     )
     raw_id_fields = ["last_health_report_job"]
 
+    def get_queryset(self, request):
+        return (
+            super(DeviceAdmin, self)
+            .get_queryset(request)
+            .select_related("worker_host", "device_type")
+        )
+
     def has_health_check(self, obj):
         return bool(obj.get_health_check())
 
@@ -298,16 +373,7 @@ class DeviceAdmin(admin.ModelAdmin):
             "Properties",
             {"fields": ("hostname", "device_type", "worker_host", "device_version")},
         ),
-        (
-            "Device owner",
-            {
-                "fields": (
-                    ("user", "group"),
-                    ("physical_owner", "physical_group"),
-                    "is_public",
-                )
-            },
-        ),
+        ("Device owner", {"fields": (("physical_owner", "physical_group"),)}),
         (
             "Status",
             {
@@ -335,7 +401,6 @@ class DeviceAdmin(admin.ModelAdmin):
         "health",
         "has_health_check",
         "health_check_enabled",
-        "is_public",
         "valid_device",
     )
     search_fields = ("hostname", "device_type__name")
@@ -346,28 +411,17 @@ class DeviceAdmin(admin.ModelAdmin):
         device_health_maintenance,
         device_health_retired,
     ]
-
-
-class VisibilityForm(forms.ModelForm):
-    def clean_viewing_groups(self):
-        viewing_groups = self.cleaned_data["viewing_groups"]
-        visibility = self.cleaned_data["visibility"]
-        if len(viewing_groups) != 1 and visibility == TestJob.VISIBLE_GROUP:
-            raise ValidationError(
-                "Group visibility must have exactly one viewing group."
-            )
-        elif len(viewing_groups) != 0 and visibility == TestJob.VISIBLE_PERSONAL:
-            raise ValidationError(
-                "Personal visibility cannot have any viewing groups assigned."
-            )
-        elif len(viewing_groups) != 0 and visibility == TestJob.VISIBLE_PUBLIC:
-            raise ValidationError(
-                "Pulibc visibility cannot have any viewing groups assigned."
-            )
-        return self.cleaned_data["viewing_groups"]
+    inlines = [GroupDevicePermissionInline]
 
 
 class TestJobAdmin(admin.ModelAdmin):
+    def get_queryset(self, request):
+        return (
+            super(TestJobAdmin, self)
+            .get_queryset(request)
+            .select_related("requested_device_type", "actual_device", "submitter")
+        )
+
     def requested_device_type_name(self, obj):
         return "" if obj.requested_device_type is None else obj.requested_device_type
 
@@ -378,23 +432,10 @@ class TestJobAdmin(admin.ModelAdmin):
         return settings.ALLOW_ADMIN_DELETE
 
     requested_device_type_name.short_description = "Request device type"
-    form = VisibilityForm
     actions = [cancel_action, fail_action]
     list_filter = ("state", RequestedDeviceTypeFilter, ActualDeviceFilter)
     fieldsets = (
-        (
-            "Owner",
-            {
-                "fields": (
-                    "user",
-                    "group",
-                    "submitter",
-                    "is_public",
-                    "visibility",
-                    "viewing_groups",
-                )
-            },
-        ),
+        ("Owner", {"fields": ("submitter", "viewing_groups", "is_public")}),
         ("Request", {"fields": ("requested_device_type", "priority", "health_check")}),
         (
             "Advanced properties",
@@ -429,6 +470,13 @@ disable_health_check_action.short_description = "disable health checks"
 
 
 class DeviceTypeAdmin(admin.ModelAdmin):
+    def get_queryset(self, request):
+        return (
+            super(DeviceTypeAdmin, self)
+            .get_queryset(request)
+            .select_related("architecture", "bits", "processor")
+        )
+
     def architecture_name(self, obj):
         if obj.architecture:
             return obj.architecture
@@ -490,7 +538,6 @@ class DeviceTypeAdmin(admin.ModelAdmin):
     list_display = (
         "name",
         "display",
-        "owners_only",
         "health_check_enabled",
         "health_check_frequency",
         "architecture_name",
@@ -500,10 +547,7 @@ class DeviceTypeAdmin(admin.ModelAdmin):
         "bit_count",
     )
     fieldsets = (
-        (
-            "Properties",
-            {"fields": ("name", "description", "display", "owners_only", "aliases")},
-        ),
+        ("Properties", {"fields": ("name", "description", "display")}),
         (
             "Health checks",
             {
@@ -527,6 +571,7 @@ class DeviceTypeAdmin(admin.ModelAdmin):
         ),
     )
     ordering = ["name"]
+    inlines = [GroupDeviceTypePermissionInline]
 
 
 def worker_health_active(ModelAdmin, request, queryset):
