@@ -18,12 +18,13 @@
 # along with LAVA.  If not, see <http://www.gnu.org/licenses/>.
 
 import contextlib
-import errno
 import glob
 import os
 import xmlrpc.client
 
+from django.conf import settings
 from django.db import IntegrityError
+from django.forms import ValidationError
 
 from linaro_django_xmlrpc.models import ExposedV2API
 from lava_scheduler_app.api import check_perm
@@ -31,25 +32,31 @@ from lava_scheduler_app.models import Alias, DeviceType
 
 
 class SchedulerDeviceTypesAPI(ExposedV2API):
-
     def _available_device_types(self):
         """ List avaiable device types by looking at the configuration files """
         available_types = []
-        for fname in glob.iglob("/etc/lava-server/dispatcher-config/device-types/*.jinja2"):
+        pattern = os.path.join(settings.DEVICE_TYPES_PATH, "*.jinja2")
+        for fname in glob.iglob(pattern):
             device_type = os.path.basename(fname[:-7])
             if not device_type.startswith("base"):
                 available_types.append(device_type)
         available_types.sort()
         return available_types
 
-    @check_perm("lava_scheduler_app.add_devicetype")
-    def add(self, name, description, display, owners_only,
-            health_frequency, health_denominator):
+    @check_perm("lava_scheduler_app.change_devicetype")
+    def add(
+        self,
+        name,
+        description,
+        display,
+        owners_only,
+        health_frequency,
+        health_denominator,
+    ):
         """
         Name
         ----
-        `scheduler.device_types.add` (`name`, `description`, `display`, `owners_only`,
-                                      `health_frequency`, health_denominator`)
+        `scheduler.device_types.add` (`name`, `description`, `display`, `owners_only`, `health_frequency`, health_denominator`)
 
         Description
         -----------
@@ -66,7 +73,7 @@ class SchedulerDeviceTypesAPI(ExposedV2API):
         `display`: bool
           Is the device-type displayed in the GUI?
         `owners_only`: bool
-          Is the device-type only available to owners?
+          DEPRECATED: this field is not used any more
         `health_frequency`: int
           How often to run health checks
         `health_denominator`: string ("hours" or "jobs")
@@ -81,17 +88,22 @@ class SchedulerDeviceTypesAPI(ExposedV2API):
         elif health_denominator == "jobs":
             health_denominator = DeviceType.HEALTH_PER_JOB
         else:
-            raise xmlrpc.client.Fault(
-                400, "Bad request: invalid health_denominator.")
+            raise xmlrpc.client.Fault(400, "Bad request: invalid health_denominator.")
 
         try:
-            DeviceType.objects.create(name=name, description=description,
-                                      display=display, owners_only=owners_only,
-                                      health_frequency=health_frequency,
-                                      health_denominator=health_denominator)
-        except IntegrityError:
+            dt = DeviceType(
+                name=name,
+                description=description,
+                display=display,
+                health_frequency=health_frequency,
+                health_denominator=health_denominator,
+            )
+            dt.full_clean()
+            dt.save()
+        except (IntegrityError, ValidationError):
             raise xmlrpc.client.Fault(
-                400, "Bad request: device-type name is already used.")
+                400, "Bad request: device-type name is already used."
+            )
 
     def get_health_check(self, name):
         """
@@ -120,7 +132,7 @@ class SchedulerDeviceTypesAPI(ExposedV2API):
         """
         with contextlib.suppress(DeviceType.DoesNotExist):
             dt = DeviceType.objects.get(name=name)
-            if dt.owners_only and not dt.some_devices_visible_to(self.user):
+            if not dt.can_view(self.user):
                 raise xmlrpc.client.Fault(404, "Device-type '%s' was not found." % name)
 
         # Filename should not be a path or starting with a dot
@@ -128,15 +140,18 @@ class SchedulerDeviceTypesAPI(ExposedV2API):
             raise xmlrpc.client.Fault(400, "Invalid device-type '%s'" % name)
 
         try:
-            filename = os.path.join("/etc/lava-server/dispatcher-config/health-checks", name)
-            filename += ".yaml" if not filename.endswith('.yaml') else ''
+            filename = os.path.join(
+                "/etc/lava-server/dispatcher-config/health-checks", name
+            )
+            filename += ".yaml" if not filename.endswith(".yaml") else ""
             with open(filename, "r") as f_in:
                 return xmlrpc.client.Binary(f_in.read().encode("utf-8"))
+        except FileNotFoundError:
+            raise xmlrpc.client.Fault(404, "Device-type '%s' was not found." % name)
         except OSError as exc:
-            if exc.errno == errno.ENOENT:
-                raise xmlrpc.client.Fault(404, "Device-type '%s' was not found." % name)
-            else:
-                raise xmlrpc.client.Fault(400, "Unable to read health-check: %s" % exc.strerror)
+            raise xmlrpc.client.Fault(
+                400, "Unable to read health-check: %s" % exc.strerror
+            )
 
     def get_template(self, name):
         """
@@ -165,7 +180,7 @@ class SchedulerDeviceTypesAPI(ExposedV2API):
         """
         with contextlib.suppress(DeviceType.DoesNotExist):
             dt = DeviceType.objects.get(name=name)
-            if dt.owners_only and not dt.some_devices_visible_to(self.user):
+            if not dt.can_view(self.user):
                 raise xmlrpc.client.Fault(404, "Device-type '%s' was not found." % name)
 
         # Filename should not be a path or starting with a dot
@@ -173,15 +188,16 @@ class SchedulerDeviceTypesAPI(ExposedV2API):
             raise xmlrpc.client.Fault(400, "Invalid device-type '%s'" % name)
 
         try:
-            filename = os.path.join("/etc/lava-server/dispatcher-config/device-types", name)
-            filename += ".jinja2" if not filename.endswith('.jinja2') else ''
+            filename = os.path.join(settings.DEVICE_TYPES_PATH, name)
+            filename += ".jinja2" if not filename.endswith(".jinja2") else ""
             with open(filename, "r") as f_in:
                 return xmlrpc.client.Binary(f_in.read().encode("utf-8"))
+        except FileNotFoundError:
+            raise xmlrpc.client.Fault(404, "Device-type '%s' was not found." % name)
         except OSError as exc:
-            if exc.errno == errno.ENOENT:
-                raise xmlrpc.client.Fault(404, "Device-type '%s' was not found." % name)
-            else:
-                raise xmlrpc.client.Fault(400, "Unable to read device-type configuration: %s" % exc.strerror)
+            raise xmlrpc.client.Fault(
+                400, "Unable to read device-type configuration: %s" % exc.strerror
+            )
 
     @check_perm("lava_scheduler_app.change_devicetype")
     def set_health_check(self, name, config):
@@ -217,13 +233,16 @@ class SchedulerDeviceTypesAPI(ExposedV2API):
             raise xmlrpc.client.Fault(400, "Invalid device-type '%s'" % name)
 
         try:
-            filename = os.path.join("/etc/lava-server/dispatcher-config/health-checks", name)
-            filename += ".yaml" if not filename.endswith('.yaml') else ''
+            filename = os.path.join(
+                "/etc/lava-server/dispatcher-config/health-checks", name
+            )
+            filename += ".yaml" if not filename.endswith(".yaml") else ""
             with open(filename, "w") as f_out:
                 f_out.write(config)
         except OSError as exc:
             raise xmlrpc.client.Fault(
-                400, "Unable to write health-check: %s" % exc.strerror)
+                400, "Unable to write health-check: %s" % exc.strerror
+            )
 
     @check_perm("lava_scheduler_app.change_devicetype")
     def set_template(self, name, config):
@@ -259,13 +278,14 @@ class SchedulerDeviceTypesAPI(ExposedV2API):
             raise xmlrpc.client.Fault(400, "Invalid device-type '%s'" % name)
 
         try:
-            filename = os.path.join("/etc/lava-server/dispatcher-config/device-types", name)
-            filename += ".jinja2" if not filename.endswith('.jinja2') else ''
+            filename = os.path.join(settings.DEVICE_TYPES_PATH, name)
+            filename += ".jinja2" if not filename.endswith(".jinja2") else ""
             with open(filename, "w") as f_out:
                 f_out.write(config)
         except OSError as exc:
             raise xmlrpc.client.Fault(
-                400, "Unable to write device-type configuration: %s" % exc.strerror)
+                400, "Unable to write device-type configuration: %s" % exc.strerror
+            )
 
     def list(self, show_all=False):
         """
@@ -288,22 +308,35 @@ class SchedulerDeviceTypesAPI(ExposedV2API):
         This function returns an XML-RPC array of device-types
         """
         available_types = self._available_device_types()
-        device_types = [dt for dt in DeviceType.objects.all().order_by('name')
-                        if not dt.owners_only or dt.some_devices_visible_to(self.user)]
+
+        device_types = [
+            dt
+            for dt in DeviceType.objects.all()
+            .visible_by_user(self.user)
+            .order_by("name")
+        ]
         ret = []
         for dt in device_types:
-            ret.append({"name": dt.name,
-                        "devices": dt.device_set.count(),
-                        "installed": True,
-                        "template": dt.name in available_types})
+            ret.append(
+                {
+                    "name": dt.name,
+                    "devices": dt.device_set.count(),
+                    "installed": True,
+                    "template": dt.name in available_types,
+                }
+            )
         if show_all:
             device_type_names = [dt.name for dt in device_types]
             for dt_name in available_types:
                 if dt_name not in device_type_names:
-                    ret.append({"name": dt_name,
-                                "devices": 0,
-                                "installed": False,
-                                "template": True})
+                    ret.append(
+                        {
+                            "name": dt_name,
+                            "devices": 0,
+                            "installed": False,
+                            "template": True,
+                        }
+                    )
         return ret
 
     def show(self, name):
@@ -329,33 +362,41 @@ class SchedulerDeviceTypesAPI(ExposedV2API):
         try:
             dt = DeviceType.objects.get(name=name)
         except DeviceType.DoesNotExist:
-            raise xmlrpc.client.Fault(
-                404, "Device-type '%s' was not found." % name)
-
-        if dt.owners_only and not dt.some_devices_visible_to(self.user):
-            raise xmlrpc.client.Fault(
-                404, "Device-type '%s' was not found." % name)
+            raise xmlrpc.client.Fault(404, "Device-type '%s' was not found." % name)
+        if not dt.can_view(self.user):
+            raise xmlrpc.client.Fault(404, "Device-type '%s' was not found." % name)
 
         aliases = [str(alias.name) for alias in dt.aliases.all()]
-        devices = [str(d.hostname) for d in dt.device_set.all() if d.is_visible_to(self.user)]
-        dt_dict = {"name": dt.name,
-                   "description": dt.description,
-                   "display": dt.display,
-                   "owners_only": dt.owners_only,
-                   "health_disabled": dt.disable_health_check,
-                   "aliases": aliases,
-                   "devices": devices}
+        devices = [
+            str(d.hostname) for d in dt.device_set.all() if d.can_view(self.user)
+        ]
+        dt_dict = {
+            "name": dt.name,
+            "description": dt.description,
+            "display": dt.display,
+            "health_disabled": dt.disable_health_check,
+            "aliases": aliases,
+            "devices": devices,
+        }
 
         return dt_dict
 
-    @check_perm("lava_scheduler_app.change_devicetype")
-    def update(self, name, description, display, owners_only, health_frequency,
-               health_denominator, health_disabled):
+    def update(
+        self,
+        name,
+        description,
+        display,
+        owners_only,
+        health_frequency,
+        health_denominator,
+        health_disabled,
+    ):
         """
         Name
         ----
         `scheduler.device_types.update` (`name`, `description=None`,
-                                         `display=None`, `owners_only=None`,
+                                         `display=None`,
+                                         `owners_only=None`,
                                          `health_frequency=None`,
                                          `health_denominator=None`,
                                          `health_disabled=None`)
@@ -374,7 +415,7 @@ class SchedulerDeviceTypesAPI(ExposedV2API):
         `display`: bool
           Is the device-type displayed in the GUI?
         `owners_only`: bool
-          Hide this device type for all users except owners of devices of this type.
+          DEPRECATED: this field is not used any more
         `health_frequency`: int
           How often to run health checks
         `health_denominator`: string ("hours" or "jobs")
@@ -389,8 +430,11 @@ class SchedulerDeviceTypesAPI(ExposedV2API):
         try:
             dt = DeviceType.objects.get(name=name)
         except DeviceType.DoesNotExist:
+            raise xmlrpc.client.Fault(404, "Device-type '%s' was not found." % name)
+        if not dt.can_change(self.user):
             raise xmlrpc.client.Fault(
-                404, "Device-type '%s' was not found." % name)
+                403, "No 'admin' permissions for device-type '%s'." % name
+            )
 
         if description is not None:
             dt.description = description
@@ -398,9 +442,6 @@ class SchedulerDeviceTypesAPI(ExposedV2API):
         if display is not None:
             dt.display = display
 
-        if owners_only is not None:
-            dt.owners_only = owners_only
-
         if health_frequency is not None:
             dt.health_frequency = health_frequency
 
@@ -411,7 +452,8 @@ class SchedulerDeviceTypesAPI(ExposedV2API):
                 health_denominator = DeviceType.HEALTH_PER_JOB
             else:
                 raise xmlrpc.client.Fault(
-                    400, "Bad request: invalid health_denominator.")
+                    400, "Bad request: invalid health_denominator."
+                )
 
             dt.health_denominator = health_denominator
 
@@ -422,9 +464,7 @@ class SchedulerDeviceTypesAPI(ExposedV2API):
 
 
 class SchedulerDeviceTypesAliasesAPI(ExposedV2API):
-
     @check_perm("lava_scheduler_app.add_alias")
-    @check_perm("lava_scheduler_app.change_devicetype")
     def add(self, name, alias):
         """
         Name
@@ -450,12 +490,14 @@ class SchedulerDeviceTypesAliasesAPI(ExposedV2API):
         try:
             dt = DeviceType.objects.get(name=name)
         except DeviceType.DoesNotExist:
+            raise xmlrpc.client.Fault(404, "Device-type '%s' was not found." % name)
+        if not dt.can_change(self.user):
             raise xmlrpc.client.Fault(
-                404, "DeviceType '%s' was not found." % name)
+                403, "No 'admin' permissions for device-type '%s'." % name
+            )
 
         alias_obj, _ = Alias.objects.get_or_create(name=alias)
         dt.aliases.add(alias_obj)
-        dt.save()
 
     def list(self, name):
         """
@@ -479,16 +521,11 @@ class SchedulerDeviceTypesAliasesAPI(ExposedV2API):
         try:
             dt = DeviceType.objects.get(name=name)
         except DeviceType.DoesNotExist:
-            raise xmlrpc.client.Fault(
-                404, "DeviceType '%s' was not found." % name)
-
-        if dt.owners_only and not dt.some_devices_visible_to(self.user):
-            raise xmlrpc.client.Fault(
-                404, "Device-type '%s' was not found." % name)
-
+            raise xmlrpc.client.Fault(404, "Device-type '%s' was not found." % name)
+        if not dt.can_view(self.user):
+            raise xmlrpc.client.Fault(404, "Device-type '%s' was not found." % name)
         return [a.name for a in dt.aliases.all().order_by("name")]
 
-    @check_perm("lava_scheduler_app.change_devicetype")
     def delete(self, name, alias):
         """
         Name
@@ -513,14 +550,15 @@ class SchedulerDeviceTypesAliasesAPI(ExposedV2API):
         try:
             dt = DeviceType.objects.get(name=name)
         except DeviceType.DoesNotExist:
+            raise xmlrpc.client.Fault(404, "Device-type '%s' was not found." % name)
+        if not dt.can_change(self.user):
             raise xmlrpc.client.Fault(
-                404, "DeviceType '%s' was not found." % name)
+                403, "No 'admin' permissions for device-type '%s'." % name
+            )
 
         try:
             alias_obj = Alias.objects.get(name=alias)
         except Alias.DoesNotExist:
-            raise xmlrpc.client.Fault(
-                404, "Alias '%s' was not found." % name)
+            raise xmlrpc.client.Fault(404, "Alias '%s' was not found." % alias)
 
         dt.aliases.remove(alias_obj)
-        dt.save()
