@@ -19,10 +19,15 @@
 
 import os
 from datetime import datetime, timedelta
-import pytz
+import voluptuous
 import xmlrpc.client
-from django.utils import timezone
+import yaml
+
+from django.conf import settings
+
 from linaro_django_xmlrpc.models import ExposedV2API
+
+import lava_common.schemas as schemas
 from lava_scheduler_app.api import SchedulerAPI
 from lava_scheduler_app.logutils import read_logs
 from lava_scheduler_app.models import TestJob
@@ -141,8 +146,7 @@ class SchedulerJobsAPI(ExposedV2API):
 
         if job.is_multinode:
             return job.multinode_definition
-        else:
-            return job.original_definition
+        return job.original_definition
 
     def list(self, state=None, health=None, start=0, limit=25, since=0, verbose=False):
         """
@@ -191,7 +195,9 @@ class SchedulerJobsAPI(ExposedV2API):
         ret = []
         start = max(0, start)
         limit = min(limit, 100)
-        jobs = TestJob.objects.all()
+        jobs = TestJob.objects.visible_by_user(self.user).select_related(
+            "requested_device_type", "submitter"
+        )
         if state:
             try:
                 jobs = jobs.filter(state=TestJob.STATE_REVERSE[state.capitalize()])
@@ -208,15 +214,7 @@ class SchedulerJobsAPI(ExposedV2API):
             end_time = datetime.now()
             # search back in time
             start_time = end_time - timedelta(minutes=since)
-            try:
-                jobs = jobs.filter(end_time__range=[start_time, end_time])
-            except TestJob.DoesNotExist:
-                raise xmlrpc.client.Fault(
-                    404, "No jobs exist since %s minutes ago" % since
-                )
-
-        if not jobs:
-            raise xmlrpc.client.Fault(404, "No jobs match the specified criteria.")
+            jobs = jobs.filter(end_time__range=[start_time, end_time])
 
         for job in jobs.order_by("-id")[start : start + limit]:
             device_type = None
@@ -266,6 +264,59 @@ class SchedulerJobsAPI(ExposedV2API):
 
         return ret
 
+    def queue(self, device_types=None, start=0, limit=25):
+        """
+        Name
+        ----
+        `scheduler.jobs.queue` (`device_types=None`, `start=0`, `limit=25`)
+
+        Description
+        -----------
+        List the queued jobs (state.SUBMITTED), within the specified range,
+        in descending order of job ID.
+        Jobs can be filtered by `requested_device_type` (if provided).
+
+        Arguments
+        ---------
+        `device_types`: Array of str
+          If provided, list jobs whose requested_device_type match any of the
+          provided device-types. None by default (no filtering).
+        `start`: int
+          Skip the first N job(s) in the list
+        `limit`: int
+          Max number of jobs to return.
+          This value will be clamped to 100
+
+        Return value
+        ------------
+        This function returns an array of jobs with keys:
+            "id", "description", "requested_device_type", "submitter"
+
+        If no queued test jobs exist to match the criteria, an empty array
+        is returned.
+        """
+        ret = []
+        start = max(0, start)
+        limit = min(limit, 100)
+        jobs = (
+            TestJob.objects.filter(state=TestJob.STATE_SUBMITTED)
+            .visible_by_user(self.user)
+            .select_related("requested_device_type", "submitter")
+        )
+        if device_types is not None:
+            jobs = jobs.filter(requested_device_type__name__in=device_types)
+
+        for job in jobs.order_by("-id")[start : start + limit]:
+            data = {
+                "id": job.display_id,
+                "description": job.description,
+                "requested_device_type": job.requested_device_type.name,
+                "submitter": job.submitter.username,
+            }
+            ret.append(data)
+
+        return ret
+
     def logs(self, job_id, start=0, end=None):
         """
         Name
@@ -344,6 +395,14 @@ class SchedulerJobsAPI(ExposedV2API):
         device_type = None
         if job.requested_device_type is not None:
             device_type = job.requested_device_type.name
+        if job.is_public:
+            visibility = "Public"
+        elif job.viewing_groups.count() == 0:
+            visibility = "Personal"
+        else:
+            visibility = "Group (%s)" % ", ".join(
+                [g.name for g in job.viewing_groups.all()]
+            )
 
         return {
             "id": job.display_id,
@@ -359,7 +418,7 @@ class SchedulerJobsAPI(ExposedV2API):
             "start_time": job.start_time,
             "end_time": job.end_time,
             "tags": [t.name for t in job.tags.all()],
-            "visibility": job.get_visibility_display(),
+            "visibility": visibility,
             "failure_comment": job.failure_comment,
         }
 
@@ -411,3 +470,37 @@ class SchedulerJobsAPI(ExposedV2API):
         """
         cls = SchedulerAPI(self._context)
         return cls.submit_job(definition)
+
+    def validate(self, definition, strict=False):
+        """
+        Name
+        ----
+        `scheduler.jobs.validate` (`definition`, `strict=False`)
+
+        Description
+        -----------
+        Validate the given job definition against the schema validator.
+
+        Arguments
+        ---------
+        `definition`: string
+            Job YAML string.
+        `strict`: boolean
+            If set to True, the validator will reject any extra keys that are
+            present in the job definition but not defined in the schema.
+
+        Return value
+        ------------
+        This function returns None if the job definition is valid. Returns a
+        dictionary in case of error with the key and msg.
+        """
+        data = yaml.safe_load(definition)
+        try:
+            schemas.validate(
+                data,
+                strict=strict,
+                extra_context_variables=settings.EXTRA_CONTEXT_VARIABLES,
+            )
+            return {}
+        except voluptuous.Invalid as exc:
+            return {"path": str(exc.path), "msg": exc.msg}
