@@ -17,7 +17,8 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with LAVA.  If not, see <http://www.gnu.org/licenses/>.
 
-import os
+import contextlib
+import pathlib
 import xmlrpc.client
 
 from django.db import IntegrityError, transaction
@@ -28,7 +29,6 @@ from lava_scheduler_app.models import Worker
 
 
 class SchedulerWorkersAPI(ExposedV2API):
-
     @check_perm("lava_scheduler_app.add_worker")
     def add(self, hostname, description=None, disabled=False):
         """
@@ -56,12 +56,11 @@ class SchedulerWorkersAPI(ExposedV2API):
         """
         try:
             health = Worker.HEALTH_RETIRED if disabled else Worker.HEALTH_ACTIVE
-            Worker.objects.create(hostname=hostname,
-                                  description=description,
-                                  health=health)
-        except IntegrityError as exc:
-            raise xmlrpc.client.Fault(
-                400, "Bad request: %s" % exc.message)
+            Worker.objects.create(
+                hostname=hostname, description=description, health=health
+            )
+        except IntegrityError:
+            raise xmlrpc.client.Fault(400, "Bad request: worker already exists?")
 
     def get_config(self, hostname):
         """
@@ -72,6 +71,9 @@ class SchedulerWorkersAPI(ExposedV2API):
         Description
         -----------
         Return the worker configuration
+        The server will first try
+        /etc/lava-server/dispatcher.d/<hostname>/dispatcher.yaml and fallback to
+        /etc/lava-server/dispatcher.d/<hostname>.yaml
 
         Arguments
         ---------
@@ -82,20 +84,75 @@ class SchedulerWorkersAPI(ExposedV2API):
         ------------
         This function returns the worker configuration
         """
+        # Sanitize hostname as we will use it in a path
+        if len(pathlib.Path(hostname).parts) != 1:
+            raise xmlrpc.client.Fault(400, "Invalid worker name")
+
+        # Find the worker in the database
         try:
             Worker.objects.get(hostname=hostname)
         except Worker.DoesNotExist:
-            raise xmlrpc.client.Fault(
-                404, "Worker '%s' was not found." % hostname)
+            raise xmlrpc.client.Fault(404, "Worker '%s' was not found." % hostname)
 
-        filename = os.path.join("/etc/lava-server/dispatcher.d",
-                                "%s.yaml" % hostname)
+        base = pathlib.Path("/etc/lava-server/dispatcher.d")
+        with contextlib.suppress(OSError):
+            data = (base / hostname / "dispatcher.yaml").read_text(encoding="utf-8")
+            return xmlrpc.client.Binary(data.encode("utf-8"))
+
+        with contextlib.suppress(OSError):
+            data = (base / ("%s.yaml" % hostname)).read_text(encoding="utf-8")
+            return xmlrpc.client.Binary(data.encode("utf-8"))
+
+        raise xmlrpc.client.Fault(
+            404, "Worker '%s' does not have a configuration" % hostname
+        )
+
+    def get_env(self, hostname):
+        """
+        Name
+        ----
+        `scheduler.workers.get_env` (`hostname`)
+
+        Description
+        -----------
+        Return the worker environment
+        The server will first try
+        /etc/lava-server/dispatcher.d/<hostname>/env.yaml and fallback to
+        /etc/lava-server/env.yaml
+
+        Arguments
+        ---------
+        `hostname`: string
+          Hostname of the worker
+
+        Return value
+        ------------
+        This function returns the worker environment
+        """
+        # Sanitize hostname as we will use it in a path
+        if len(pathlib.Path(hostname).parts) != 1:
+            raise xmlrpc.client.Fault(400, "Invalid worker name")
+
+        # Find the worker in the database
         try:
-            with open(filename, "r") as f_in:
-                return xmlrpc.client.Binary(f_in.read().encode('utf-8'))
-        except OSError:
-            raise xmlrpc.client.Fault(
-                404, "Worker '%s' does not have a configuration" % hostname)
+            Worker.objects.get(hostname=hostname)
+        except Worker.DoesNotExist:
+            raise xmlrpc.client.Fault(404, "Worker '%s' was not found." % hostname)
+
+        base = pathlib.Path("/etc/lava-server/")
+        with contextlib.suppress(OSError):
+            data = (base / "dispatcher.d" / hostname / "env.yaml").read_text(
+                encoding="utf-8"
+            )
+            return xmlrpc.client.Binary(data.encode("utf-8"))
+
+        with contextlib.suppress(OSError):
+            data = (base / "env.yaml").read_text(encoding="utf-8")
+            return xmlrpc.client.Binary(data.encode("utf-8"))
+
+        raise xmlrpc.client.Fault(
+            404, "Worker '%s' does not have a configuration" % hostname
+        )
 
     @check_perm("lava_scheduler_app.change_worker")
     def set_config(self, hostname, config):
@@ -106,7 +163,6 @@ class SchedulerWorkersAPI(ExposedV2API):
 
         Description
         -----------
-        [superuser only]
         Set the worker configuration
 
         Arguments
@@ -120,20 +176,63 @@ class SchedulerWorkersAPI(ExposedV2API):
         ------------
         True if the configuration was saved to file, False otherwise.
         """
+        # Sanitize hostname as we will use it in a path
+        if len(pathlib.Path(hostname).parts) != 1:
+            raise xmlrpc.client.Fault(400, "Invalid worker name")
+
         try:
             Worker.objects.get(hostname=hostname)
         except Worker.DoesNotExist:
-            raise xmlrpc.client.Fault(
-                404, "Worker '%s' was not found." % hostname)
+            raise xmlrpc.client.Fault(404, "Worker '%s' was not found." % hostname)
+
+        path = (
+            pathlib.Path("/etc/lava-server/dispatcher.d") / hostname / "dispatcher.yaml"
+        )
+        with contextlib.suppress(OSError):
+            path.parent.mkdir(mode=0o755, parents=True, exist_ok=True)
+            path.write_text(config, encoding="utf-8")
+            return True
+
+        return False
+
+    @check_perm("lava_scheduler_app.change_worker")
+    def set_env(self, hostname, env):
+        """
+        Name
+        ----
+        `scheduler.workers.set_env` (`hostname`, `env`)
+
+        Description
+        -----------
+        Set the worker environment
+
+        Arguments
+        ---------
+        `hostname`: string
+          Hostname of the worker
+        `env`: string
+          The worker environment as a yaml file
+
+        Return value
+        ------------
+        True if the environment was saved to file, False otherwise.
+        """
+        # Sanitize hostname as we will use it in a path
+        if len(pathlib.Path(hostname).parts) != 1:
+            raise xmlrpc.client.Fault(400, "Invalid worker name")
 
-        filename = os.path.join("/etc/lava-server/dispatcher.d",
-                                "%s.yaml" % hostname)
         try:
-            with open(filename, "w") as f_out:
-                f_out.write(config)
-                return True
-        except OSError:
-            return False
+            Worker.objects.get(hostname=hostname)
+        except Worker.DoesNotExist:
+            raise xmlrpc.client.Fault(404, "Worker '%s' was not found." % hostname)
+
+        path = pathlib.Path("/etc/lava-server/dispatcher.d") / hostname / "env.yaml"
+        with contextlib.suppress(OSError):
+            path.parent.mkdir(mode=0o755, parents=True, exist_ok=True)
+            path.write_text(env, encoding="utf-8")
+            return True
+
+        return False
 
     def list(self):
         """
@@ -153,7 +252,7 @@ class SchedulerWorkersAPI(ExposedV2API):
         ------------
         This function returns an XML-RPC array of workers
         """
-        workers = Worker.objects.all().order_by('hostname')
+        workers = Worker.objects.all().order_by("hostname")
         return [w.hostname for w in workers]
 
     def show(self, hostname):
@@ -179,15 +278,18 @@ class SchedulerWorkersAPI(ExposedV2API):
         try:
             worker = Worker.objects.get(hostname=hostname)
         except Worker.DoesNotExist:
-            raise xmlrpc.client.Fault(
-                404, "Worker '%s' was not found." % hostname)
+            raise xmlrpc.client.Fault(404, "Worker '%s' was not found." % hostname)
 
-        return {"hostname": worker.hostname,
-                "description": worker.description,
-                "state": worker.get_state_display(),
-                "health": worker.get_health_display(),
-                "devices": [d.hostname for d in worker.device_set.all().order_by("hostname")],
-                "last_ping": worker.last_ping}
+        return {
+            "hostname": worker.hostname,
+            "description": worker.description,
+            "state": worker.get_state_display(),
+            "health": worker.get_health_display(),
+            "devices": [
+                d.hostname for d in worker.device_set.all().order_by("hostname")
+            ],
+            "last_ping": worker.last_ping,
+        }
 
     @check_perm("lava_scheduler_app.change_worker")
     def update(self, hostname, description=None, health=None):
@@ -218,8 +320,7 @@ class SchedulerWorkersAPI(ExposedV2API):
             try:
                 worker = Worker.objects.select_for_update().get(hostname=hostname)
             except Worker.DoesNotExist:
-                raise xmlrpc.client.Fault(
-                    404, "Worker '%s' was not found." % hostname)
+                raise xmlrpc.client.Fault(404, "Worker '%s' was not found." % hostname)
 
             if description is not None:
                 worker.description = description
@@ -232,7 +333,6 @@ class SchedulerWorkersAPI(ExposedV2API):
                 elif health == "RETIRED":
                     worker.go_health_retired(self.user, "xmlrpc api")
                 else:
-                    raise xmlrpc.client.Fault(
-                        400, "Invalid health: %s" % health)
+                    raise xmlrpc.client.Fault(400, "Invalid health: %s" % health)
 
             worker.save()
