@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2018 Linaro Limited
+# Copyright (C) 2019 Linaro Limited
 #
 # Author: Remi Duraffort <remi.duraffort@linaro.org>
 #
@@ -18,18 +18,16 @@
 # along with LAVA.  If not, see <http://www.gnu.org/licenses/>.
 
 import contextlib
-import jinja2
 import logging
 import re
-import smtplib
-import socket
 
 from django.conf import settings
 from django.contrib.auth.models import User
 from django.core.mail import send_mail
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 from django.db import IntegrityError
 
+from lava_scheduler_app import dbutils
 from lava_scheduler_app import utils
 from lava_results_app.models import Query, TestCase, TestSuite
 from lava_scheduler_app.models import (
@@ -130,7 +128,7 @@ def create_callback(job, callback_data, notification):
 def get_notification_args(job):
     args = {}
     args["job"] = job
-    args["url_prefix"] = "http://%s" % utils.get_domain()
+    args["url_prefix"] = "http://%s" % dbutils.get_domain()
     # Get lava.job result if available
     with contextlib.suppress(TestCase.DoesNotExist):
         lava_job_obj = TestCase.objects.get(
@@ -260,7 +258,7 @@ def get_notification_args(job):
 def create_irc_notification(job):
     args = {}
     args["job"] = job
-    args["url_prefix"] = "http://%s" % utils.get_domain()
+    args["url_prefix"] = "http://%s" % dbutils.get_domain()
     return create_notification_body(Notification.DEFAULT_IRC_TEMPLATE, **args)
 
 
@@ -307,12 +305,7 @@ def send_notifications(job):
                     if result:
                         recipient.status = NotificationRecipient.SENT
                         recipient.save()
-                except (
-                    smtplib.SMTPRecipientsRefused,
-                    jinja2.exceptions.TemplateError,
-                    smtplib.SMTPSenderRefused,
-                    OSError,
-                ) as exc:
+                except Exception as exc:
                     logger.exception(exc)
                     logger.warning(
                         "[%d] failed to send email notification to %s",
