@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2018 Linaro Limited
+# Copyright (C) 2018-2019 Linaro Limited
 #
 # Author: Neil Williams <neil.williams@linaro.org>
 #         Remi Duraffort <remi.duraffort@linaro.org>
@@ -24,6 +24,7 @@ from voluptuous import (
     All,
     Any,
     Exclusive,
+    In,
     Invalid,
     Length,
     Match,
@@ -33,6 +34,10 @@ from voluptuous import (
     Schema,
 )
 
+from lava_common.schemas import CONTEXT_VARIABLES
+
+from django.conf import settings
+
 INVALID_CHARACTER_ERROR_MSG = "Invalid character"
 
 
@@ -101,15 +106,8 @@ def _simple_params():
 
 
 def _context_schema():
-    return Schema(
-        {
-            Optional("arch"): str,
-            Optional("memory"): int,
-            Optional("netdevice"): str,
-            Optional("extra_options"): list,
-        },
-        extra=True,
-    )
+    context_variables = CONTEXT_VARIABLES + settings.EXTRA_CONTEXT_VARIABLES
+    return Schema({In(context_variables): Any(int, str, [int, str])}, extra=False)
 
 
 def _job_boot_schema():
@@ -181,8 +179,61 @@ def _monitor_def_schema():
     )
 
 
+def _job_interactive_schema():
+    return Schema(
+        {
+            Required("interactive"): _interactive_def_schema(),
+            Optional("timeout"): _timeout_schema(),
+        },
+        extra=True,
+    )
+
+
+def _interactive_def_schema():
+    return Schema(
+        [
+            {
+                Required("name"): Match(
+                    r"^[a-zA-Z0-9-_]+$", msg=INVALID_CHARACTER_ERROR_MSG
+                ),
+                Required("prompts"): list,
+                Required("script"): _interactive_script_schema(),
+            }
+        ]
+    )
+
+
+def _interactive_script_schema():
+    return Schema(
+        [
+            {
+                Optional("name"): Match(
+                    r"^[a-zA-Z0-9-_]+$", msg=INVALID_CHARACTER_ERROR_MSG
+                ),
+                Required("command"): Any(None, str),
+                Optional("failures"): [
+                    {
+                        Required("message"): str,
+                        Optional("exception"): Any(
+                            "InfrastructureError", "JobError", "TestError"
+                        ),
+                        Optional("error"): str,
+                    }
+                ],
+                Optional("successes"): [{Required("message"): str}],
+            }
+        ]
+    )
+
+
 def _job_command_schema():
-    return Schema({Required("name"): str, Optional("timeout"): _timeout_schema()})
+    return Schema(
+        {
+            Required("name"): str,
+            Optional("timeout"): _timeout_schema(),
+            Optional("namespace"): str,
+        }
+    )
 
 
 def _job_actions_schema():
@@ -191,7 +242,9 @@ def _job_actions_schema():
             {
                 "deploy": Any(_deploy_tftp_schema(), _job_deploy_schema()),
                 "boot": _job_boot_schema(),
-                "test": Any(_job_monitor_schema(), _job_test_schema()),
+                "test": Any(
+                    _job_monitor_schema(), _job_interactive_schema(), _job_test_schema()
+                ),
                 "command": _job_command_schema(),
             }
         ]
@@ -282,6 +335,7 @@ def _validate_multinode(data_object):
 
     # List the roles
     roles = list(multi["roles"].keys())
+    context_schema = _context_schema()
     # Check that "host_role" and "expect_role" does exist
     for role in roles:
         host_role = multi["roles"][role].get("host_role")
@@ -299,6 +353,9 @@ def _validate_multinode(data_object):
                 )
         elif expect_role is not None:
             raise SubmissionException("'expect_role' without 'host_role'")
+        # Check context
+        context = multi["roles"][role].get("context", {})
+        context_schema(context)
 
 
 def _job_protocols_schema():
@@ -420,6 +477,7 @@ def _device_schema():
             "device_info": [dict],
             "static_info": [dict],
             "storage_info": [dict],
+            "environment": dict,
             "flash_cmds_order": list,
             "parameters": dict,
             "board_id": str,
