@@ -19,7 +19,6 @@
 # along with LAVA.  If not, see <http://www.gnu.org/licenses/>.
 
 import yaml
-import logging
 import random
 from django.contrib.admin.models import LogEntry
 from django.utils.html import escape
@@ -28,7 +27,7 @@ from django.utils.timesince import timesince
 import django_tables2 as tables
 from lava_results_app.models import TestCase
 from lava_scheduler_app.models import TestJob, Device, DeviceType, Worker
-from lava.utils.lavatable import LavaTable
+from lava_server.lavatable import LavaTable
 from django.db.models import Q
 from django.utils import timezone
 
@@ -65,13 +64,14 @@ class RestrictedIDLinkColumn(IDLinkColumn):
 
 
 def pklink(record):
-    job_id = record.pk
+    pk = record.pk
     if isinstance(record, TestJob):
         if record.sub_jobs_list:
-            job_id = record.sub_id
+            pk = record.sub_id
+    verbose_name = record._meta.verbose_name.capitalize()
     return mark_safe(  # nosec - internal data
-        '<a href="%s" title="job summary">%s</a>'
-        % (record.get_absolute_url(), escape(job_id))
+        '<a href="%s" title="%s summary">%s</a>'
+        % (record.get_absolute_url(), escape(verbose_name), escape(pk))
     )
 
 
@@ -86,7 +86,6 @@ class ExpandedStatusColumn(tables.Column):
         device is Reserved or Running. Logs error if reserved or running
         with no current job.
         """
-        logger = logging.getLogger("lava_scheduler_app")
         if record.state == Device.STATE_RUNNING:
             current_job = record.current_job()
             return mark_safe(  # nosec - internal data
@@ -114,64 +113,12 @@ class ExpandedStatusColumn(tables.Column):
             return record.get_simple_state_display()
 
 
-class RestrictedDeviceColumn(tables.Column):
-    def __init__(self, verbose_name="Submissions restricted to", **kw):
-        kw["verbose_name"] = verbose_name
-        super().__init__(**kw)
-
-    def render(self, record):
-        """
-        If the strings here are changed, ensure the strings in the restriction_query
-        are changed to match.
-        :param record: a database record
-        :return: a text string describing the restrictions on this device.
-        """
-        label = None
-        if record.health == Device.HEALTH_BAD:
-            return "Health check failed: no test jobs will be scheduled."
-        if record.health == Device.HEALTH_MAINTENANCE:
-            return "No test jobs will be scheduled."
-        if record.health == Device.HEALTH_RETIRED:
-            return "Retired: no submissions possible."
-        if record.is_public:
-            return ""
-        if record.user:
-            label = record.user.email
-        if record.group:
-            label = "group %s" % record.group
-        return label
-
-
-def all_jobs_with_custom_sort():
-    jobs = (
-        TestJob.objects.select_related(
-            "actual_device",
-            "actual_device__user",
-            "actual_device__group",
-            "actual_device__device_type",
-            "requested_device_type",
-            "submitter",
-            "user",
-            "group",
-        )
-        .extra(
-            select={
-                "device_sort": "coalesce("
-                "actual_device_id, "
-                "requested_device_type_id)",
-                "duration_sort": "date_trunc('second', end_time - start_time)",
-            }
-        )
-        .all()
-    )
+def visible_jobs_with_custom_sort(user):
+    jobs = TestJob.objects.visible_by_user(user)
     return jobs.order_by("-submit_time")
 
 
 class JobErrorsTable(LavaTable):
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-        self.length = 10
-
     job = tables.Column(verbose_name="Job", empty_values=[""])
     job.orderable = False
     end_time = tables.DateColumn(format="Nd, g:ia")
@@ -230,17 +177,16 @@ class JobTable(LavaTable):
     ensure those are copied into the new class.
     """
 
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-        self.length = 25
-
     id = tables.Column(verbose_name="ID")
     actions = tables.TemplateColumn(
         template_name="lava_scheduler_app/job_actions_field.html"
     )
     actions.orderable = False
-    device = tables.Column(accessor="device_sort")
-    duration = tables.Column(accessor="duration_sort")
+    device = tables.Column(accessor="actual_device", verbose_name="Device")
+    device_type = tables.Column(
+        accessor="requested_device_type", verbose_name="Device type"
+    )
+    duration = tables.Column()
     duration.orderable = False
     submit_time = tables.DateColumn(format="Nd, g:ia")
     end_time = tables.DateColumn(format="Nd, g:ia")
@@ -272,21 +218,23 @@ class JobTable(LavaTable):
                 % record.get_state_display()
             )
 
+    def render_device_type(self, record):
+        if record.requested_device_type:
+            return pklink(record.requested_device_type)
+        return record
+
     def render_device(self, record):
         if record.actual_device:
-            device_type = record.actual_device.device_type
             retval = pklink(record.actual_device)
-        elif record.requested_device_type:
-            device_type = record.requested_device_type
-            retval = mark_safe(  # nosec - internal data
-                "<i>%s</i>" % escape(record.requested_device_type.pk)
-            )
         elif record.dynamic_connection:
             return "connection"
         else:
             return "-"
-        if not device_type.some_devices_visible_to(self.context.get("request").user):
-            return "Unavailable"
+        device_type = None
+        if record.requested_device_type:
+            device_type = record.requested_device_type
+        if not device_type:
+            return "Error"
         return retval
 
     def render_description(self, value):  # pylint: disable=no-self-use
@@ -302,15 +250,12 @@ class JobTable(LavaTable):
         # alternatively, use 'fields' value to include specific fields.
         exclude = [
             "is_public",
-            "user",
-            "group",
             "sub_id",
             "target_group",
             "health_check",
             "definition",
             "original_definition",
             "multinode_definition",
-            "admin_notifications",
             "requested_device_type",
             "start_time",
             "log_file",
@@ -323,6 +268,7 @@ class JobTable(LavaTable):
             "state",
             "health",
             "device",
+            "device_type",
             "description",
             "submitter",
             "submit_time",
@@ -334,6 +280,7 @@ class JobTable(LavaTable):
             "actions",
             "state",
             "device",
+            "device_type",
             "description",
             "submitter",
             "submit_time",
@@ -345,6 +292,7 @@ class JobTable(LavaTable):
             "device_query": "device",  # active_device
             "owner_query": "submitter",  # submitter
             "job_state_query": "state",
+            "requested_device_type_query": "requested_device_type",
         }
         # fields which can be searched with default __contains queries
         # note the enums cannot be searched this way.
@@ -360,13 +308,30 @@ class IndexJobTable(JobTable):
         template_name="lava_scheduler_app/job_actions_field.html"
     )
     actions.orderable = False
-    device = tables.Column(accessor="device_sort")
     submit_time = tables.DateColumn("Nd, g:ia")
     end_time = tables.DateColumn("Nd, g:ia")
 
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-        self.length = 25
+    def render_health(self, record):
+        if record.health == Device.HEALTH_GOOD:
+            return mark_safe(  # nosec - internal data
+                '<strong class="text-success">Good</strong>'
+            )
+        elif record.health in [Device.HEALTH_UNKNOWN, Device.HEALTH_LOOPING]:
+            return mark_safe(  # nosec - internal data
+                '<span class="text-info">%s</span>' % record.get_health_display()
+            )
+        elif record.health == Device.HEALTH_BAD:
+            return mark_safe(  # nosec - internal data
+                '<span class="text-danger">Bad</span>'
+            )
+        elif record.health == Device.HEALTH_MAINTENANCE:
+            return mark_safe(  # nosec - internal data
+                '<span class="text-warning">Maintenance</span>'
+            )
+        else:
+            return mark_safe(  # nosec - internal data
+                '<span class="text-muted">Retired</span>'
+            )
 
     class Meta(
         JobTable.Meta
@@ -378,6 +343,8 @@ class IndexJobTable(JobTable):
             "health",
             "priority",
             "device",
+            "device_type",
+            "health",
             "description",
             "submitter",
             "submit_time",
@@ -388,6 +355,8 @@ class IndexJobTable(JobTable):
             "state",
             "priority",
             "device",
+            "device_type",
+            "health",
             "description",
             "submitter",
             "submit_time",
@@ -403,7 +372,7 @@ class TagsColumn(tables.Column):
         )
         tags = ""
         values = list(value.all())
-        if len(values) > 0:
+        if values:
             tags = '<p class="collapse" id="%s">' % tag_id
             tags += ",<br>".join(
                 '<abbr data-toggle="tooltip" title="%s">%s</abbr>'
@@ -424,18 +393,14 @@ class FailedJobTable(JobTable):
         template_name="lava_scheduler_app/job_actions_field.html"
     )
     actions.orderable = False
-    device = tables.Column(accessor="device_sort")
-    duration = tables.Column(accessor="duration_sort")
+    device = tables.Column(accessor="actual_device")
+    duration = tables.Column()
     duration.orderable = False
     failure_tags = TagsColumn()
     failure_comment = tables.Column(empty_values=())
     submit_time = tables.DateColumn("Nd, g:ia")
     end_time = tables.DateColumn("Nd, g:ia")
 
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-        self.length = 10
-
     def render_failure_comment(self, record):
         if record.failure_comment:
             return record.failure_comment
@@ -485,10 +450,6 @@ class LongestJobTable(JobTable):
     running = tables.Column(accessor="start_time", verbose_name="Running")
     running.orderable = False
 
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-        self.length = 10
-
     def render_running(self, record):  # pylint: disable=no-self-use
         if not record.start_time:
             return ""
@@ -515,16 +476,12 @@ class OverviewJobsTable(JobTable):
         template_name="lava_scheduler_app/job_actions_field.html"
     )
     actions.orderable = False
-    device = tables.Column(accessor="device_sort")
-    duration = tables.Column(accessor="duration_sort")
+    device = tables.Column(accessor="actual_device", verbose_name="Device")
+    duration = tables.Column()
     duration.orderable = False
     submit_time = tables.DateColumn("Nd, g:ia")
     end_time = tables.DateColumn("Nd, g:ia")
 
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-        self.length = 10
-
     class Meta(
         JobTable.Meta
     ):  # pylint: disable=too-few-public-methods,no-init,no-self-use
@@ -538,7 +495,8 @@ class OverviewJobsTable(JobTable):
             "end_time",
             "duration",
         )
-        sequence = ("id", "actions")
+        sequence = ("id", "actions", "device")
+        exclude = ("device_type",)
 
 
 class RecentJobsTable(JobTable):
@@ -549,16 +507,11 @@ class RecentJobsTable(JobTable):
         template_name="lava_scheduler_app/job_actions_field.html"
     )
     actions.orderable = False
-    device = tables.Column(accessor="device_sort")
-    duration = tables.Column(accessor="duration_sort")
+    duration = tables.Column()
     duration.orderable = False
     submit_time = tables.DateColumn("Nd, g:ia")
     end_time = tables.DateColumn("Nd, g:ia")
 
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-        self.length = 10
-
     class Meta(
         JobTable.Meta
     ):  # pylint: disable=too-few-public-methods,no-init,no-self-use
@@ -581,14 +534,10 @@ class RecentJobsTable(JobTable):
             "end_time",
             "duration",
         )
-        exclude = ("device",)
+        exclude = ("device", "device_type", "actual_device", "requested_device_type")
 
 
 class DeviceHealthTable(LavaTable):
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-        self.length = 25
-
     def render_last_health_report_job(self, record):  # pylint: disable=no-self-use
         report = record.last_health_report_job
         if report is None:
@@ -627,10 +576,6 @@ class DeviceHealthTable(LavaTable):
 
 
 class DeviceTypeTable(LavaTable):
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-        self.length = 50
-
     def render_idle(self, record):  # pylint: disable=no-self-use
         return record["idle"] if record["idle"] > 0 else ""
 
@@ -640,9 +585,6 @@ class DeviceTypeTable(LavaTable):
     def render_busy(self, record):  # pylint: disable=no-self-use
         return record["busy"] if record["busy"] > 0 else ""
 
-    def render_restricted(self, record):  # pylint: disable=no-self-use
-        return record["restricted"] if record["restricted"] > 0 else ""
-
     def render_name(self, record):  # pylint: disable=no-self-use
         return pklink(DeviceType.objects.get(name=record["device_type"]))
 
@@ -659,7 +601,6 @@ class DeviceTypeTable(LavaTable):
     idle = tables.Column()
     offline = tables.Column()
     busy = tables.Column()
-    restricted = tables.Column()
     # sadly, this needs to be not orderable as it would otherwise sort by the accessor.
     queue = tables.Column(accessor="idle", verbose_name="Queue", orderable=False)
 
@@ -670,7 +611,6 @@ class DeviceTypeTable(LavaTable):
         exclude = [
             "display",
             "disable_health_check",
-            "owners_only",
             "architecture",
             "health_denominator",
             "health_frequency",
@@ -684,16 +624,12 @@ class DeviceTypeTable(LavaTable):
 
 
 class DeviceTable(LavaTable):
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-        self.length = 50
-
     def render_device_type(self, record):  # pylint: disable=no-self-use
         return pklink(record.device_type)
 
     def render_worker_host(self, record):
         if not record.worker_host and record.health == Device.HEALTH_RETIRED:
-            return "..."
+            return mark_safe("<i>...</i>")  # nosec - internal data
         if not record.worker_host and record.health != Device.HEALTH_RETIRED:
             return mark_safe(  # nosec - internal data
                 '<span class="text-danger"><i>No worker</i> <span class="glyphicon glyphicon-fire"></span></span>'
@@ -751,8 +687,6 @@ class DeviceTable(LavaTable):
     )
     device_type = tables.Column()
     state = ExpandedStatusColumn("state")
-    owner = RestrictedDeviceColumn()
-    owner.orderable = False
     health = tables.Column(verbose_name="Health")
     tags = TagsColumn()
 
@@ -761,9 +695,6 @@ class DeviceTable(LavaTable):
     ):  # pylint: disable=too-few-public-methods,no-init,no-self-use
         model = Device
         exclude = [
-            "user",
-            "group",
-            "is_public",
             "device_version",
             "physical_owner",
             "physical_group",
@@ -771,28 +702,19 @@ class DeviceTable(LavaTable):
             "current_job",
             "last_health_report_job",
         ]
-        sequence = [
-            "hostname",
-            "worker_host",
-            "device_type",
-            "state",
-            "health",
-            "owner",
-        ]
+        sequence = ["hostname", "worker_host", "device_type", "state", "health"]
         searches = {"hostname": "contains"}
         queries = {
             "device_type_query": "device_type",
             "device_state_query": "state",
             "device_health_query": "health",
-            "restriction_query": "restrictions",
             "tags_query": "tags",
         }
 
 
-class WorkerTable(tables.Table):  # pylint: disable=too-few-public-methods,no-init
+class WorkerTable(LavaTable):  # pylint: disable=too-few-public-methods,no-init
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
-        self.length = 10
         self.show_help = True
 
     hostname = tables.TemplateColumn(
@@ -845,11 +767,7 @@ class WorkerTable(tables.Table):  # pylint: disable=too-few-public-methods,no-in
         sequence = ["hostname", "state", "health", "description"]
 
 
-class LogEntryTable(tables.Table):
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-        self.length = 10
-
+class LogEntryTable(LavaTable):
     action_time = tables.DateColumn(format="Nd, g:ia")
     object_id = tables.Column(verbose_name="Name")
     change_message = tables.Column(verbose_name="Reason", empty_values=[None])
@@ -888,9 +806,6 @@ class NoWorkerDeviceTable(DeviceTable):
     ):  # pylint: disable=too-few-public-methods,no-init,no-self-use
         exclude = [
             "worker_host",
-            "user",
-            "group",
-            "is_public",
             "device_version",
             "physical_owner",
             "physical_group",
@@ -921,8 +836,19 @@ class QueueJobsTable(JobTable):
     actions = tables.TemplateColumn(
         template_name="lava_scheduler_app/job_actions_field.html"
     )
+
+    def render_requested_device_type(self, record):  # pylint: disable=no-self-use
+        return mark_safe(  # nosec - internal data
+            '<a href="%s" title="%s device_type">%s</a>'
+            % (
+                record.requested_device_type.get_absolute_url(),
+                record.requested_device_type,
+                record.requested_device_type,
+            )
+        )
+
     actions.orderable = False
-    device = tables.Column(accessor="device_sort")
+    requested_device_type = tables.Column()
     in_queue = tables.TemplateColumn(
         """
     for {{ record.submit_time|timesince }}
@@ -932,17 +858,11 @@ class QueueJobsTable(JobTable):
     submit_time = tables.DateColumn("Nd, g:ia")
     end_time = tables.DateColumn("Nd, g:ia")
 
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-        self.length = 50
-
-    class Meta(
-        JobTable.Meta
-    ):  # pylint: disable=too-few-public-methods,no-init,no-self-use
+    class Meta(JobTable.Meta):
         fields = (
             "id",
             "actions",
-            "device",
+            "requested_device_type",
             "description",
             "submitter",
             "submit_time",
@@ -951,20 +871,24 @@ class QueueJobsTable(JobTable):
         sequence = (
             "id",
             "actions",
-            "device",
+            "requested_device_type",
             "description",
             "submitter",
             "submit_time",
             "in_queue",
         )
-        exclude = ("state", "health", "priority", "end_time", "duration")
+        exclude = (
+            "state",
+            "health",
+            "priority",
+            "end_time",
+            "duration",
+            "device_type",
+            "device",
+        )
 
 
 class PassingHealthTable(DeviceHealthTable):
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-        self.length = 25
-
     def render_device_type(self, record):  # pylint: disable=no-self-use
         return pklink(record.device_type)
 
@@ -993,10 +917,6 @@ class RunningTable(LavaTable):
     any particular DeviceType.
     """
 
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-        self.length = 50
-
     # deprecated: dynamic connections are TestJob without a device
 
     def render_jobs(self, record):  # pylint: disable=no-self-use
@@ -1035,7 +955,6 @@ class RunningTable(LavaTable):
         exclude = [
             "display",
             "disable_health_check",
-            "owners_only",
             "architecture",
             "processor",
             "cpu_model",
