@@ -1,11 +1,11 @@
 import os
-import sys
 import yaml
 import jinja2
 import unittest
-import logging
 import subprocess  # nosec unit test support
-from nose.tools import nottest
+
+from lava_common.compat import yaml_safe_load
+from lava_common.decorators import nottest
 from lava_scheduler_app.models import (
     Device,
     DeviceType,
@@ -15,7 +15,7 @@ from lava_scheduler_app.models import (
     _pipeline_protocols,
 )
 from lava_scheduler_app.dbutils import match_vlan_interface
-from django.contrib.auth.models import Group, Permission, User
+from django.contrib.auth.models import User
 from lava_scheduler_app.utils import split_multinode_yaml
 from lava_scheduler_app.tests.test_submission import ModelFactory, TestCaseWithFactory
 from lava_scheduler_app.schema import (
@@ -23,14 +23,16 @@ from lava_scheduler_app.schema import (
     validate_device,
     SubmissionException,
 )
+
+from lava_common.compat import yaml_load
 from lava_dispatcher.device import PipelineDevice
 from lava_dispatcher.parser import JobParser
-from lava_dispatcher.test.test_defs import check_missing_path
+from lava_dispatcher.tests.test_defs import check_missing_path
 from lava_common.exceptions import JobError, InfrastructureError
 from lava_dispatcher.actions.boot.qemu import BootQEMU
 from lava_dispatcher.protocols.multinode import MultinodeProtocol
 from lava_common.constants import SYS_CLASS_KVM
-from lava_dispatcher.test.utils import DummyLogger
+from lava_dispatcher.tests.utils import DummyLogger
 from unittest import TestCase
 
 
@@ -47,46 +49,26 @@ class YamlFactory(ModelFactory):
     save a TestJob into the database. Hence qemu.yaml.
     """
 
-    def __init__(self):
-        super().__init__()
-        Device.CONFIG_PATH = os.path.join(
-            os.getcwd(), "lava_scheduler_app", "tests", "devices"
-        )
-        logging.basicConfig(stream=sys.stdout, level=logging.DEBUG)
-        logger = logging.getLogger("unittests")
-        logger.disabled = True
-        logger.propagate = False
-        logger = logging.getLogger("dispatcher")
-        logging.disable(logging.DEBUG)
-        logger.disabled = True
-        logger.propagate = False
-
     def make_device_type(self, name="qemu"):
 
         device_type = DeviceType.objects.get_or_create(name=name)[0]
         device_type.save()
         return device_type
 
-    def make_device(
-        self, device_type=None, hostname=None, tags=None, is_public=True, **kw
-    ):
+    def make_device(self, device_type=None, hostname=None, tags=None, **kw):
         if device_type is None:
             device_type = self.ensure_device_type()
         if hostname is None:
             hostname = self.getUniqueString()
         if tags and not isinstance(tags, list):
             tags = []
-        # a hidden device type will override is_public
-        device = Device(
-            device_type=device_type, is_public=is_public, hostname=hostname, **kw
-        )
+        device = Device(device_type=device_type, hostname=hostname, **kw)
         if tags:
-            device.tags = tags
+            device.tags.set(tags)
         if DEBUG:
             print(
-                "making a device of type %s %s %s with tags '%s'",
+                "making a device of type %s %s with tags '%s'",
                 device_type,
-                device.is_public,
                 device.hostname,
                 ", ".join([x.name for x in device.tags.all()]),
             )
@@ -95,10 +77,10 @@ class YamlFactory(ModelFactory):
 
     def make_job_data(self, actions=None, **kw):
         sample_job_file = os.path.join(
-            os.path.dirname(__file__), "devices", "qemu.yaml"
+            os.path.dirname(__file__), "sample_jobs", "qemu.yaml"
         )
         with open(sample_job_file, "r") as test_support:
-            data = yaml.safe_load(test_support)
+            data = yaml_safe_load(test_support)
         data.update(kw)
         return data
 
@@ -124,7 +106,7 @@ class PipelineDeviceTags(TestCaseWithFactory):
         }
 
     def test_make_job_yaml(self):
-        data = yaml.safe_load(self.factory.make_job_yaml())
+        data = yaml_safe_load(self.factory.make_job_yaml())
         self.assertIn("device_type", data)
         self.assertNotIn("timeout", data)
         self.assertIn("timeouts", data)
@@ -142,27 +124,25 @@ class PipelineDeviceTags(TestCaseWithFactory):
 
     def test_no_tags(self):
         self.factory.make_device(self.device_type, "fakeqemu3")
-        TestJob.from_yaml_and_user(
-            self.factory.make_job_yaml(), self.factory.make_user()
-        )
+        user = self.factory.make_user()
+        TestJob.from_yaml_and_user(self.factory.make_job_yaml(), user)
 
     def test_priority(self):
         self.factory.make_device(self.device_type, "fakeqemu3")
-        job = TestJob.from_yaml_and_user(
-            self.factory.make_job_yaml(), self.factory.make_user()
-        )
+        user = self.factory.make_user()
+        job = TestJob.from_yaml_and_user(self.factory.make_job_yaml(), user)
         self.assertEqual(TestJob.LOW, job.priority)
 
     def test_yaml_device_tags(self):
         Tag.objects.all().delete()
         tag_list = [self.factory.ensure_tag("usb"), self.factory.ensure_tag("sata")]
-        data = yaml.safe_load(self.factory.make_job_yaml(tags=["usb", "sata"]))
+        data = yaml_safe_load(self.factory.make_job_yaml(tags=["usb", "sata"]))
         validate_submission(data)
         device = self.factory.make_device(self.device_type, "fakeqemu4", tags=tag_list)
         job_ctx = data.get("context", {})
         device_config = device.load_configuration(job_ctx)  # raw dict
         validate_device(device_config)
-        self.assertTrue(device.is_valid(system=False))
+        self.assertTrue(device.is_valid())
         self.assertIn("tags", data)
         self.assertEqual(type(data["tags"]), list)
         self.assertIn("usb", data["tags"])
@@ -171,21 +151,22 @@ class PipelineDeviceTags(TestCaseWithFactory):
     def test_undefined_tags(self):
         Tag.objects.all().delete()
         self.factory.make_device(self.device_type, "fakeqemu1")
+        user = self.factory.make_user()
         self.assertRaises(
             yaml.YAMLError,
             TestJob.from_yaml_and_user,
             self.factory.make_job_yaml(tags=["tag1", "tag2"]),
-            self.factory.make_user(),
+            user,
         )
 
     def test_from_yaml_unsupported_tags(self):
         self.factory.make_device(self.device_type, "fakeqemu1")
         self.factory.ensure_tag("usb")
         self.factory.ensure_tag("sata")
+        user = self.factory.make_user()
         try:
             TestJob.from_yaml_and_user(
-                self.factory.make_job_yaml(tags=["usb", "sata"]),
-                self.factory.make_user(),
+                self.factory.make_job_yaml(tags=["usb", "sata"]), user
             )
         except DevicesUnavailableException:
             pass
@@ -197,8 +178,9 @@ class PipelineDeviceTags(TestCaseWithFactory):
     def test_from_yaml_and_user_sets_multiple_tag_from_device_tags(self):
         tag_list = [self.factory.ensure_tag("tag1"), self.factory.ensure_tag("tag2")]
         self.factory.make_device(self.device_type, hostname="fakeqemu1", tags=tag_list)
+        user = self.factory.make_user()
         job = TestJob.from_yaml_and_user(
-            self.factory.make_job_yaml(tags=["tag1", "tag2"]), self.factory.make_user()
+            self.factory.make_job_yaml(tags=["tag1", "tag2"]), user
         )
         self.assertEqual(set(tag.name for tag in job.tags.all()), {"tag1", "tag2"})
 
@@ -208,11 +190,12 @@ class PipelineDeviceTags(TestCaseWithFactory):
         self.factory.make_device(
             device_type=self.device_type, hostname="fakeqemu1", tags=tags
         )
+        user = self.factory.make_user()
         job1 = TestJob.from_yaml_and_user(
-            self.factory.make_job_yaml(tags=["tag"]), self.factory.make_user()
+            self.factory.make_job_yaml(tags=["tag"]), user
         )
         job2 = TestJob.from_yaml_and_user(
-            self.factory.make_job_yaml(tags=["tag"]), self.factory.make_user()
+            self.factory.make_job_yaml(tags=["tag"]), user
         )
         self.assertEqual(
             set(tag.pk for tag in job1.tags.all()),
@@ -237,11 +220,12 @@ class PipelineDeviceTags(TestCaseWithFactory):
         self.factory.make_device(
             device_type=self.device_type, hostname="fakeqemu2", tags=tag_list
         )
+        user = self.factory.make_user()
         job = TestJob.from_yaml_and_user(
             self.factory.make_job_yaml(
                 tags=["common_tag1", "common_tag2", "unique_tag"]
             ),
-            self.factory.make_user(),
+            user,
         )
         self.assertEqual(set(tag for tag in job.tags.all()), set(tag_list))
 
@@ -256,7 +240,8 @@ class TestPipelineSubmit(TestCaseWithFactory):
 
     def test_from_yaml_and_user_sets_definition(self):
         definition = self.factory.make_job_yaml()
-        job = TestJob.from_yaml_and_user(definition, self.factory.make_user())
+        user = self.factory.make_user()
+        job = TestJob.from_yaml_and_user(definition, user)
         self.assertEqual(definition, job.definition)
 
     def test_from_yaml_and_user_sets_submitter(self):
@@ -276,10 +261,10 @@ class TestPipelineSubmit(TestCaseWithFactory):
         device = Device.objects.get(hostname="fakeqemu1")
         user = self.factory.make_user()
         job = TestJob.from_yaml_and_user(self.factory.make_job_yaml(), user)
-        job_def = yaml.safe_load(job.definition)
+        job_def = yaml_safe_load(job.definition)
         job_ctx = job_def.get("context", {})
         device_config = device.load_configuration(job_ctx)  # raw dict
-        self.assertTrue(device.is_valid(system=False))
+        self.assertTrue(device.is_valid())
         self.assertEqual(
             device_config["actions"]["boot"]["methods"]["qemu"]["parameters"][
                 "command"
@@ -287,7 +272,7 @@ class TestPipelineSubmit(TestCaseWithFactory):
             "qemu-system-x86_64",
         )
 
-        job_data = yaml.safe_load(self.factory.make_job_yaml())
+        job_data = yaml_safe_load(self.factory.make_job_yaml())
         job_data["context"].update({"netdevice": "tap"})
         job_ctx = job_data.get("context", {})
         device_config = device.load_configuration(job_ctx)  # raw dict
@@ -309,7 +294,7 @@ class TestPipelineSubmit(TestCaseWithFactory):
             "base_ip_args": "ip=dhcp",
         }
         device_config = device.load_configuration(job_ctx)  # raw dict
-        self.assertTrue(device.is_valid(system=False))
+        self.assertTrue(device.is_valid())
         self.assertIn("uefi-menu", device_config["actions"]["boot"]["methods"])
         self.assertIn("nfs", device_config["actions"]["boot"]["methods"]["uefi-menu"])
         menu_data = device_config["actions"]["boot"]["methods"]["uefi-menu"]["nfs"]
@@ -349,7 +334,7 @@ class TestPipelineSubmit(TestCaseWithFactory):
         )
 
     def test_metadata(self):
-        data = yaml.safe_load(self.factory.make_job_yaml(metadata={15: "test"}))
+        data = yaml_safe_load(self.factory.make_job_yaml(metadata={15: "test"}))
         validate_submission(data)
         metadata = {
             "build-url": None,
@@ -359,13 +344,13 @@ class TestPipelineSubmit(TestCaseWithFactory):
             "git-url": "https://git.linaro.org/zephyrproject-org/zephyr.git",
             "git-commit": 1234,
         }
-        data = yaml.safe_load(self.factory.make_job_yaml(metadata=metadata))
+        data = yaml_safe_load(self.factory.make_job_yaml(metadata=metadata))
         self.assertRaises(SubmissionException, validate_submission, data)
         metadata["build-url"] = "http://nowhere.com"
-        data = yaml.safe_load(self.factory.make_job_yaml(metadata=metadata))
+        data = yaml_safe_load(self.factory.make_job_yaml(metadata=metadata))
         self.assertRaises(SubmissionException, validate_submission, data)
         metadata["zephyr-gcc-variant"] = "4.9"
-        data = yaml.safe_load(self.factory.make_job_yaml(metadata=metadata))
+        data = yaml_safe_load(self.factory.make_job_yaml(metadata=metadata))
         validate_submission(data)
 
     def test_command_list(self):
@@ -387,15 +372,27 @@ class TestPipelineSubmit(TestCaseWithFactory):
         self.assertIn("parameters", device_dict)
         self.assertIn("timeouts", device_dict)
         self.assertIn("actions", device_dict)
+        self.assertIn("deploy", device_dict["actions"])
+        self.assertIn("boot", device_dict["actions"])
+        self.assertIn("connections", device_dict["actions"]["deploy"])
+        self.assertIn("connections", device_dict["actions"]["boot"])
+        self.assertIn("methods", device_dict["actions"]["deploy"])
+        self.assertIn("methods", device_dict["actions"]["boot"])
         device_dict = device.minimise_configuration(device_dict)
         self.assertIsNotNone(device_dict)
         self.assertNotIn("commands", device_dict)
         self.assertNotIn("parameters", device_dict)
         self.assertIn("actions", device_dict)
+        self.assertIn("deploy", device_dict["actions"])
+        self.assertIn("connections", device_dict["actions"]["deploy"])
+        self.assertIn("methods", device_dict["actions"]["deploy"])
+        self.assertIn("boot", device_dict["actions"])
+        self.assertIn("connections", device_dict["actions"]["boot"])
+        self.assertIn("methods", device_dict["actions"]["boot"])
         self.assertIn("timeouts", device_dict)
 
     def test_auto_login(self):
-        data = yaml.safe_load(self.factory.make_job_yaml())
+        data = yaml_safe_load(self.factory.make_job_yaml())
         validate_submission(data)
 
         boot_params = None
@@ -421,80 +418,22 @@ class TestPipelineSubmit(TestCaseWithFactory):
         auto_login["login_commands"] = ["whoami", "sudo su"]
         validate_submission(data)
 
-    def test_visibility(self):
-        user = self.factory.make_user()
-        user2 = self.factory.make_user()
-        user3 = self.factory.make_user()
-
-        # public set in the YAML
-        yaml_str = self.factory.make_job_yaml()
-        yaml_data = yaml.safe_load(yaml_str)
-        job = TestJob.from_yaml_and_user(yaml_str, user)
-        self.assertTrue(job.is_public)
-        self.assertTrue(job.can_view(user))
-        self.assertTrue(job.can_view(user2))
-        self.assertTrue(job.can_view(user3))
-
-        yaml_data["visibility"] = "personal"
-        self.assertEqual(yaml_data["visibility"], "personal")
-        job2 = TestJob.from_yaml_and_user(yaml.dump(yaml_data), user3)
-        self.assertFalse(job2.is_public)
-        self.assertFalse(job2.can_view(user))
-        self.assertFalse(job2.can_view(user2))
-        self.assertTrue(job2.can_view(user3))
-
-        group1, _ = Group.objects.get_or_create(name="group1")
-        group1.user_set.add(user2)
-        job2.viewing_groups.add(group1)
-        job2.visibility = TestJob.VISIBLE_GROUP
-        job2.save()
-        self.assertFalse(job2.is_public)
-        self.assertEqual(job2.visibility, TestJob.VISIBLE_GROUP)
-        self.assertEqual(len(job2.viewing_groups.all()), 1)
-        self.assertIn(group1, job2.viewing_groups.all())
-        self.assertTrue(job.can_view(user2))
-        self.assertFalse(job2.can_view(user))
-        self.assertTrue(job2.can_view(user3))
-
-        job_data = yaml.safe_load(self.factory.make_job_yaml())
-        job_data["visibility"] = {"group": [group1.name]}
-        param = job_data["visibility"]
-        if isinstance(param, dict):
-            self.assertIn("group", param)
-            self.assertIsInstance(param["group"], list)
-            self.assertIn(group1.name, param["group"])
-            self.assertIn(group1, Group.objects.filter(name__in=param["group"]))
-
-        job3 = TestJob.from_yaml_and_user(yaml.dump(job_data), user2)
-        self.assertEqual(
-            TestJob.VISIBLE_CHOICES[job3.visibility],
-            TestJob.VISIBLE_CHOICES[TestJob.VISIBLE_GROUP],
-        )
-        self.assertEqual(list(job3.viewing_groups.all()), [group1])
-        job3.refresh_from_db()
-        self.assertEqual(
-            TestJob.VISIBLE_CHOICES[job3.visibility],
-            TestJob.VISIBLE_CHOICES[TestJob.VISIBLE_GROUP],
-        )
-        self.assertEqual(list(job3.viewing_groups.all()), [group1])
-
     # FIXME: extend once the master validation code is exposed for unit tests
     def test_compatibility(self):  # pylint: disable=too-many-locals
         user = self.factory.make_user()
         # public set in the YAML
         yaml_str = self.factory.make_job_yaml()
-        yaml_data = yaml.safe_load(yaml_str)
+        yaml_data = yaml_safe_load(yaml_str)
         job = TestJob.from_yaml_and_user(yaml_str, user)
-        self.assertTrue(job.is_public)
         self.assertTrue(job.can_view(user))
         # initial state prior to validation
         self.assertEqual(job.pipeline_compatibility, 0)
         self.assertNotIn("compatibility", yaml_data)
         # FIXME: dispatcher master needs to make this kind of test more accessible.
-        definition = yaml.safe_load(job.definition)
+        definition = yaml_safe_load(job.definition)
         self.assertNotIn("protocols", definition)
         job.actual_device = Device.objects.get(hostname="fakeqemu1")
-        job_def = yaml.safe_load(job.definition)
+        job_def = yaml_safe_load(job.definition)
         job_ctx = job_def.get("context", {})
         parser = JobParser()
         device = job.actual_device
@@ -503,16 +442,16 @@ class TestPipelineSubmit(TestCaseWithFactory):
             device_config = device.load_configuration(job_ctx)  # raw dict
         except (jinja2.TemplateError, yaml.YAMLError, OSError) as exc:
             # FIXME: report the exceptions as useful user messages
-            self.fail("[%d] jinja2 error: %s" % (job.id, exc))
+            self.fail("[%s] jinja2 error: %s" % (job.id, exc))
         if not device_config or not isinstance(device_config, dict):
             # it is an error to have a pipeline device without a device dictionary as it will never get any jobs.
             msg = (
                 "Administrative error. Device '%s' has no device dictionary."
                 % device.hostname
             )
-            self.fail("[%d] device-dictionary error: %s" % (job.id, msg))
+            self.fail("[%s] device-dictionary error: %s" % (job.id, msg))
 
-        self.assertTrue(device.is_valid(system=False))
+        self.assertTrue(device.is_valid())
         device_object = PipelineDevice(
             device_config
         )  # equivalent of the NewDevice in lava-dispatcher, without .yaml file.
@@ -562,20 +501,11 @@ class TestExtendsSubmit(TestCaseWithFactory):
             device_type=self.device_type, hostname="juno-r2-uboot-01"
         )
         self.factory.make_device(device_type=self.device_type, hostname="juno-r2-01")
-        logging.basicConfig(stream=sys.stdout, level=logging.DEBUG)
-        logger = logging.getLogger("lava_scheduler_app")
-        logger.disabled = True
-        logger.propagate = False
-        logger = logging.getLogger("lava-master")
-        logging.disable(logging.DEBUG)
-        logger.disabled = True
-        logger.propagate = False
 
     def test_health_checks_extends(self):
-        device1 = Device.objects.get(hostname="juno-r2-uboot-01")
-        self.assertIsNotNone(Device.CONFIG_PATH)
+        device1 = Device.objects.get(hostname="juno-r2-01")
         self.assertIsNotNone(device1.load_configuration(output_format="raw"))
-        self.assertEqual("juno-r2-uboot", device1.get_extends())
+        self.assertEqual("juno", device1.get_extends())
         self.assertIsNotNone(device1.HEALTH_CHECK_PATH)
         self.assertTrue(
             os.path.exists(
@@ -607,14 +537,6 @@ class TestYamlMultinode(TestCaseWithFactory):
     def setUp(self):
         super().setUp()
         self.factory = YamlFactory()
-        logging.basicConfig(stream=sys.stdout, level=logging.DEBUG)
-        logger = logging.getLogger("unittests")
-        logger.disabled = True
-        logger.propagate = False
-        logger = logging.getLogger("dispatcher")
-        logging.disable(logging.DEBUG)
-        logger.disabled = True
-        logger.propagate = False
 
     def tearDown(self):
         super().tearDown()
@@ -633,7 +555,7 @@ class TestYamlMultinode(TestCaseWithFactory):
         client_check = os.path.join(
             os.path.dirname(__file__), "sample_jobs", "kvm-multinode-client.yaml"
         )
-        submission = yaml.safe_load(
+        submission = yaml_safe_load(
             open(
                 os.path.join(
                     os.path.dirname(__file__), "sample_jobs", "kvm-multinode.yaml"
@@ -647,19 +569,19 @@ class TestYamlMultinode(TestCaseWithFactory):
         self.assertEqual(len(jobs), 2)
         for role, job_list in jobs.items():
             for job in job_list:
-                del (job["protocols"]["lava-multinode"]["sub_id"])
+                del job["protocols"]["lava-multinode"]["sub_id"]
                 yaml.dump(job)  # ensure the jobs can be serialised as YAML
                 if role == "client":
-                    self.assertEqual(job, yaml.safe_load(open(client_check, "r")))
+                    self.assertEqual(job, yaml_safe_load(open(client_check, "r")))
                 if role == "server":
-                    self.assertEqual(job, yaml.safe_load(open(server_check, "r")))
+                    self.assertEqual(job, yaml_safe_load(open(server_check, "r")))
 
     @unittest.skipIf(check_rpcinfo(), "rpcinfo returns non-zero for nfs")
     def test_secondary_connection(self):
         user = self.factory.make_user()
         device_type = self.factory.make_device_type(name="mustang")
         device = self.factory.make_device(device_type, "mustang1")
-        submission = yaml.safe_load(
+        submission = yaml_safe_load(
             open(
                 os.path.join(
                     os.path.dirname(__file__),
@@ -701,7 +623,7 @@ class TestYamlMultinode(TestCaseWithFactory):
             )
             self.fail("[%d] device-dictionary error: %s" % (host_job.id, msg))
 
-        self.assertTrue(device.is_valid(system=False))
+        self.assertTrue(device.is_valid())
         device_object = PipelineDevice(
             device_config
         )  # equivalent of the NewDevice in lava-dispatcher, without .yaml file.
@@ -745,7 +667,7 @@ class TestYamlMultinode(TestCaseWithFactory):
         Tag.objects.all().delete()
         self.factory.ensure_tag("tap"),
         self.factory.ensure_tag("virtio")
-        submission = yaml.safe_load(
+        submission = yaml_safe_load(
             open(
                 os.path.join(
                     os.path.dirname(__file__), "sample_jobs", "kvm-multinode.yaml"
@@ -805,7 +727,7 @@ class TestYamlMultinode(TestCaseWithFactory):
         self.assertEqual(len(job_list), 3)
 
     def test_multinode_lxc(self):
-        submission = yaml.safe_load(
+        submission = yaml_safe_load(
             open(
                 os.path.join(
                     os.path.dirname(__file__), "sample_jobs", "lxc-multinode.yaml"
@@ -838,7 +760,7 @@ class TestYamlMultinode(TestCaseWithFactory):
                 self.fail("Unrecognised role: %s" % role)
 
     def test_multinode_hikey(self):
-        submission = yaml.safe_load(
+        submission = yaml_safe_load(
             open(
                 os.path.join(
                     os.path.dirname(__file__), "sample_jobs", "hikey_multinode.yaml"
@@ -885,7 +807,7 @@ class TestYamlMultinode(TestCaseWithFactory):
                 self.fail("Unrecognised role: %s" % role)
 
     def test_multinode_nexus4(self):
-        submission = yaml.safe_load(
+        submission = yaml_safe_load(
             open(
                 os.path.join(
                     os.path.dirname(__file__), "sample_jobs", "nexus4_multinode.yaml"
@@ -921,7 +843,7 @@ class TestYamlMultinode(TestCaseWithFactory):
         device_type = self.factory.make_device_type()
         Device.objects.filter(device_type=device_type).delete()
         Tag.objects.all().delete()
-        submission = yaml.safe_load(
+        submission = yaml_safe_load(
             open(
                 os.path.join(
                     os.path.dirname(__file__), "sample_jobs", "kvm-multinode.yaml"
@@ -962,7 +884,7 @@ class TestYamlMultinode(TestCaseWithFactory):
         self.assertEqual(len(job_object_list), 2)
         for job in job_object_list:
             self.assertEqual(list(job.sub_jobs_list), job_object_list)
-            check = yaml.safe_load(job.definition)
+            check = yaml_safe_load(job.definition)
             if check["protocols"]["lava-multinode"]["role"] == "client":
                 self.assertEqual(
                     check["protocols"]["lava-multinode"]["tags"],
@@ -982,7 +904,7 @@ class TestYamlMultinode(TestCaseWithFactory):
     def test_multinode_group(self):
         user = self.factory.make_user()
         device_type = self.factory.make_device_type()
-        submission = yaml.safe_load(
+        submission = yaml_safe_load(
             open(
                 os.path.join(
                     os.path.dirname(__file__), "sample_jobs", "kvm-multinode.yaml"
@@ -1000,8 +922,8 @@ class TestYamlMultinode(TestCaseWithFactory):
         job_object_list = _pipeline_protocols(submission, user, yaml.dump(submission))
         for job in job_object_list:
             self.assertEqual(list(job.sub_jobs_list), job_object_list)
-        check_one = yaml.safe_load(job_object_list[0].definition)
-        check_two = yaml.safe_load(job_object_list[1].definition)
+        check_one = yaml_safe_load(job_object_list[0].definition)
+        check_two = yaml_safe_load(job_object_list[1].definition)
         self.assertEqual(
             job_object_list[0].target_group, job_object_list[1].target_group
         )
@@ -1031,7 +953,7 @@ class TestYamlMultinode(TestCaseWithFactory):
     def test_multinode_definition(self):
         user = self.factory.make_user()
         device_type = self.factory.make_device_type()
-        submission = yaml.safe_load(
+        submission = yaml_safe_load(
             open(
                 os.path.join(
                     os.path.dirname(__file__), "sample_jobs", "kvm-multinode.yaml"
@@ -1067,7 +989,7 @@ class TestYamlMultinode(TestCaseWithFactory):
     def test_invalid_multinode(self):  # pylint: disable=too-many-locals
         user = self.factory.make_user()
         device_type = self.factory.make_device_type()
-        submission = yaml.safe_load(
+        submission = yaml_safe_load(
             open(
                 os.path.join(
                     os.path.dirname(__file__), "sample_jobs", "kvm-multinode.yaml"
@@ -1102,10 +1024,10 @@ class TestYamlMultinode(TestCaseWithFactory):
         )
         # FIXME: dispatcher master needs to make this kind of test more accessible.
         for job in job_object_list:
-            definition = yaml.safe_load(job.definition)
+            definition = yaml_safe_load(job.definition)
             self.assertNotEqual(definition["protocols"]["lava-multinode"]["sub_id"], "")
             job.actual_device = Device.objects.get(hostname="fakeqemu1")
-            job_def = yaml.safe_load(job.definition)
+            job_def = yaml_safe_load(job.definition)
             job_ctx = job_def.get("context", {})
             parser = JobParser()
             device = None
@@ -1134,7 +1056,7 @@ class TestYamlMultinode(TestCaseWithFactory):
                     device_object.target = device.hostname
                 device_object["hostname"] = device.hostname
 
-            self.assertTrue(device.is_valid(system=False))
+            self.assertTrue(device.is_valid())
             validate_list = job.sub_jobs_list if job.is_multinode else [job]
             for check_job in validate_list:
                 parser_device = None if job.dynamic_connection else device_object
@@ -1169,7 +1091,7 @@ class TestYamlMultinode(TestCaseWithFactory):
         self.factory.make_device(device_type, "fakeqemu2")
         self.factory.make_device(device_type, "fakeqemu3")
         self.factory.make_device(device_type, "fakeqemu4")
-        submission = yaml.safe_load(
+        submission = yaml_safe_load(
             open(
                 os.path.join(
                     os.path.dirname(__file__), "sample_jobs", "kvm-multinode.yaml"
@@ -1188,7 +1110,7 @@ class TestYamlMultinode(TestCaseWithFactory):
         device_type = self.factory.make_device_type()
         self.factory.make_device(device_type, "fakeqemu1")
         self.factory.make_device(device_type, "fakeqemu2")
-        client_submission = yaml.safe_load(
+        client_submission = yaml_safe_load(
             open(
                 os.path.join(
                     os.path.dirname(__file__),
@@ -1201,7 +1123,7 @@ class TestYamlMultinode(TestCaseWithFactory):
         job_ctx = client_submission.get("context", {})
         device = Device.objects.get(hostname="fakeqemu1")
         device_config = device.load_configuration(job_ctx)  # raw dict
-        self.assertTrue(device.is_valid(system=False))
+        self.assertTrue(device.is_valid())
         parser_device = PipelineDevice(device_config)
         parser = JobParser()
         pipeline_job = parser.parse(
@@ -1222,7 +1144,7 @@ class TestYamlMultinode(TestCaseWithFactory):
             meta_dict,
         )
         # simulate dynamic connection
-        dynamic = yaml.load(  # nosec - not suitable for safe_load
+        dynamic = yaml_load(  # nosec - not suitable for safe_load
             open(
                 os.path.join(
                     os.path.dirname(__file__),
@@ -1256,7 +1178,7 @@ class TestYamlMultinode(TestCaseWithFactory):
         bbb_type = self.factory.make_device_type("beaglebone-black")
         self.factory.make_device(hostname="bbb-01", device_type=bbb_type)
         self.factory.make_device(hostname="bbb-02", device_type=bbb_type)
-        submission = yaml.safe_load(
+        submission = yaml_safe_load(
             open(
                 os.path.join(
                     os.path.dirname(__file__), "sample_jobs", "bbb-qemu-multinode.yaml"
@@ -1267,7 +1189,7 @@ class TestYamlMultinode(TestCaseWithFactory):
         job_object_list = _pipeline_protocols(submission, user, yaml.dump(submission))
 
         for job in job_object_list:
-            definition = yaml.safe_load(job.definition)
+            definition = yaml_safe_load(job.definition)
             self.assertNotEqual(definition["protocols"]["lava-multinode"]["sub_id"], "")
             sub_ids = [job.sub_id for job in job_object_list]
             self.assertEqual(len(set(sub_ids)), len(sub_ids))
@@ -1277,7 +1199,7 @@ class TestYamlMultinode(TestCaseWithFactory):
                 job.actual_device = Device.objects.get(hostname="bbb-01")
             else:
                 self.fail("Unrecognised device type: %s" % job.requested_device_type)
-            job_def = yaml.safe_load(job.definition)
+            job_def = yaml_safe_load(job.definition)
             job_ctx = job_def.get("context", {})
             parser = JobParser()
             device_object = None
@@ -1304,7 +1226,7 @@ class TestYamlMultinode(TestCaseWithFactory):
                 if "target" not in device_object:
                     device_object.target = device.hostname
                 device_object["hostname"] = device.hostname
-                self.assertTrue(device.is_valid(system=False))
+                self.assertTrue(device.is_valid())
 
             self.assertNotEqual(job.device_role, "Error")
             parser_device = None if job.dynamic_connection else device_object
@@ -1334,7 +1256,7 @@ class TestYamlMultinode(TestCaseWithFactory):
         bbb_type = self.factory.make_device_type("beaglebone-black")
         self.factory.make_device(hostname="bbb-01", device_type=bbb_type)
         self.factory.make_device(hostname="bbb-02", device_type=bbb_type)
-        submission = yaml.safe_load(
+        submission = yaml_safe_load(
             open(
                 os.path.join(
                     os.path.dirname(__file__), "sample_jobs", "bbb-qemu-multinode.yaml"
@@ -1349,7 +1271,7 @@ class TestYamlMultinode(TestCaseWithFactory):
         ] = True
         job_object_list = _pipeline_protocols(submission, user, yaml.dump(submission))
         for job in job_object_list:
-            definition = yaml.safe_load(job.definition)
+            definition = yaml_safe_load(job.definition)
             role = definition["protocols"][MultinodeProtocol.name]["role"]
             self.assertNotEqual(definition["protocols"]["lava-multinode"]["sub_id"], "")
             if role == "client":
@@ -1365,7 +1287,6 @@ class VlanInterfaces(TestCaseWithFactory):
         super().setUp()
         # YAML, pipeline only
         user = User.objects.create_user("test", "e@mail.invalid", "test")
-        user.user_permissions.add(Permission.objects.get(codename="add_testjob"))
         user.save()
         bbb_type = self.factory.make_device_type("beaglebone-black")
         self.factory.make_device(hostname="bbb-01", device_type=bbb_type)
@@ -1376,7 +1297,7 @@ class VlanInterfaces(TestCaseWithFactory):
         )
 
     def test_vlan_interface(self):  # pylint: disable=too-many-locals
-        submission = yaml.safe_load(open(self.filename, "r"))
+        submission = yaml_safe_load(open(self.filename, "r"))
         self.assertIn("protocols", submission)
         self.assertIn("lava-vland", submission["protocols"])
         roles = [role for role, _ in submission["protocols"]["lava-vland"].items()]
