@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2017 Linaro Limited
+# Copyright (C) 2017-2019 Linaro Limited
 #
 # Author: Remi Duraffort <remi.duraffort@linaro.org>
 #
@@ -19,15 +19,13 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses>.
 
-import os
 from datetime import timedelta
-import yaml
 
 from django.contrib.auth.models import User
 from django.test import TestCase
 from django.utils import timezone
 
-from lava_dispatcher.test.utils import DummyLogger
+from lava_dispatcher.tests.utils import DummyLogger
 from lava_scheduler_app.models import Device, DeviceType, TestJob, Worker
 from lava_scheduler_app.scheduler import schedule, schedule_health_checks
 
@@ -47,17 +45,6 @@ actions: []
 
 class TestHealthCheckScheduling(TestCase):
     def setUp(self):
-        Device.CONFIG_PATH = os.path.abspath(
-            os.path.join(
-                os.path.dirname(__file__),
-                "..",
-                "..",
-                "lava_scheduler_app",
-                "tests",
-                "devices",
-            )
-        )
-
         self.worker01 = Worker.objects.create(
             hostname="worker-01", state=Worker.STATE_ONLINE
         )
@@ -79,7 +66,6 @@ class TestHealthCheckScheduling(TestCase):
             hostname="panda01",
             device_type=self.device_type01,
             worker_host=self.worker01,
-            is_public=True,
             health=Device.HEALTH_UNKNOWN,
         )
         # This device should never be considered (his worker is OFFLINE)
@@ -87,14 +73,12 @@ class TestHealthCheckScheduling(TestCase):
             hostname="panda02",
             device_type=self.device_type01,
             worker_host=self.worker02,
-            is_public=True,
             health=Device.HEALTH_UNKNOWN,
         )
         self.device03 = Device.objects.create(
             hostname="panda03",
             device_type=self.device_type01,
             worker_host=self.worker03,
-            is_public=True,
             health=Device.HEALTH_UNKNOWN,
         )
         # ignored by other tests, used to check device.is_valid handling
@@ -102,7 +86,6 @@ class TestHealthCheckScheduling(TestCase):
             hostname="unknown-01",
             device_type=self.device_type02,
             worker_host=self.worker01,
-            is_public=True,
             health=Device.HEALTH_RETIRED,
         )
 
@@ -110,10 +93,8 @@ class TestHealthCheckScheduling(TestCase):
         self.last_hc03 = TestJob.objects.create(
             health_check=True,
             actual_device=self.device03,
-            user=self.user,
             submitter=self.user,
             start_time=timezone.now(),
-            is_public=True,
             state=TestJob.STATE_FINISHED,
             health=TestJob.HEALTH_COMPLETE,
         )
@@ -147,7 +128,7 @@ class TestHealthCheckScheduling(TestCase):
         self.assertEqual(self.device03.get_health_check(), None)
         # Schedule without health check
         available_devices = schedule_health_checks(DummyLogger())[0]
-        self.assertEquals(available_devices, {"panda": ["panda01", "panda03"]})
+        self.assertEqual(available_devices, {"panda": ["panda01", "panda03"]})
 
     def test_disabled_hc(self):
         # Make sure that get_health_check does return something
@@ -159,13 +140,12 @@ class TestHealthCheckScheduling(TestCase):
         self.device_type01.disable_health_check = True
         self.device_type01.save()
         available_devices = schedule_health_checks(DummyLogger())[0]
-        self.assertEquals(available_devices, {"panda": ["panda01", "panda03"]})
+        self.assertEqual(available_devices, {"panda": ["panda01", "panda03"]})
 
     def test_no_devicedict(self):
         Device.get_health_check = _minimal_valid_job
         self.device_type02.disable_health_check = False
         self.device_type02.display = True
-        self.device_type02.owners_only = False
         self.device_type02.save()
 
         self.device04.state = Device.STATE_IDLE
@@ -187,7 +167,7 @@ class TestHealthCheckScheduling(TestCase):
         self.assertNotEqual(self.device03.get_health_check(), None)
 
         available_devices = schedule_health_checks(DummyLogger())[0]
-        self.assertEquals(available_devices, {"panda": []})
+        self.assertEqual(available_devices, {"panda": []})
         self._check_hc_scheduled(self.device01)
         self._check_hc_not_scheduled(self.device02)
         self._check_hc_scheduled(self.device03)
@@ -206,7 +186,7 @@ class TestHealthCheckScheduling(TestCase):
         self.device03.health = Device.HEALTH_GOOD
         self.device03.save()
         available_devices = schedule_health_checks(DummyLogger())[0]
-        self.assertEquals(available_devices, {"panda": ["panda03"]})
+        self.assertEqual(available_devices, {"panda": ["panda03"]})
         self._check_hc_scheduled(self.device01)
         self._check_hc_not_scheduled(self.device02)
         self._check_hc_not_scheduled(self.device03)
@@ -225,7 +205,7 @@ class TestHealthCheckScheduling(TestCase):
         self.device03.health = Device.HEALTH_LOOPING
         self.device03.save()
         available_devices = schedule_health_checks(DummyLogger())[0]
-        self.assertEquals(available_devices, {"panda": []})
+        self.assertEqual(available_devices, {"panda": []})
         self._check_hc_scheduled(self.device01)
         self._check_hc_not_scheduled(self.device02)
         self._check_hc_scheduled(self.device03)
@@ -250,7 +230,7 @@ class TestHealthCheckScheduling(TestCase):
             self.device03.health = health
             self.device03.save()
             available_devices = schedule_health_checks(DummyLogger())[0]
-            self.assertEquals(available_devices, {"panda": []})
+            self.assertEqual(available_devices, {"panda": []})
             self._check_hc_not_scheduled(self.device01)
             self._check_hc_not_scheduled(self.device02)
             self._check_hc_not_scheduled(self.device03)
@@ -274,9 +254,7 @@ class TestHealthCheckScheduling(TestCase):
         # Create a job that should be scheduled now
         j = TestJob.objects.create(
             requested_device_type=self.device_type01,
-            user=self.user,
             submitter=self.user,
-            is_public=True,
             definition=_minimal_valid_job(None),
         )
         schedule(DummyLogger())
@@ -290,9 +268,7 @@ class TestHealthCheckScheduling(TestCase):
         # Create a job that should be scheduled after the health check
         j = TestJob.objects.create(
             requested_device_type=self.device_type01,
-            user=self.user,
             submitter=self.user,
-            is_public=True,
             definition=_minimal_valid_job(None),
         )
         self.device03.refresh_from_db()
@@ -326,23 +302,17 @@ class TestHealthCheckScheduling(TestCase):
         # Create a job that should be scheduled now
         j01 = TestJob.objects.create(
             requested_device_type=self.device_type01,
-            user=self.user,
             submitter=self.user,
-            is_public=True,
             definition=_minimal_valid_job(None),
         )
         j02 = TestJob.objects.create(
             requested_device_type=self.device_type01,
-            user=self.user,
             submitter=self.user,
-            is_public=True,
             definition=_minimal_valid_job(None),
         )
         j03 = TestJob.objects.create(
             requested_device_type=self.device_type01,
-            user=self.user,
             submitter=self.user,
-            is_public=True,
             definition=_minimal_valid_job(None),
         )
 
@@ -375,16 +345,6 @@ class TestHealthCheckScheduling(TestCase):
 
 class TestVisibility(TestCase):
     def setUp(self):
-        Device.CONFIG_PATH = os.path.abspath(
-            os.path.join(
-                os.path.dirname(__file__),
-                "..",
-                "..",
-                "lava_scheduler_app",
-                "tests",
-                "devices",
-            )
-        )
         self.worker01 = Worker.objects.create(
             hostname="worker-01", state=Worker.STATE_ONLINE
         )
@@ -401,7 +361,6 @@ class TestVisibility(TestCase):
             hostname="panda01",
             device_type=self.device_type01,
             worker_host=self.worker01,
-            is_public=True,
             health=Device.HEALTH_UNKNOWN,
         )
         # This device should never be considered (his worker is OFFLINE)
@@ -409,14 +368,12 @@ class TestVisibility(TestCase):
             hostname="panda02",
             device_type=self.device_type01,
             worker_host=self.worker02,
-            is_public=True,
             health=Device.HEALTH_UNKNOWN,
         )
         self.device03 = Device.objects.create(
             hostname="panda03",
             device_type=self.device_type01,
             worker_host=self.worker03,
-            is_public=False,
             health=Device.HEALTH_UNKNOWN,
         )
         self.user = User.objects.create(username="user-01")
@@ -431,7 +388,7 @@ class TestVisibility(TestCase):
         for job in TestJob.objects.filter(
             state__in=[TestJob.STATE_SUBMITTED, TestJob.STATE_SCHEDULING]
         ):
-            job.go_state_finished(TestJob.HEALTH_GOOD)
+            job.go_state_finished(TestJob.HEALTH_COMPLETE)
 
     def _minimal_personal_job(self):
         return """
@@ -471,7 +428,6 @@ actions: []
         self._check_initial_state()
 
         self.device_type01.disable_health_check = False
-        self.device_type01.owners_only = False
         self.device_type01.save()
 
         schedule_health_checks(DummyLogger())[0]
@@ -480,42 +436,10 @@ actions: []
         self._check_hc_not_scheduled(self.device02)
         self._check_hc_scheduled(self.device03)
 
-    def test_health_visibility_owners(self):
-        self._check_initial_state()
-
-        self.device_type01.disable_health_check = False
-        self.device_type01.owners_only = True
-        self.device_type01.save()
-
-        schedule_health_checks(DummyLogger())[0]
-
-        # no health checks can be scheduled for _minimal_valid_job
-        self._check_hc_not_scheduled(self.device01)
-        self._check_hc_not_scheduled(self.device02)
-        self._check_hc_not_scheduled(self.device03)
-
-    def test_health_visibility_owners_personal(self):
-        self._check_initial_state()
-
-        # repeat test_health_visibility_owners with suitable test job
-        Device.get_health_check = self._minimal_personal_job
-
-        self.device_type01.disable_health_check = False
-        self.device_type01.owners_only = True
-        self.device_type01.save()
-
-        schedule_health_checks(DummyLogger())[0]
-
-        # health checks can be scheduled for _minimal_personal_job
-        self._check_hc_scheduled(self.device01)
-        self._check_hc_not_scheduled(self.device02)
-        self._check_hc_scheduled(self.device03)
-
     def test_health_visibility_some_restricted(self):
         self._check_initial_state()
 
         self.device_type01.disable_health_check = False
-        self.device_type01.owners_only = False
         self.device_type01.save()
 
         schedule_health_checks(DummyLogger())[0]
@@ -529,9 +453,7 @@ actions: []
         self._check_initial_state()
 
         self.device_type01.disable_health_check = False
-        self.device_type01.owners_only = False
         self.device_type01.save()
-        self.device01.is_public = False
 
         schedule_health_checks(DummyLogger())[0]
 
@@ -542,16 +464,6 @@ actions: []
 
 class TestPriorities(TestCase):
     def setUp(self):
-        Device.CONFIG_PATH = os.path.abspath(
-            os.path.join(
-                os.path.dirname(__file__),
-                "..",
-                "..",
-                "lava_scheduler_app",
-                "tests",
-                "devices",
-            )
-        )
         self.worker01 = Worker.objects.create(
             hostname="worker-01", state=Worker.STATE_ONLINE
         )
@@ -561,7 +473,6 @@ class TestPriorities(TestCase):
             device_type=self.device_type01,
             worker_host=self.worker01,
             health=Device.HEALTH_GOOD,
-            is_public=True,
         )
         self.user = User.objects.create(username="user-01")
         self.original_health_check = Device.get_health_check
@@ -588,9 +499,7 @@ class TestPriorities(TestCase):
         ]:
             j = TestJob.objects.create(
                 requested_device_type=self.device_type01,
-                user=self.user,
                 submitter=self.user,
-                is_public=True,
                 definition=_minimal_valid_job(None),
                 priority=p,
             )
@@ -695,9 +604,7 @@ class TestPriorities(TestCase):
         ]:
             j = TestJob.objects.create(
                 requested_device_type=self.device_type01,
-                user=self.user,
                 submitter=self.user,
-                is_public=True,
                 definition=_minimal_valid_job(None),
                 priority=p,
             )
