@@ -1,15 +1,13 @@
 import os
-import sys
 import yaml
 import unittest
-import logging
 import tempfile
 
-# pylint: disable=superfluous-parens,ungrouped-imports
+from lava_common.compat import yaml_safe_load
 from lava_dispatcher.parser import JobParser
 from lava_dispatcher.device import NewDevice
 from lava_dispatcher.action import Timeout
-from lava_dispatcher.test.utils import DummyLogger, infrastructure_error
+from lava_dispatcher.tests.utils import DummyLogger, infrastructure_error
 from lava_scheduler_app.tests.test_base_templates import (
     BaseTemplate,
     prepare_jinja_template,
@@ -168,10 +166,6 @@ class TestUbootTemplates(BaseTemplate.BaseTemplateCases):
         self.assertTrue(checked)
 
     def test_panda_template(self):
-        logging.basicConfig(stream=sys.stdout, level=logging.DEBUG)
-        logger = logging.getLogger("unittests")
-        logger.disabled = True
-        logger.propagate = False
         data = """{% extends 'panda.jinja2' %}
 {% set connection_command = 'telnet serial4 7012' %}
 {% set hard_reset_command = '/usr/bin/pduclient --daemon staging-master --hostname pdu15 --command reboot --port 05' %}
@@ -322,14 +316,6 @@ class TestUbootTemplates(BaseTemplate.BaseTemplateCases):
 
     @unittest.skipIf(infrastructure_error("lxc-info"), "lxc-info not installed")
     def test_panda_lxc_template(self):
-        logging.basicConfig(stream=sys.stdout, level=logging.DEBUG)
-        logger = logging.getLogger("unittests")
-        logger.disabled = True
-        logger.propagate = False
-        logger = logging.getLogger("dispatcher")
-        logging.disable(logging.DEBUG)
-        logger.disabled = True
-        logger.propagate = False
         data = """{% extends 'panda.jinja2' %}
 {% set power_off_command = '/usr/local/lab-scripts/snmp_pdu_control --hostname pdu15 --command off --port 07' %}
 {% set hard_reset_command = '/usr/local/lab-scripts/snmp_pdu_control --hostname pdu15 --command reboot --port 07' %}
@@ -341,15 +327,13 @@ class TestUbootTemplates(BaseTemplate.BaseTemplateCases):
         os.write(fdesc, yaml.dump(template_dict).encode())
         panda = NewDevice(device_yaml)
         lxc_yaml = os.path.join(
-            os.path.dirname(__file__), "devices", "panda-lxc-aep.yaml"
+            os.path.dirname(__file__), "sample_jobs", "panda-lxc-aep.yaml"
         )
         with open(lxc_yaml) as sample_job_data:
             parser = JobParser()
             job = parser.parse(sample_job_data, panda, 4577, None, "")
         os.close(fdesc)
         job.logger = DummyLogger()
-        job.logger.disabled = True
-        job.logger.propagate = False
         job.validate()
 
     def test_ethaddr(self):
@@ -425,7 +409,7 @@ class TestUbootTemplates(BaseTemplate.BaseTemplateCases):
         self.assertTrue(self.validate_data("staging-juno-01", data))
         test_template = prepare_jinja_template("staging-juno-01", data, raw=True)
         rendered = test_template.render()
-        template_dict = yaml.safe_load(rendered)
+        template_dict = yaml_safe_load(rendered)
         self.assertIsNotNone(template_dict)
         self.assertEqual({"boot": 30}, template_dict["character_delays"])
         self.assertIn("error-messages", template_dict["constants"]["u-boot"])
@@ -449,7 +433,7 @@ class TestUbootTemplates(BaseTemplate.BaseTemplateCases):
         )
 
         rendered = test_template.render(bootloader_prompt="vexpress>")
-        template_dict = yaml.safe_load(rendered)
+        template_dict = yaml_safe_load(rendered)
         self.assertIsNotNone(template_dict)
         self.assertEqual({"boot": 30}, template_dict["character_delays"])
         self.assertIn("error-messages", template_dict["constants"]["u-boot"])
@@ -508,7 +492,7 @@ class TestUbootTemplates(BaseTemplate.BaseTemplateCases):
         ]
 
         rendered = self.render_device_dictionary_file("imx8m-01.jinja2")
-        template_dict = yaml.safe_load(rendered)
+        template_dict = yaml_safe_load(rendered)
         self.assertIsNotNone(template_dict)
         self.assertIn("error-messages", template_dict["constants"]["u-boot"])
         self.assertEqual(
@@ -520,7 +504,7 @@ class TestUbootTemplates(BaseTemplate.BaseTemplateCases):
 
         context = {"bootloader_prompt": "imx8m=>"}
         rendered = self.render_device_dictionary_file("imx8m-01.jinja2", context)
-        template_dict = yaml.safe_load(rendered)
+        template_dict = yaml_safe_load(rendered)
         self.assertIsNotNone(template_dict)
         self.assertIn("error-messages", template_dict["constants"]["u-boot"])
         self.assertEqual(
@@ -537,7 +521,7 @@ class TestUbootTemplates(BaseTemplate.BaseTemplateCases):
         checked = False
         context = {"console_device": "ttyUSB1"}
         rendered = self.render_device_dictionary_file("imx8m-01.jinja2", context)
-        template_dict = yaml.safe_load(rendered)
+        template_dict = yaml_safe_load(rendered)
         commands = template_dict["actions"]["boot"]["methods"]["u-boot"]["ramdisk"][
             "commands"
         ]
@@ -549,6 +533,22 @@ class TestUbootTemplates(BaseTemplate.BaseTemplateCases):
                 checked = True
         self.assertTrue(checked)
 
+    def test_x15_template(self):
+        # Test that we can override fastboot_deploy_uboot_commands
+        rendered = self.render_device_dictionary_file("x15-01.jinja2", raw=False)
+        params = rendered["actions"]["deploy"]["methods"]["u-boot"]["parameters"]
+        self.assertEqual(params["fastboot"]["commands"], ["fastboot 1"])
+        self.assertIsNone(rendered["actions"]["deploy"]["methods"]["fastboot"])
+
+        rendered = self.render_device_dictionary_file(
+            "x15-01.jinja2",
+            raw=False,
+            job_ctx={"fastboot_deploy_uboot_commands": ["fastboot 0"]},
+        )
+        params = rendered["actions"]["deploy"]["methods"]["u-boot"]["parameters"]
+        self.assertEqual(params["fastboot"]["commands"], ["fastboot 0"])
+        self.assertIsNone(rendered["actions"]["deploy"]["methods"]["fastboot"])
+
     def test_xilinx_zcu102(self):
         with open(
             os.path.join(os.path.dirname(__file__), "devices", "zcu102.jinja2")
@@ -611,3 +611,21 @@ class TestUbootTemplates(BaseTemplate.BaseTemplateCases):
         self.assertEqual(
             template_dict["constants"]["u-boot"]["interrupt_ctrl_list"], ["c"]
         )
+
+    def test_rzn1d_template(self):
+        data = """{% extends 'rzn1d.jinja2' %}"""
+        self.assertTrue(self.validate_data("rzn1d-01", data))
+        template_dict = prepare_jinja_template("rzn1d-01", data, raw=False)
+        commands = template_dict["actions"]["boot"]["methods"]["u-boot"]["ramdisk"][
+            "commands"
+        ]
+        for line in commands:
+            if "setenv initrd_high" in line:
+                self.fail("rzn1d should not have initrd_high set")
+            if "setenv fdt_high" in line:
+                self.fail("rzn1d should not have fdt_high set")
+        # Check that "fit" boot command is available
+        commands = template_dict["actions"]["boot"]["methods"]["u-boot"]["fit"][
+            "commands"
+        ]
+        self.assertTrue(isinstance(commands, list))
