@@ -19,17 +19,24 @@
 # along with LAVA.  If not, see <http://www.gnu.org/licenses/>.
 
 import os
-import subprocess  # nosec internal
 import xmlrpc.client
 import yaml
 
 from django.http import Http404
 from django.conf import settings
+from django.contrib.auth.models import Group
 from django.core.exceptions import PermissionDenied
 
+from lava_common.compat import yaml_safe_load
 from lava_common.utils import debian_package_version
+from lava_scheduler_app.api import check_perm
 from lava_scheduler_app.views import get_restricted_job
-from lava_scheduler_app.models import Device, DeviceType
+from lava_scheduler_app.models import (
+    Device,
+    DeviceType,
+    GroupDevicePermission,
+    GroupDeviceTypePermission,
+)
 from linaro_django_xmlrpc.models import errors, Mapper, SystemAPI
 
 
@@ -79,7 +86,7 @@ class LavaSystemAPI(SystemAPI):
         ------------
         lava-server version string
         """
-        return debian_package_version(pkg="lava-server", split=False)
+        return debian_package_version(pkg="lava-server")
 
     # Update the integer return value when adding arguments to
     # existing functions anywhere in the XML-RPC API or
@@ -159,31 +166,31 @@ class LavaSystemAPI(SystemAPI):
         }
 
         master = {"ERROR": "invalid master config"}
-        filename = os.path.join(settings.MEDIA_ROOT, 'lava-master-config.yaml')
+        filename = os.path.join(settings.MEDIA_ROOT, "lava-master-config.yaml")
         if os.path.exists(filename):
             try:
-                with open(filename, 'r') as output:
-                    master = yaml.safe_load(output)
+                with open(filename, "r") as output:
+                    master = yaml_safe_load(output)
             except yaml.YAMLError as exc:
                 return master
         if master:
             data.update(master)
 
         log_config = {"ERROR": "invalid logging config"}
-        filename = os.path.join(settings.MEDIA_ROOT, 'lava-logs-config.yaml')
+        filename = os.path.join(settings.MEDIA_ROOT, "lava-logs-config.yaml")
         if os.path.exists(filename):
             try:
-                with open(filename, 'r') as output:
-                    log_config = yaml.safe_load(output)
+                with open(filename, "r") as output:
+                    log_config = yaml_safe_load(output)
             except yaml.YAMLError as exc:
                 return log_config
         if log_config:
             data.update(log_config)
         return {
-            "MASTER_URL": data['master_socket'],
-            "LOGGING_URL": data['socket'],
-            "IPv6": data['ipv6'],
-            "ENCRYPT": data.get('encrypt', False),
+            "MASTER_URL": data["master_socket"],
+            "LOGGING_URL": data["socket"],
+            "IPv6": data["ipv6"],
+            "ENCRYPT": data.get("encrypt", False),
             "EVENT_TOPIC": settings.EVENT_TOPIC,
             "EVENT_SOCKET": settings.EVENT_SOCKET,
             "EVENT_NOTIFICATION": settings.EVENT_NOTIFICATION,
@@ -238,8 +245,8 @@ class LavaSystemAPI(SystemAPI):
         self._authenticate()
         if not isinstance(job_list, list):
             raise xmlrpc.client.Fault(
-                errors.BAD_REQUEST,
-                "job list argument must be a list")
+                errors.BAD_REQUEST, "job list argument must be a list"
+            )
         username = self._switch_user(username)
         retval = {}
         for job_id in job_list:
@@ -354,8 +361,8 @@ class LavaSystemAPI(SystemAPI):
         self._authenticate()
         if not isinstance(device_list, list):
             raise xmlrpc.client.Fault(
-                errors.BAD_REQUEST,
-                "device list argument must be a list")
+                errors.BAD_REQUEST, "device list argument must be a list"
+            )
         username = self._switch_user(username)
         retval = {}
         for hostname in device_list:
@@ -364,22 +371,20 @@ class LavaSystemAPI(SystemAPI):
             except Device.DoesNotExist:
                 continue
             device_type = device.device_type
-            if device_type.owners_only and not device.is_owned_by(username):
-                continue
             retval.setdefault(device_type.name, [])
-            visible = device.is_visible_to(username)
+            visible = device.can_view(username)
             if visible:
-                retval[device_type.name].append({
-                    hostname: {
-                        'is_pipeline': True,
-                        'visible': visible,
-                        'exclusive': True
+                retval[device_type.name].append(
+                    {
+                        hostname: {
+                            "is_pipeline": True,
+                            "visible": visible,
+                            "exclusive": True,
+                        }
                     }
-                })
+                )
             else:
-                retval[device_type.name].append({
-                    hostname: {'visible': visible}
-                })
+                retval[device_type.name].append({hostname: {"visible": visible}})
         return retval
 
     def user_can_submit_to_types(self, type_list, username=None):
@@ -434,25 +439,18 @@ class LavaSystemAPI(SystemAPI):
         self._authenticate()
         if not isinstance(type_list, list):
             raise xmlrpc.client.Fault(
-                errors.BAD_REQUEST,
-                "type list argument must be a list")
-        username = self._switch_user(username)
-        if not username.has_perm('lava_scheduler_app.add_testjob'):
-            raise xmlrpc.client.Fault(
-                errors.FORBIDDEN,
-                "User '%s' does not have permissiont to submit jobs." % username
+                errors.BAD_REQUEST, "type list argument must be a list"
             )
+        user = self._switch_user(username)
+
         retval = {}
-        for type_name in type_list:
-            try:
-                device_type = DeviceType.objects.get(name=type_name)
-            except DeviceType.DoesNotExist:
-                continue
-            devices = Device.objects.filter(device_type=device_type)
-            access = []
-            for device in devices:
-                access.append(device.can_submit(username))
-            retval[device_type.name] = any(access)
+        device_types = DeviceType.objects.filter(name__in=type_list)
+
+        for device_type in device_types:
+            accessible = False
+            if user.has_perm(DeviceType.SUBMIT_PERMISSION, device_type):
+                accessible = True
+            retval[device_type.name] = accessible
         return retval
 
     def pipeline_network_map(self, switch=None):
@@ -491,38 +489,240 @@ class LavaSystemAPI(SystemAPI):
         self._authenticate()
         # get all device dictionaries, build the entire map.
         dictionaries = [
-            (device.hostname, device.load_configuration()) for device in Device.objects.all()
+            (device.hostname, device.load_configuration())
+            for device in Device.objects.visible_by_user(self.user)
         ]
-        network_map = {'switches': {}}
+        network_map = {"switches": {}}
         for (hostname, params) in dictionaries:
-            if 'interfaces' not in params:
+            if "interfaces" not in params:
                 continue
-            for interface in params['interfaces']:
-                for map_switch, port in params['map'][interface].items():
+            for interface in params["interfaces"]:
+                for map_switch, port in params["map"][interface].items():
                     port_list = []
                     device = {
-                        'interface': interface,
-                        'mac': params['mac_addr'][interface],
-                        'sysfs': params['sysfs'][interface],
-                        'hostname': hostname
+                        "interface": interface,
+                        "mac": params["mac_addr"][interface],
+                        "sysfs": params["sysfs"][interface],
+                        "hostname": hostname,
                     }
-                    port_list.append({'port': port, 'device': device})
-                    switch_port = network_map['switches'].setdefault(map_switch, [])
+                    port_list.append({"port": port, "device": device})
+                    switch_port = network_map["switches"].setdefault(map_switch, [])
                     # Any switch can only have one entry for one port
                     if port not in switch_port:
                         switch_port.extend(port_list)
 
         if switch:
-            if switch in network_map['switches']:
-                return yaml.dump(network_map['switches'][switch])
+            if switch in network_map["switches"]:
+                return yaml.dump(network_map["switches"][switch])
             else:
                 return xmlrpc.client.Fault(
-                    404, "No switch '%s' was found in the network map of supported devices." % switch)
+                    404,
+                    "No switch '%s' was found in the network map of supported devices."
+                    % switch,
+                )
         return yaml.dump(network_map)
 
+    @check_perm("lava_scheduler_app.change_devicetype")
+    def assign_perm_device_type(self, perm, device_type, group):
+        """
+        Name
+        ----
+        assign_perm_device_type(`perm`, `device_type`, `group`):
+
+        Description
+        -----------
+
+        Grant a permission to a specific group over a device type.
+
+        This function requires ``change_devicetype`` permission.
+
+        Arguments
+        ---------
+        perm: string
+            Permission codename string. Currently supported permissions for
+            Device_Types are 'view_devicetype', 'submit_to_devicetype' and
+            'change_devicetype'.
+        device_type: string
+            name of device type to assign permission for. Device type with
+            specified name must exist in LAVA.
+        group: string
+            group name to which the permission will be granted
+
+        Return value
+        ------------
+        No return value.
+        """
+        if not isinstance(device_type, str):
+            raise xmlrpc.client.Fault(
+                errors.BAD_REQUEST, "device_type name must be a string"
+            )
+        try:
+            group = Group.objects.get(name=group)
+        except Group.DoesNotExist:
+            raise xmlrpc.client.Fault(
+                errors.BAD_REQUEST, "please use existing group name"
+            )
+
+        try:
+            device_type = DeviceType.objects.get(name=device_type)
+        except DeviceType.DoesNotExist:
+            raise xmlrpc.client.Fault(
+                errors.BAD_REQUEST, "please use existing device type name"
+            )
+
+        GroupDeviceTypePermission.objects.assign_perm(perm, group, device_type)
+
+    @check_perm("lava_scheduler_app.change_devicetype")
+    def revoke_perm_device_type(self, perm, device_type, group):
+        """
+        Name
+        ----
+        revoke_perm_device_type(`perm`, `device_type`, `group`):
+
+        Description
+        -----------
+
+        Revoke a permission from a specific group over a device type.
+
+        This function requires ``change_devicetype`` permission.
+
+        Arguments
+        ---------
+        perm: string
+            Permission codename string. Currently supported permissions for
+            Device_Types are 'view_devicetype', 'submit_to_devicetype' and
+            'change_devicetype'.
+        device_type: string
+            name of device type to revoke permission for. Device type with
+            specified name must exist in LAVA.
+        group: string
+            group name to which the permission will be revoked
+
+        Return value
+        ------------
+        No return value.
+        """
+        if not isinstance(device_type, str):
+            raise xmlrpc.client.Fault(
+                errors.BAD_REQUEST, "device_type name must be a string"
+            )
+        try:
+            group = Group.objects.get(name=group)
+        except Group.DoesNotExist:
+            raise xmlrpc.client.Fault(
+                errors.BAD_REQUEST, "please use existing group name"
+            )
+
+        try:
+            device_type = DeviceType.objects.get(name=device_type)
+        except DeviceType.DoesNotExist:
+            raise xmlrpc.client.Fault(
+                errors.BAD_REQUEST, "please use existing device type name"
+            )
+
+        GroupDeviceTypePermission.objects.remove_perm(perm, group, device_type)
+
+    @check_perm("lava_scheduler_app.change_device")
+    def assign_perm_device(self, perm, device, group):
+        """
+        Name
+        ----
+        assign_perm_device(`perm`, `device`, `group`):
+
+        Description
+        -----------
+
+        Grant a permission to a specific group over a device.
+
+        This function requires ``change_device`` permission.
+
+        Arguments
+        ---------
+        perm: string
+            Permission codename string. Currently supported permissions for
+            Devices are 'view_device', 'submit_to_device' and
+            'change_device'.
+        device: string
+            device hostname to assign permission for. Device with the specific
+            hostname must exist in LAVA.
+        group: string
+            group name to which the permission will be granted
+
+        Return value
+        ------------
+        No return value.
+        """
+        if not isinstance(device, str):
+            raise xmlrpc.client.Fault(
+                errors.BAD_REQUEST, "device argument must be a string"
+            )
+        try:
+            group = Group.objects.get(name=group)
+        except Group.DoesNotExist:
+            raise xmlrpc.client.Fault(
+                errors.BAD_REQUEST, "please use existing group name"
+            )
+
+        try:
+            device = Device.objects.get(hostname=device)
+        except Device.DoesNotExist:
+            raise xmlrpc.client.Fault(
+                errors.BAD_REQUEST, "please use existing device hostname"
+            )
+
+        GroupDevicePermission.objects.assign_perm(perm, group, device)
+
+    @check_perm("lava_scheduler_app.change_device")
+    def revoke_perm_device(self, perm, device, group):
+        """
+        Name
+        ----
+        revoke_perm_device(`perm`, `device`, `group`):
+
+        Description
+        -----------
+
+        Revoke a permission from a specific group over a device.
+
+        This function requires ``change_device`` permission.
+
+        Arguments
+        ---------
+        perm: string
+            Permission codename string. Currently supported permissions for
+            Devices are 'view_device', 'submit_to_device' and 'change_device'.
+        device: string
+            device hostname to revoke permission for. Device with the specific
+            hostname must exist in LAVA.
+        group: string
+            group name to which the permission will be revoked
+
+        Return value
+        ------------
+        No return value.
+        """
+        if not isinstance(device, str):
+            raise xmlrpc.client.Fault(
+                errors.BAD_REQUEST, "device argument must be a string"
+            )
+        try:
+            group = Group.objects.get(name=group)
+        except Group.DoesNotExist:
+            raise xmlrpc.client.Fault(
+                errors.BAD_REQUEST, "please use existing group name"
+            )
+
+        try:
+            device = Device.objects.get(hostname=device)
+        except Device.DoesNotExist:
+            raise xmlrpc.client.Fault(
+                errors.BAD_REQUEST, "please use existing device hostname"
+            )
+
+        GroupDevicePermission.objects.remove_perm(perm, group, device)
+
 
 class LavaMapper(Mapper):
-
     def register_introspection_methods(self):
         """
         Register LavaSystemAPI as 'system' object.
@@ -530,4 +730,4 @@ class LavaMapper(Mapper):
         LavaSystemAPI adds a 'whoami' system method above what the default
         has.
         """
-        self.register(LavaSystemAPI, 'system')
+        self.register(LavaSystemAPI, "system")
