@@ -17,28 +17,29 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with LAVA.  If not, see <http://www.gnu.org/licenses/>.
 
-from lava_server.settings.config_file import ConfigFile
 from django.conf import settings
 
 
 def lava(request):
     return {
-        'lava': {
-            'instance_name': settings.INSTANCE_NAME,
-            'branding_url': settings.BRANDING_URL,
-            'branding_icon': settings.BRANDING_ICON,
-            'branding_alt': settings.BRANDING_ALT,
-            'branding_height': settings.BRANDING_HEIGHT,
-            'branding_width': settings.BRANDING_WIDTH,
-            'branding_bug_url': settings.BRANDING_BUG_URL,
-            'branding_source_url': settings.BRANDING_SOURCE_URL,
-            'branding_message': settings.BRANDING_MESSAGE,
+        "lava": {
+            "instance_name": settings.INSTANCE_NAME,
+            "branding_url": settings.BRANDING_URL,
+            "branding_icon": settings.BRANDING_ICON,
+            "branding_alt": settings.BRANDING_ALT,
+            "branding_height": settings.BRANDING_HEIGHT,
+            "branding_width": settings.BRANDING_WIDTH,
+            "branding_bug_url": settings.BRANDING_BUG_URL,
+            "branding_source_url": settings.BRANDING_SOURCE_URL,
+            "branding_message": settings.BRANDING_MESSAGE,
+            "branding_css": settings.BRANDING_CSS,
         }
     }
 
 
 def ldap_available(request):
-    ldap_enabled = "django_auth_ldap.backend.LDAPBackend" in settings.AUTHENTICATION_BACKENDS
+    ldap_enabled = (
+        "django_auth_ldap.backend.LDAPBackend" in settings.AUTHENTICATION_BACKENDS
+    )
     login_message_ldap = getattr(settings, "LOGIN_MESSAGE_LDAP", "")
-    return {"ldap_available": ldap_enabled,
-            "login_message_ldap": login_message_ldap}
+    return {"ldap_available": ldap_enabled, "login_message_ldap": login_message_ldap}
