@@ -20,6 +20,8 @@
 import contextlib
 import os
 
+# pylint: disable=unused-import,unused-wildcard-import,wildcard-import
+
 from lava_server.settings.common import *
 
 
@@ -27,38 +29,35 @@ from lava_server.settings.common import *
 DEBUG = True
 TEMPLATES[0]["OPTIONS"]["debug"] = True
 
-# Disable TZ for the test as dashboard_app does not pass the tests.
-# FIXME: should be removed when v1 is removed
-USE_TZ = False
+USE_TZ = True
 
 # Top-level directory of the project.
 PROJECT_SRC_DIR = os.path.normpath(
-    os.path.join(
-        os.path.dirname(
-            os.path.abspath(__file__)),
-        ".."))
+    os.path.join(os.path.dirname(os.path.abspath(__file__)), "..", "..")
+)
 
-# Top-level directory for nonvolatile files
-PRECIOUS_DIR = os.path.join(PROJECT_SRC_DIR, "precious")
-
-# Top-level directory of the precious project state.
+# Top-level directory of the static files
 #
 # In short: this is where your non-source content ends up at, this place should
 # keep the database file(s), user uploaded media files as well as the cache of
 # static files, if built.
-PROJECT_STATE_DIR = os.path.join(PRECIOUS_DIR, "var/lib/lava-server/")
+PROJECT_STATE_DIR = os.environ.get(
+    "LAVA_BASE_DIR", os.path.join(PROJECT_SRC_DIR, "tmp")
+)
 
 # Create state directory if needed
 os.makedirs(PROJECT_STATE_DIR, exist_ok=True)
 
 DATABASES = {
-    'default': {
-        'ENGINE': 'django.db.backends.postgresql_psycopg2',
-        'NAME': 'devel',
-        'USER': 'devel',
-        'PASSWORD': 'devel',
-        'HOST': 'localhost',
-        'PORT': ''}}
+    "default": {
+        "ENGINE": "django.db.backends.postgresql",
+        "NAME": "devel",
+        "USER": "devel",
+        "PASSWORD": "devel",
+        "HOST": "localhost",
+        "PORT": "",
+    }
+}
 
 # Absolute filesystem path to the directory that will hold user-uploaded files.
 # Example: "/home/media/media.lawrence.com/"
@@ -72,9 +71,20 @@ ARCHIVE_ROOT = os.path.join(PROJECT_STATE_DIR, "archive")
 # Example: "/home/media/static.lawrence.com/"
 STATIC_ROOT = os.path.join(PROJECT_STATE_DIR, "static")
 
+# Use device configuration files from source tree
+DEVICES_PATH = os.path.join(PROJECT_SRC_DIR, "etc/dispatcher-config/devices")
+DEVICE_TYPES_PATH = os.path.join(PROJECT_SRC_DIR, "etc/dispatcher-config/device-types")
+HEALTH_CHECKS_PATH = os.path.join(
+    PROJECT_SRC_DIR, "etc/dispatcher-config/health-checks"
+)
 
 # Make this unique, and don't share it with anybody.
-SECRET_KEY = '00000000000000000000000000000000000000000000000000'
+SECRET_KEY = "00000000000000000000000000000000000000000000000000"
+
+# Relax security settings to simplify local development
+ALLOWED_HOSTS = ["*"]
+CSRF_COOKIE_SECURE = False
+SESSION_COOKIE_SECURE = False
 
 # Try using devserver if available, devserver is a very useful extension that
 # makes debugging applications easier. It shows a lot of interesting output,
@@ -83,23 +93,24 @@ SECRET_KEY = '00000000000000000000000000000000000000000000000000'
 # achieved.
 with contextlib.suppress(ImportError):
     import devserver
-    INSTALLED_APPS += ['devserver']
+
+    INSTALLED_APPS += ["devserver"]
 
 USE_DEBUG_TOOLBAR = False
 
 # Any emails that would normally be sent are redirected to stdout.
 # This setting is only used for django 1.2 and newer.
-EMAIL_BACKEND = 'django.core.mail.backends.console.EmailBackend'
+EMAIL_BACKEND = "django.core.mail.backends.console.EmailBackend"
 
 # default branding details
 BRANDING_ALT = "LAVA Software logo"
-BRANDING_ICON = 'lava_server/images/logo.png'
-BRANDING_URL = 'http://www.lavasoftware.org'
-BRANDING_HEIGHT = "BRANDING_HEIGHT", 22
-BRANDING_WIDTH = "BRANDING_WIDTH", 22
+BRANDING_ICON = "lava_server/images/logo.png"
+BRANDING_URL = "http://www.lavasoftware.org"
+BRANDING_HEIGHT = 22
+BRANDING_WIDTH = 22
 BRANDING_BUG_URL = "https://git.lavasoftware.org/lava/lava/issues"
 BRANDING_SOURCE_URL = "https://git.lavasoftware.org/lava/lava"
-BRANDING_MESSAGE = ''
+BRANDING_MESSAGE = ""
 
 # Use default instance name
 INSTANCE_NAME = "default"
@@ -107,48 +118,48 @@ INSTANCE_NAME = "default"
 # Logging
 
 LOGGING = {
-    'version': 1,
-    'disable_existing_loggers': False,
-    'filters': {
-        'require_debug_false': {
-            '()': 'django.utils.log.RequireDebugFalse'
+    "version": 1,
+    "disable_existing_loggers": False,
+    "filters": {"require_debug_false": {"()": "django.utils.log.RequireDebugFalse"}},
+    "formatters": {
+        "lava": {"format": "%(levelname)s %(asctime)s %(module)s %(message)s"}
+    },
+    "handlers": {
+        "logfile": {
+            "class": "logging.handlers.WatchedFileHandler",
+            "filename": "django.log",
+            "formatter": "lava",
         }
     },
-    'formatters': {
-        'lava': {
-            'format': '%(levelname)s %(asctime)s %(module)s %(message)s'
-        }
-    },
-    'handlers': {
-        'logfile': {
-            'class': 'logging.handlers.WatchedFileHandler',
-            'filename': 'django.log',
-            'formatter': 'lava'
-        }
-    },
-    'loggers': {
-        'django': {
-            'handlers': ['logfile'],
+    "loggers": {
+        "django": {
+            "handlers": ["logfile"],
             # DEBUG outputs all SQL statements
-            'level': 'ERROR',
-            'propagate': True,
+            "level": "ERROR",
+            "propagate": True,
         },
-        'django_auth_ldap': {
-            'handlers': ['logfile'],
-            'level': 'INFO',
-            'propagate': True,
+        "django_auth_ldap": {
+            "handlers": ["logfile"],
+            "level": "INFO",
+            "propagate": True,
         },
-        'lava_scheduler_app': {
-            'handlers': ['logfile'],
-            'level': 'INFO',
-            'propagate': True,
-        }
-    }
+        "lava_scheduler_app": {
+            "handlers": ["logfile"],
+            "level": "INFO",
+            "propagate": True,
+        },
+    },
 }
 
 # Do not use caching as it interfere with test
-CACHES = {
-    'default': {
-        'BACKEND': 'django.core.cache.backends.dummy.DummyCache',
-    }
-}
+CACHES = {"default": {"BACKEND": "django.core.cache.backends.dummy.DummyCache"}}
+
+AUTHENTICATION_BACKENDS = [
+    "django.contrib.auth.backends.ModelBackend",
+    "lava_server.backends.GroupPermissionBackend",
+]
+
+try:
+    from lava_server.settings.local_settings import *  # noqa
+except ImportError:
+    pass
