@@ -1,4 +1,4 @@
-# Copyright (C) 2010 Linaro Limited
+# Copyright (C) 2010-2019 Linaro Limited
 #
 # Author: Zygmunt Krynicki <zygmunt.krynicki@linaro.org>
 #
@@ -20,13 +20,12 @@
 Unit tests for Linaro Django XML-RPC Application
 """
 import re
-import logging
 import xmlrpc.client
-from nose.tools import nottest
-from django.contrib.auth.models import User
-from django.core.urlresolvers import reverse
-from django_testscenarios.ubertest import TestCase, TestCaseWithScenarios
 
+from django.contrib.auth.models import User
+from django_testscenarios.ubertest import TestCase
+
+from lava_common.decorators import nottest
 from linaro_django_xmlrpc.models import (
     AuthToken,
     CallContext,
@@ -52,6 +51,7 @@ class MockUser:
     def is_active(self):
         return self._is_active
 
+    @property
     def is_authenticated(self):
         return self._is_authenticated
 
@@ -71,13 +71,6 @@ class ExampleAPI(ExposedAPI):
 
 
 class CallContextTests(TestCase):
-    def setUp(self):
-        super().setUp()
-        logger = logging.getLogger("linaro-django-xmlrpc-mapper")
-        logger.disabled = True
-        logger = logging.getLogger("linaro-django-xmlrpc-dispatcher")
-        logger.disabled = True
-
     def test_unauthenticated_users_are_ignored(self):
         user = MockUser(is_authenticated=False, is_active=True)
         context = CallContext(user, None, None)
@@ -391,7 +384,7 @@ class SystemAPITest(TestCase):
     def test_methodSignature_returns_signature_when_defined(self):
         class TestAPI(ExposedAPI):
             @xml_rpc_signature("str", "int")
-            def int_to_str(value):
+            def int_to_str(self, value):
                 return "%s" % value
 
         self.mapper.register(TestAPI, "TestAPI")
