@@ -65,6 +65,7 @@ def setup_logger(options):
             options.master_cert,
             options.slave_cert,
             options.job_id,
+            options.socks_proxy,
             options.ipv6,
         )
     else:
@@ -95,6 +96,9 @@ def main():
     group.add_argument(
         "--slave-cert", default=None, metavar="PATH", help="Slave certificate file"
     )
+    group.add_argument(
+        "--socks-proxy", type=str, default=None, help="Connect using a socks proxy"
+    )
     group.add_argument("--ipv6", action="store_true", default=False, help="Enable IPv6")
 
     # Parse the command line
@@ -118,7 +122,7 @@ def main():
     device = "/dev/%s" % options.device_node
 
     if not os.path.exists(device):
-        logger.debug("Skipping node not in /dev/ : %s" % options.device_node)
+        logger.debug("Skipping node not in /dev/ : %s", options.device_node)
         syslog.syslog(
             "[%s] Skipping node not in /dev/ : %s"
             % (options.job_id, options.device_node)
@@ -127,9 +131,9 @@ def main():
 
     lxc_cmd = ["lxc-device", "-n", lxc_name, "add", device]
     try:
-        output = subprocess.check_output(
+        output = subprocess.check_output(  # nosec - internal
             lxc_cmd, stderr=subprocess.STDOUT
-        )  # nosec - internal
+        )
         output = output.decode("utf-8", errors="replace")
         logger.debug(output)
         logger.info("[%s] device %s added", uniq_str, device)
